@@ -24,8 +24,6 @@
 #include <limits>
 
 // Taglib
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
 #include <tag.h>
 #include <tlist.h>
 #include <tstring.h>
@@ -44,7 +42,6 @@
 #include <wavpackfile.h>
 #include <asffile.h>
 #include <mp4file.h>
-#pragma GCC diagnostic pop
 
 // converts a peak value from the normal digital scale form to the more useful decibel form
 // decibels are relative to the /adjusted/ waveform
