@@ -52,11 +52,8 @@
 #include <audioproperties.h>
 
 #ifdef TAGLIB_EXTRAS_FOUND
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
 #include <audiblefiletyperesolver.h>
 #include <realmediafiletyperesolver.h>
-#pragma GCC diagnostic pop
 #endif // TAGLIB_EXTRAS_FOUND
 
 
@@ -150,11 +147,10 @@ Meta::Tag::generateUniqueId( const QString &path )
     TagLib::ByteVector bv = generatedUniqueIdHelper( fileref );
     md5.addData( bv.data(), bv.size() );
 
-    char databuf[16384];
-    int readlen = 0;
-
     if( qfile.open( QIODevice::ReadOnly ) )
     {
+        char databuf[16384];
+        int readlen;
         if( ( readlen = qfile.read( databuf, 16384 ) ) > 0 )
         {
             md5.addData( databuf, readlen );
