@@ -182,7 +182,7 @@ ID3v2TagHelper::setTags( const Meta::FieldHash &changes )
 {
     bool modified = TagHelper::setTags( changes );
 
-    foreach( const qint64 key, changes.keys() )
+    for( const qint64 key : changes.keys() )
     {
         QVariant value = changes.value( key );
         TagLib::ByteVector field( fieldName( key ).toCString() );
