@@ -36,7 +36,7 @@ Meta::Tag::Qt4QStringToTString( const QString &str )
 {
     // Declare new var to prevent double call of trimmed func
     QString val = str.trimmed();
-    return val.isEmpty() ? TagLib::String::null : TagLib::String( val.toUtf8().data(), TagLib::String::UTF8 );
+    return val.isEmpty() ? TagLib::String() : TagLib::String( val.toUtf8().data(), TagLib::String::UTF8 );
 }
 
 QString
