@@ -363,74 +363,6 @@ ReplayGainModeAction::ReplayGainModeAction( KActionCollection *ac, QObject *pare
     }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////
-// BurnMenuAction
-//////////////////////////////////////////////////////////////////////////////////////////
-BurnMenuAction::BurnMenuAction( KActionCollection *ac, QObject *parent )
-  : QAction( parent )
-{
-    setText(i18n( "Burn" ));
-    ac->addAction(QStringLiteral("burn_menu"), this);
-}
-
-QWidget*
-BurnMenuAction::createWidget( QWidget *w )
-{
-    KToolBar *bar = dynamic_cast<KToolBar*>(w);
-
-    if( bar && KAuthorized::authorizeAction( objectName() ) )
-    {
-        //const int id = QAction::getToolButtonID();
-
-        //addContainer( bar, id );
-        w->addAction( this );
-        //connect( bar, &KToolBar::destroyed, this, &BurnMenuAction::slotDestroyed );
-
-        //bar->insertButton( QString::null, id, true, i18n( "Burn" ), index );
-
-        //KToolBarButton* button = bar->getButton( id );
-        //button->setPopup( Amarok::BurnMenu::instance() );
-        //button->setObjectName( "toolbutton_burn_menu" );
-        //button->setIcon( "k3b" );
-
-        //return associatedWidgets().count() - 1;
-        return nullptr;
-    }
-    //else return -1;
-    else return nullptr;
-}
-
-
-BurnMenu* BurnMenu::s_instance = nullptr;
-
-BurnMenu::BurnMenu( QWidget* parent )
-    : QMenu( parent )
-{
-    s_instance = this;
-
-    addAction( i18n("Current Playlist"), this, &BurnMenu::slotBurnCurrentPlaylist );
-    addAction( i18n("Selected Tracks"), this, &BurnMenu::slotBurnSelectedTracks );
-    //TODO add "album" and "all tracks by artist"
-}
-
-QMenu*
-BurnMenu::instance()
-{
-    return s_instance ? s_instance : new BurnMenu( The::mainWindow() );
-}
-
-void
-BurnMenu::slotBurnCurrentPlaylist() //SLOT
-{
-    //K3bExporter::instance()->exportCurrentPlaylist();
-}
-
-void
-BurnMenu::slotBurnSelectedTracks() //SLOT
-{
-    //K3bExporter::instance()->exportSelectedTracks();
-}
-
 
 //////////////////////////////////////////////////////////////////////////////////////////
 // StopAction
