@@ -129,7 +129,7 @@ AmarokMimeData::tracks() const
         QCoreApplication::instance()->processEvents( QEventLoop::ExcludeUserInputEvents );
     }
     Meta::TrackList result = d->tracks;
-    foreach( Collections::QueryMaker *qm, d->queryMakers )
+    for( Collections::QueryMaker *qm : d->queryMakers )
     {
         if( d->trackMap.contains( qm ) )
             result << d->trackMap.value( qm );
@@ -160,7 +160,7 @@ AmarokMimeData::getTrackListSignal() const
     else
     {
         Meta::TrackList result = d->tracks;
-        foreach( Collections::QueryMaker *qm, d->queryMakers )
+        for( Collections::QueryMaker *qm : d->queryMakers )
         {
             if( d->trackMap.contains( qm ) )
                 result << d->trackMap.value( qm );
@@ -296,76 +296,87 @@ void AmarokMimeData::addBookmarkGroups( const BookmarkGroupList &groups )
 }
 
 QVariant
-AmarokMimeData::retrieveData( const QString &mimeType, QVariant::Type type ) const
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+AmarokMimeData::retrieveData( const QString &mimeType, QVariant::Type vtype ) const
+#else
+AmarokMimeData::retrieveData( const QString &mimeType, QMetaType type ) const
+#endif
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QMetaType type(vtype);
+#endif
     Meta::TrackList tracks = this->tracks();
     Playlists::PlaylistList playlists = this->playlists();
     Podcasts::PodcastChannelList channels = this->podcastChannels();
     Podcasts::PodcastEpisodeList episodes = this->podcastEpisodes();
     if( !tracks.isEmpty() )
     {
-        if( mimeType == QLatin1String("text/uri-list") && (type == QVariant::List || type == QVariant::ByteArray) )
+        if( mimeType == QLatin1String("text/uri-list") && (type.id() == QMetaType::QVariantList || type.id() == QMetaType::QByteArray) )
         {
             QList<QVariant> list;
-            foreach( Meta::TrackPtr track, tracks )
+            for( Meta::TrackPtr track : tracks )
             {
                 list.append( QVariant( QUrl( track->playableUrl() ) ) );
             }
-            foreach( Podcasts::PodcastEpisodePtr episode, episodes )
+            for( Podcasts::PodcastEpisodePtr episode : episodes )
             {
                 list.append( QVariant( QUrl( episode->playableUrl() ) ) );
             }
-            foreach( Playlists::PlaylistPtr playlist, playlists )
+            for( Playlists::PlaylistPtr playlist : playlists )
             {
                 list.append( QVariant( QUrl( playlist->uidUrl() ) ) );
             }
-            foreach( Podcasts::PodcastChannelPtr channel, channels )
+            for( Podcasts::PodcastChannelPtr channel : channels )
             {
                 list.append( QVariant( QUrl( channel->url() ) ) );
             }
             return QVariant( list );
         }
-        if( mimeType == QLatin1String("text/plain") && (type == QVariant::String || type == QVariant::ByteArray) )
+        if( mimeType == QLatin1String("text/plain") && (type.id() == QMetaType::QString || type.id() == QMetaType::QByteArray) )
         {
             QString result;
-            foreach( Meta::TrackPtr track, tracks )
+            for( Meta::TrackPtr track : tracks )
             {
                 if( !result.isEmpty() )
-                    result += '\n';
+                    result += QLatin1Char('\n');
                 result += track->artist()->prettyName();
                 result += QLatin1String(" - ");
                 result += track->prettyName();
             }
-            foreach( Podcasts::PodcastEpisodePtr episode, episodes )
+            for( Podcasts::PodcastEpisodePtr episode : episodes )
             {
                 if( !result.isEmpty() )
-                    result += '\n';
+                    result += QLatin1Char('\n');
                 result += episode->prettyName();
                 result += QLatin1String(" - ");
                 result += episode->channel()->prettyName();
             }
-            foreach( Playlists::PlaylistPtr playlist, playlists )
+            for( Playlists::PlaylistPtr playlist : playlists )
             {
                 if( !result.isEmpty() )
-                    result += '\n';
+                    result += QLatin1Char('\n');
                 result += playlist->prettyName();
             }
-            foreach( Podcasts::PodcastChannelPtr channel, channels )
+            for( Podcasts::PodcastChannelPtr channel : channels )
             {
                 if( !result.isEmpty() )
-                    result += '\n';
+                    result += QLatin1Char('\n');
                 result += channel->prettyName();
             }
             return QVariant( result );
         }
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    return QMimeData::retrieveData( mimeType, vtype );
+#else
     return QMimeData::retrieveData( mimeType, type );
+#endif
 }
 
 void
 AmarokMimeData::startQueries()
 {
-    foreach( Collections::QueryMaker *qm, d->queryMakers )
+    for( Collections::QueryMaker *qm : d->queryMakers )
     {
         qm->setQueryType( Collections::QueryMaker::Track );
         connect( qm, &Collections::QueryMaker::newTracksReady,
