@@ -16,7 +16,6 @@
 
 #include "App.h"
 
-#include <config.h>
 #include "EngineController.h"
 #include "KNotificationBackend.h"
 #include "MainWindow.h"
@@ -80,6 +79,14 @@
 #include <QStringList>
 #include <QTimer>                       //showHyperThreadingWarning()
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+#include <QNetworkInformation>
+#endif
+
+#ifdef Q_OS_WINDOWS
+#include <QDBusConnectionInterface>
+#endif
+
 #ifdef Q_OS_APPLE
 #include <CoreFoundation/CoreFoundation.h>
 extern void setupEventHandler_mac(SRefCon);
@@ -505,6 +512,10 @@ App::continueInit()
     //FFmpeg which should not take more than ~200msec.
     Amarok::Components::setTranscodingController( new Transcoding::Controller( this ) );
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    QNetworkInformation::instance()->loadBackendByFeatures( QNetworkInformation::Feature::Reachability );
+#endif
+
     PERF_LOG( "App init done" )
 
     // check that the amarok sql configuration is valid.
