@@ -48,6 +48,7 @@
 #include <phonon/VolumeFaderEffect>
 
 #include <QCoreApplication>
+#include <QRegularExpression>
 #include <QUrlQuery>
 #include <QTimer>
 #include <QtMath>
@@ -249,21 +250,21 @@ EngineController::slotFillInSupportedMimeTypes()
         return;
     }
 
-    QRegExp avFilter( "^(audio|video)/", Qt::CaseInsensitive );
+    QRegularExpression avFilter( QStringLiteral("^(audio|video)/"), QRegularExpression::CaseInsensitiveOption);
     m_supportedMimeTypes = Phonon::BackendCapabilities::availableMimeTypes().filter( avFilter );
 
     // Add whitelist hacks
     // MP4 Audio Books have a different extension that KFileItem/Phonon don't grok
-    if( !m_supportedMimeTypes.contains( "audio/x-m4b" ) )
-        m_supportedMimeTypes << "audio/x-m4b";
+    if( !m_supportedMimeTypes.contains( QStringLiteral("audio/x-m4b") ) )
+        m_supportedMimeTypes << QStringLiteral("audio/x-m4b");
 
     // technically, "audio/flac" is not a valid mimetype (not on IANA list), but some things expect it
-    if( m_supportedMimeTypes.contains( "audio/x-flac" ) && !m_supportedMimeTypes.contains( "audio/flac" ) )
-        m_supportedMimeTypes << "audio/flac";
+    if( m_supportedMimeTypes.contains( QStringLiteral("audio/x-flac") ) && !m_supportedMimeTypes.contains( QStringLiteral("audio/flac") ) )
+        m_supportedMimeTypes << QStringLiteral("audio/flac");
 
     // technically, "audio/mp4" is the official mime type, but sometimes Phonon returns audio/x-m4a
-    if( m_supportedMimeTypes.contains( "audio/x-m4a" ) && !m_supportedMimeTypes.contains( "audio/mp4" ) )
-        m_supportedMimeTypes << "audio/mp4";
+    if( m_supportedMimeTypes.contains( QStringLiteral("audio/x-m4a") ) && !m_supportedMimeTypes.contains( QStringLiteral("audio/mp4") ) )
+        m_supportedMimeTypes << QStringLiteral("audio/mp4");
 
     // unblock waiting for the semaphore in supportedMimeTypes(). We can over-shoot
     // resource number so that next call to supportedMimeTypes won't have to
@@ -328,7 +329,7 @@ EngineController::play() //SLOT
 
     if( isPaused() )
     {
-        if( m_currentTrack && m_currentTrack->type() == "stream" )
+        if( m_currentTrack && m_currentTrack->type() == QStringLiteral("stream") )
         {
             debug() << "This is a stream that cannot be resumed after pausing. Restarting instead.";
             play( m_currentTrack );
@@ -406,7 +407,7 @@ EngineController::playUrl( const QUrl &url, uint offset, bool startPaused )
     debug() << "Offset: " << offset;
 
     m_currentAudioCdTrack = 0;
-    if( url.scheme() == "audiocd" )
+    if( url.scheme() == QStringLiteral("audiocd") )
     {
         QStringList pathItems = url.path().split( QLatin1Char('/'), Qt::KeepEmptyParts );
         if( pathItems.count() != 3 )
@@ -421,7 +422,7 @@ EngineController::playUrl( const QUrl &url, uint offset, bool startPaused )
             error() << __PRETTY_FUNCTION__ << "failed to get positive track number from" << url.url();
             return;
         }
-        QString device = QUrlQuery(url).queryItemValue( "device" );
+        QString device = QUrlQuery(url).queryItemValue( QStringLiteral("device") );
 
         m_media->setCurrentSource( Phonon::MediaSource( Phonon::Cd, device ) );
         m_currentAudioCdTrack = trackNumber;
@@ -465,6 +466,7 @@ EngineController::playUrl( const QUrl &url, uint offset, bool startPaused )
             m_pauseTimer->stop();
             if( supportsFadeout() )
                 m_fader->setVolume( 1.0 );
+            updateReplayGainSetting( (bool) m_nextTrack ); // read gain from next track if available
             m_media->play();
         }
     }
@@ -529,7 +531,13 @@ EngineController::stop( bool forceInstant, bool playingWillContinue ) //SLOT
         unsubscribeFrom( m_currentTrack );
         if( m_currentAlbum )
             unsubscribeFrom( m_currentAlbum );
-        const qint64 pos = trackPositionMs();
+        qint64 pos = trackPositionMs();
+        // Phonon-vlc media progress reporting gets stuck when preparing a gapless track change,
+        // with some formats, it seems, causing this function to get called after m_media starts
+        // reporting a current time of 0. This function is stop, so if engine claims that position
+        // is 0, be very suspicious and try to use own value if that seems more sensible. BUG 337849
+        if( pos == 0 )
+            pos = m_lastTickPosition;
         // updateStreamLength() intentionally not here, we're probably in the middle of a track
         const qint64 length = trackLength();
         Q_EMIT trackFinishedPlaying( m_currentTrack, pos / qMax<double>( length, pos ) );
@@ -757,8 +765,15 @@ EngineController::setNextTrack( Meta::TrackPtr track )
     {
         m_media->clearQueue();
         // keep in sync with playUrl(), slotPlayableUrlFetched()
-        if( url.scheme() != "audiocd" ) // we don't support gapless for CD, bug 305708
+        // we don't support gapless for CD, bug 305708.
+        // also try to avoid volume spikes: only do gapless if replaygain is not
+        // active or tracks are from the same album, bug 299461
+        if( url.scheme() != QStringLiteral("audiocd") && ( !m_preamp
+            || AmarokConfig::replayGainMode() == AmarokConfig::EnumReplayGainMode::Off
+            || ( track->album() && track->album() == m_currentTrack->album() ) ) )
+        {
             m_media->enqueue( url );
+        }
         m_nextTrack = track;
         m_nextUrl = url;
     }
@@ -1011,42 +1026,7 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
         }
     }
 
-    if( m_currentTrack
-        && AmarokConfig::replayGainMode() != AmarokConfig::EnumReplayGainMode::Off )
-    {
-        Meta::ReplayGainTag mode;
-        // gain is usually negative (but may be positive)
-        mode = ( AmarokConfig::replayGainMode() == AmarokConfig::EnumReplayGainMode::Track)
-            ? Meta::ReplayGain_Track_Gain
-            : Meta::ReplayGain_Album_Gain;
-        qreal gain = m_currentTrack->replayGain( mode );
-
-        // peak is usually positive and smaller than gain (but may be negative)
-        mode = ( AmarokConfig::replayGainMode() == AmarokConfig::EnumReplayGainMode::Track)
-            ? Meta::ReplayGain_Track_Peak
-            : Meta::ReplayGain_Album_Peak;
-        qreal peak = m_currentTrack->replayGain( mode );
-        if( gain + peak > 0.0 )
-        {
-            debug() << "Gain of" << gain << "would clip at absolute peak of" << gain + peak;
-            gain -= gain + peak;
-        }
-
-        if( m_preamp )
-        {
-            debug() << "Using gain of" << gain << "with relative peak of" << peak;
-            // we calculate the volume change ourselves, because m_preamp->setVolumeDecibel is
-            // a little confused about minus signs
-            m_preamp->setVolume( qExp( gain * log10over20 ) );
-        }
-        else
-            warning() << "Would use gain of" << gain << ", but current Phonon backend"
-                      << "doesn't seem to support pre-amplifier (VolumeFaderEffect)";
-    }
-    else if( m_preamp )
-    {
-        m_preamp->setVolume( 1.0 );
-    }
+    updateReplayGainSetting( false );
 
     bool useTrackWithinStreamDetection = false;
     if( m_currentTrack )
@@ -1058,7 +1038,7 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
         /** We only use detect-tracks-in-stream for tracks that have stream type
          * (exactly, we purposely exclude stream/lastfm) *and* that don't have length
          * already filled in. Bug 311852 */
-        if( m_currentTrack->type() == "stream" && m_currentTrack->length() == 0 )
+        if( m_currentTrack->type() == QStringLiteral("stream") && m_currentTrack->length() == 0 )
             useTrackWithinStreamDetection = true;
     }
 
@@ -1176,7 +1156,7 @@ EngineController::slotMetaDataChanged()
             << FieldPair( Phonon::GenreMetaData, Meta::Field::GENRE )
             << FieldPair( Phonon::TracknumberMetaData, Meta::Field::TRACKNUMBER )
             << FieldPair( Phonon::DescriptionMetaData, Meta::Field::COMMENT );
-    foreach( const FieldPair &pair, fieldPairs )
+    for( const FieldPair &pair : fieldPairs )
     {
         QStringList values = m_media->metaData( pair.first );
         if( !values.isEmpty() )
@@ -1306,7 +1286,7 @@ QString EngineController::prettyNowPlaying( bool progress ) const
             // we try for pretty title as it may come out better
             title = i18nc( "track on album", "<b>%1</b> on <b>%2</b>", prettyTitle, album );
         else
-            title = "<b>" + prettyTitle + "</b>";
+            title = QStringLiteral("<b>") + prettyTitle + QStringLiteral("</b>");
 
         if( title.isEmpty() )
             title = i18n( "Unknown track" );
@@ -1316,16 +1296,16 @@ QString EngineController::prettyNowPlaying( bool progress ) const
         {
             QString source = sic->sourceName();
             if( !source.isEmpty() )
-                title += ' ' + i18nc( "track from source", "from <b>%1</b>", source );
+                title += QLatin1Char(' ') + i18nc( "track from source", "from <b>%1</b>", source );
         }
 
         if( track->length() > 0 )
         {
             QString length = Meta::msToPrettyTime( track->length() ).toHtmlEscaped();
-            title += " (";
+            title += QLatin1String(" (");
             if( progress )
-                    title += Meta::msToPrettyTime( m_lastTickPosition ).toHtmlEscaped() + '/';
-            title += length + ')';
+                    title += Meta::msToPrettyTime( m_lastTickPosition ).toHtmlEscaped() + QLatin1Char('/');
+            title += length + QLatin1Char(')');
         }
 
         return title;
@@ -1389,3 +1369,44 @@ EngineController::updateStreamLength( qint64 length )
     Q_EMIT currentMetadataChanged( lengthMetaData );
 }
 
+void
+EngineController::updateReplayGainSetting( bool next )
+{
+    Meta::TrackPtr track = ( next ? m_nextTrack : m_currentTrack );
+    if( track
+        && AmarokConfig::replayGainMode() != AmarokConfig::EnumReplayGainMode::Off )
+    {
+        Meta::ReplayGainTag mode;
+        // gain is usually negative (but may be positive)
+        mode = ( AmarokConfig::replayGainMode() == AmarokConfig::EnumReplayGainMode::Track)
+            ? Meta::ReplayGain_Track_Gain
+            : Meta::ReplayGain_Album_Gain;
+        qreal gain = track->replayGain( mode );
+
+        // peak is usually positive and smaller than gain (but may be negative)
+        mode = ( AmarokConfig::replayGainMode() == AmarokConfig::EnumReplayGainMode::Track)
+            ? Meta::ReplayGain_Track_Peak
+            : Meta::ReplayGain_Album_Peak;
+        qreal peak = track->replayGain( mode );
+        if( gain + peak > 0.0 )
+        {
+            debug() << "Gain of" << gain << "would clip at absolute peak of" << gain + peak;
+            gain -= gain + peak;
+        }
+
+        if( m_preamp )
+        {
+            debug() << "Using gain of" << gain << "with relative peak of" << peak;
+            // we calculate the volume change ourselves, because m_preamp->setVolumeDecibel is
+            // a little confused about minus signs
+            m_preamp->setVolume( qExp( gain * log10over20 ) );
+        }
+        else
+            warning() << "Would use gain of" << gain << ", but current Phonon backend"
+                      << "doesn't seem to support pre-amplifier (VolumeFaderEffect)";
+    }
+    else if( m_preamp )
+    {
+        m_preamp->setVolume( 1.0 );
+    }
+}
