@@ -18,13 +18,13 @@
 #define GLOBALCURRENTTRACKACTIONS_H
 
 #include "amarok_export.h"
-#include "meta/Meta.h"
-#include "SmartPointerList.h"
+#include "core/meta/forward_declarations.h"
 
-#include <QAction>
+#include <QObject>
 
 
 class GlobalCurrentTrackActions;
+class QAction;
 
 namespace The {
     AMAROK_EXPORT GlobalCurrentTrackActions* globalCurrentTrackActions();
@@ -35,7 +35,7 @@ A global list of actions that is made available to all playing tracks.
 
 	@author Nikolaj Hald Nielsen <nhn@kde.org> 
 */
-class AMAROK_EXPORT GlobalCurrentTrackActions
+class AMAROK_EXPORT GlobalCurrentTrackActions : public QObject
 {
     friend GlobalCurrentTrackActions* The::globalCurrentTrackActions();
     
@@ -45,9 +45,9 @@ public:
     
 private:
     GlobalCurrentTrackActions();
-    ~GlobalCurrentTrackActions();
+    ~GlobalCurrentTrackActions() override;
     
-    SmartPointerList<QAction> m_actions;
+    QList<QAction*> m_actions;
 };
 
 #endif
