@@ -86,6 +86,7 @@ class AMAROK_EXPORT MainWindow : public KMainWindow
         QPointer<QMenu> ToolsMenu() const { return m_toolsMenu; }
         QPointer<QMenu> SettingsMenu() const { return m_settingsMenu; }
         QPointer<Playlist::Dock> playlistDock() const { return m_playlistDock; }
+        QPointer<ContextDock> contextDock() const { return m_contextDock; }
         void deleteBrowsers();
 
         /* Reimplemented from QMainWindow to allow only one active toolbar at any time */
@@ -108,10 +109,10 @@ class AMAROK_EXPORT MainWindow : public KMainWindow
         bool isWaitingForCd() const;
 
         /**
-         * @return Whether the application is on the currently active virtual desktop. On non-X11 systems
-           this is always true.
+         * @return Whether the application is on the currently active virtual desktop and visible.
+           Behaviour might depend on windowing system.
          */
-        bool isOnCurrentDesktop() const;
+        void checkIfExpensivesShouldBeDrawn();
 
     Q_SIGNALS:
         void loveTrack( Meta::TrackPtr track );
@@ -119,6 +120,12 @@ class AMAROK_EXPORT MainWindow : public KMainWindow
         void skipTrack();
         void switchQueueStateShortcut();
 
+        /**
+        * Called when something happens with window that might affect the need to draw expensive elements
+        * The parameter tells if drawing should continue
+        */
+        void drawNeedChanged( bool ) const;
+
     public Q_SLOTS:
         void showHide();
         void slotFullScreen();
@@ -206,6 +213,7 @@ class AMAROK_EXPORT MainWindow : public KMainWindow
         int m_searchField;
 
         bool m_waitingForCd;
+        bool m_expensiveDrawingPaused;
 };
 
 
