@@ -38,9 +38,9 @@ OpmlWriter::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread)
 #define _x m_xmlWriter
     _x->setAutoFormatting( true );
     _x->writeStartDocument();
-    _x->writeStartElement( "opml" );
-    _x->writeAttribute( "version", "2.0" );
-    _x->writeStartElement( "head" );
+    _x->writeStartElement( QStringLiteral("opml") );
+    _x->writeAttribute( QStringLiteral("version"), QStringLiteral("2.0") );
+    _x->writeStartElement( QStringLiteral("head") );
     QMapIterator<QString, QString> ai( m_headerData ); //attributesIterator
     while( ai.hasNext() )
     {
@@ -48,8 +48,8 @@ OpmlWriter::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread)
         _x->writeTextElement( ai.key(), ai.value() );
     }
     _x->writeEndElement(); // head
-    _x->writeStartElement( "body" );
-    foreach( const OpmlOutline *childOutline, m_rootOutlines )
+    _x->writeStartElement( QStringLiteral("body") );
+    for( const OpmlOutline *childOutline : m_rootOutlines )
         writeOutline( childOutline );
     _x->writeEndDocument(); //implicitly closes all open tags (opml & body)
     Q_EMIT result( 0 );
@@ -77,9 +77,9 @@ OpmlWriter::writeOutline( const OpmlOutline *outline )
 {
     bool hasChildren = outline->children().count() != 0;
     if( hasChildren && ( outline->opmlNodeType() != IncludeNode ) )
-        _x->writeStartElement( "outline" );
+        _x->writeStartElement( QStringLiteral("outline") );
     else
-        _x->writeEmptyElement( "outline" );
+        _x->writeEmptyElement( QStringLiteral("outline") );
     QMapIterator<QString, QString> ai( outline->attributes() ); // attributesIterator
     while( ai.hasNext() )
     {
@@ -90,7 +90,7 @@ OpmlWriter::writeOutline( const OpmlOutline *outline )
     // children of expanded include nodes should not be saved.
     if( hasChildren && ( outline->opmlNodeType() != IncludeNode ) )
     {
-        foreach( const OpmlOutline *childOutline, outline->children() )
+        for( const OpmlOutline *childOutline : outline->children() )
             writeOutline( childOutline );
         _x->writeEndElement(); // outline
     }
