@@ -57,7 +57,11 @@ Amarok::TrayIcon::TrayIcon( QObject *parent )
     setStatus( KStatusNotifierItem::Active );
 
     // Remove the "Configure Amarok..." action, as it makes no sense in the tray menu
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const QString preferences = QLatin1String(KStandardAction::name( KStandardAction::Preferences ));
+#else
     const QString preferences = KStandardAction::name( KStandardAction::Preferences );
+#endif
     contextMenu()->removeAction( ac->action( preferences ) );
 
     PERF_LOG( "Before adding actions" );
@@ -65,22 +69,23 @@ Amarok::TrayIcon::TrayIcon( QObject *parent )
 #ifdef Q_OS_APPLE
     // Add these functions to the dock icon menu in OS X
     qt_mac_set_dock_menu( contextMenu() );
-    contextMenu()->addAction( ac->action( "playlist_playmedia" ) );
+    contextMenu()->addAction( ac->action( QStringLiteral("playlist_playmedia") ) );
     contextMenu()->addSeparator();
 #endif
 
-    contextMenu()->addAction( ac->action( "prev"       ) );
-    contextMenu()->addAction( ac->action( "play_pause" ) );
-    contextMenu()->addAction( ac->action( "stop"       ) );
-    contextMenu()->addAction( ac->action( "next"       ) );
+    contextMenu()->addAction( ac->action( QStringLiteral("prev")       ) );
+    contextMenu()->addAction( ac->action( QStringLiteral("play_pause") ) );
+    contextMenu()->addAction( ac->action( QStringLiteral("stop")       ) );
+    contextMenu()->addAction( ac->action( QStringLiteral("next")       ) );
 
-    contextMenu()->addSeparator();
+    m_separator = contextMenu()->addSeparator();
+    contextMenu()->addActions( actionCollection() ); // quit and restore
 
-    contextMenu()->setObjectName( "TrayIconContextMenu" );
+    contextMenu()->setObjectName( QStringLiteral("TrayIconContextMenu") );
 
     PERF_LOG( "Initializing system tray icon" );
 
-    setIconByName( "amarok-symbolic" );
+    setIconByName( QStringLiteral("amarok-symbolic") );
     updateOverlayIcon();
     updateToolTipIcon();
     updateMenu();
@@ -127,12 +132,12 @@ Amarok::TrayIcon::updateToolTipIcon()
         }
         else
         {
-            setToolTipIconByName( "amarok" );
+            setToolTipIconByName( QStringLiteral("amarok") );
         }
     }
     else
     {
-        setToolTipIconByName( "amarok" );
+        setToolTipIconByName( QStringLiteral("amarok") );
     }
 }
 
@@ -171,12 +176,12 @@ Amarok::TrayIcon::updateToolTip()
             QString stars;
             for( int i = 0; i < rating / 2; ++i )
                 stars += QStringLiteral( "<img src=\"%1\" height=\"%2\" width=\"%3\">" )
-                        .arg( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/star.png" ) )
+                        .arg( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/star.png") ) )
                         .arg( QFontMetrics( QToolTip::font() ).height() )
                         .arg( QFontMetrics( QToolTip::font() ).height() );
             if( rating % 2 )
                 stars += QStringLiteral( "<img src=\"%1\" height=\"%2\" width=\"%3\">" )
-                        .arg( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/smallstar.png" ) )
+                        .arg( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/smallstar.png") ) )
                         .arg( QFontMetrics( QToolTip::font() ).height() )
                         .arg( QFontMetrics( QToolTip::font() ).height() );
 
@@ -192,7 +197,7 @@ Amarok::TrayIcon::updateToolTip()
         const QDateTime lastPlayed = statistics->lastPlayed();
         tooltip << i18n( "Last played: %1", Amarok::verboseTimeSince( lastPlayed ) );
 
-        setToolTipSubTitle( tooltip.join("<br>") );
+        setToolTipSubTitle( tooltip.join( QStringLiteral("<br>") ) );
     }
     else
     {
@@ -265,7 +270,7 @@ Amarok::TrayIcon::action( const QString& name, const QMap<QString, QAction*> &ac
 void
 Amarok::TrayIcon::updateMenu()
 {
-    foreach( QAction* action, m_extraActions )
+    for( QAction* action : m_extraActions )
     {
         contextMenu()->removeAction( action );
         // -- delete actions without parent (e.g. the ones from the capabilities)
@@ -275,12 +280,6 @@ Amarok::TrayIcon::updateMenu()
         }
     }
 
-    QMap<QString, QAction*> actionByName;
-    foreach (QAction* action, actionCollection())
-    {
-        actionByName.insert(action->text(), action);
-    }
-
     m_extraActions.clear();
 
     contextMenu()->removeAction( m_separator.data() );
@@ -289,7 +288,7 @@ Amarok::TrayIcon::updateMenu()
 
     if( m_track )
     {
-        foreach( QAction *action, The::globalCurrentTrackActions()->actions() )
+        for( QAction *action : The::globalCurrentTrackActions()->actions() )
         {
             m_extraActions.append( action );
             connect( action, &QObject::destroyed, this, [this, action]() { m_extraActions.removeAll( action ); } );
@@ -299,7 +298,7 @@ Amarok::TrayIcon::updateMenu()
         if( ac )
         {
             QList<QAction*> actions = ac->actions();
-            foreach( QAction *action, actions )
+            for( QAction *action : actions )
             {
                 m_extraActions.append( action );
                 connect( action, &QObject::destroyed, this, [this, action]() { m_extraActions.removeAll( action ); } );
@@ -315,21 +314,18 @@ Amarok::TrayIcon::updateMenu()
         }
     }
 
-    // second statement checks if the menu has already been populated (first startup), if not: do it
-    if( m_extraActions.count() > 0 ||
-        contextMenu()->actions().last() != actionByName.value( "file_quit" ) )
+    if( m_extraActions.count() > 0 )
     {
         // remove the 2 bottom items, so we can push them to the bottom again
-        contextMenu()->removeAction( action( "file_quit", actionByName ) );
-        contextMenu()->removeAction( action( "minimizeRestore", actionByName ) );
+        for( const auto action : actionCollection() )
+            contextMenu()->removeAction( action );
 
-        foreach( QAction* action, m_extraActions )
+        for( const auto action : m_extraActions )
             contextMenu()->addAction( action );
 
         m_separator = contextMenu()->addSeparator();
         // readd
-        contextMenu()->addAction( action( "minimizeRestore", actionByName  ) );
-        contextMenu()->addAction( action( "file_quit", actionByName  ) );
+        contextMenu()->addActions( actionCollection() );
     }
 }
 
@@ -337,9 +333,9 @@ void
 Amarok::TrayIcon::updateOverlayIcon()
 {
     if( The::engineController()->isPlaying() )
-        setOverlayIconByName( "media-playback-start" );
+        setOverlayIconByName( QStringLiteral("media-playback-start") );
     else if( The::engineController()->isPaused() )
-        setOverlayIconByName( "media-playback-pause" );
+        setOverlayIconByName( QStringLiteral("media-playback-pause") );
     else
         setOverlayIconByName( QString() );
 }
