@@ -19,8 +19,7 @@
 
 #include "amarok_export.h"
 #include "BrowserDefines.h"
-
-#include <KVBox>
+#include "widgets/BoxWidget.h"
 
 #include <QIcon>
 
@@ -32,7 +31,7 @@ class BrowserCategoryList;
  *
  * @author Nikolaj Hald Nielsen <nhn@kde.org>
 */
-class AMAROK_EXPORT BrowserCategory : public KVBox
+class AMAROK_EXPORT BrowserCategory : public BoxWidget
 {
     Q_OBJECT
 
@@ -44,12 +43,12 @@ public:
      * @param name The internal name of the category, used for generating Amarok urls. This should never be translated.
      * @param parent The parent widget.
      */
-    BrowserCategory( const QString &name, QWidget *parent = 0 );
+    explicit BrowserCategory( const QString &name, QWidget *parent = nullptr );
 
     /**
      * Destructor.
      */
-    ~BrowserCategory();
+    ~BrowserCategory() override;
 
     /**
      * Get the internal name of this category.
@@ -139,7 +138,7 @@ public:
     virtual void polish() {}
     virtual void setupAddItems() {}
 
-    //These 2 functions are forwarded to simplifiy the creation of urls
+    //These 2 functions are forwarded to simplify the creation of urls
     //even though they might not be needed in many cases.
     virtual QString filter() const { return QString(); }
     virtual QList<CategoryId::CatMenuId> levels() const { return QList<CategoryId::CatMenuId>(); }
@@ -156,13 +155,13 @@ public:
 
     QList<BrowserBreadcrumbItem *> additionalItems();
 
-public slots:
+public Q_SLOTS:
     void activate();
 
     //Called if this category itself is re-clicked in the breadcrumb
     virtual void reActivate() {}
 
-private slots:
+private Q_SLOTS:
     void slotSettingsChanged();
 
 private:
