@@ -17,67 +17,106 @@
 #ifndef FILEBROWSERMKII_H
 #define FILEBROWSERMKII_H
 
-#include "BrowserCategory.h"
-#include "FileView.h"
-#include "MimeTypeFilterProxyModel.h"
+#include "browsers/BrowserCategory.h"
 
-#include "widgets/SearchWidget.h"
+#include <QUrl>
 
-#include <KDirModel>
-#include <QTimer>
+class QAbstractItemView;
+class QModelIndex;
 
 class FileBrowser : public BrowserCategory
 {
     Q_OBJECT
-public:
-    FileBrowser( const char * name, QWidget *parent );
-    ~FileBrowser();
 
-    virtual void setupAddItems();
-    virtual void polish();
-    
-    virtual QString prettyName() const;
+public:
+    FileBrowser( const char *name, QWidget *parent );
+    ~FileBrowser() override;
+
+    void setupAddItems() override;
 
     /**
     * Navigate to a specific directory
     */
-    void setDir( const QString &dir );
+    void setDir( const QUrl &dir );
 
-protected slots:
-    void itemActivated( const QModelIndex &index );
-    
-    void slotSetFilterTimeout();
-    void slotFilterNow();
+    /**
+     * Return the path of the currently shown dir.
+     */
+    QString currentDir() const;
 
+public Q_SLOTS:
     void addItemActivated( const QString &callback );
 
-    virtual void reActivate();
+protected Q_SLOTS:
+    void slotNavigateToDirectory( const QModelIndex &index );
+
+    void reActivate() override;
 
     /**
      * Shows/hides the columns as selected in the context menu of the header of the
      * file view.
      * @param toggled the visibility state of a column in the context menu.
      */
-    void toggleColumn( bool toggled);
+    void toggleColumn( bool toggled );
 
+    /**
+     * Go backward in history
+     */
+    void back();
+
+    /**
+     * Go forward in history
+     */
+    void forward();
+
+    /**
+     * Navigates up one level in the path shown
+     */
+    void up();
+
+    /**
+     * Navigates to home directory
+     */
+    void home();
+
+    /*
+     * Refreshes current directory
+     */
+    void refresh();
+
+    /**
+     * Handle results of trying to setup an item in "places" that needed mounting or other
+     * special setup.
+     * @param index the index that we tried to setup
+     * @param success did the setup succeed?
+     */
+    void setupDone( const QModelIndex &index, bool success );
+
+private Q_SLOTS:
+    void initView();
+    void updateHeaderState();
 
 private:
-    void readConfig();
-    void writeConfig();
+    class Private;
+    Private *const d;
+};
 
-    QList< QAction * >       m_columnActions; //! Maintains the mapping action<->column
+/**
+ * Helper class that calls setCurrentIndex on a model view as soon as the model
+ * adds a row and then it auto-deletes itself.
+ */
+class DelayedActivator : public QObject
+{
+    Q_OBJECT
 
-    QStringList siblingsForDir( const QString &path );
-    
-    SearchWidget             *m_searchWidget;
-    KDirModel                *m_kdirModel;
-    MimeTypeFilterProxyModel *m_mimeFilterProxyModel;
+    public:
+        explicit DelayedActivator( QAbstractItemView *view );
 
-    QTimer                    m_filterTimer;
-    QString                   m_currentFilter;
-    QString                   m_currentPath;
-    FileView                 *m_fileView;
-        
+    private Q_SLOTS:
+        void slotRowsInserted( const QModelIndex &parent, int start );
+
+    private:
+        QAbstractItemView *m_view;
 };
 
 #endif // FILEBROWSERMKII_H
