@@ -20,9 +20,7 @@
 #include "PlaylistBrowserView.h"
 
 #include "MainWindow.h"
-#include "PaletteHandler.h"
 #include "PopupDropperFactory.h"
-#include "SvgHandler.h"
 #include "amarokconfig.h"
 #include "browsers/playlistbrowser/PlaylistBrowserModel.h"
 #include "browsers/playlistbrowser/PlaylistsByProviderProxy.h"
@@ -42,8 +40,6 @@
 #include <QMessageBox>
 #include <QMouseEvent>
 
-#include <KConfigGroup>
-
 #include <algorithm>
 
 using namespace PlaylistBrowserNS;
@@ -69,37 +65,37 @@ PlaylistBrowserNS::PlaylistBrowserView::PlaylistBrowserView( QAbstractItemModel
 
     m_appendAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-add-amarok") ),
             i18n( "&Add to Playlist" ), this );
-    m_appendAction->setProperty( "popupdropper_svg_id", "append" );
+    m_appendAction->setProperty( "popupdropper_svg_id", QStringLiteral("append") );
     connect( m_appendAction, &QAction::triggered, this, &PlaylistBrowserView::slotAppend );
 
     m_loadAction = new QAction( QIcon::fromTheme( QStringLiteral("folder-open") ), i18nc( "Replace the currently "
             "loaded tracks with these", "&Replace Playlist" ), this );
-    m_loadAction->setProperty( "popupdropper_svg_id", "load" );
+    m_loadAction->setProperty( "popupdropper_svg_id", QStringLiteral("load") );
     connect( m_loadAction, &QAction::triggered, this, &PlaylistBrowserView::slotLoad );
 
     m_setNewAction = new QAction( QIcon::fromTheme( QStringLiteral("rating") ), i18nc( "toggle the \"new\" status "
             " of this podcast episode", "&New" ), this );
-    m_setNewAction->setProperty( "popupdropper_svg_id", "new" );
+    m_setNewAction->setProperty( "popupdropper_svg_id", QStringLiteral("new") );
     m_setNewAction->setCheckable( true );
     connect( m_setNewAction, &QAction::triggered, this, &PlaylistBrowserView::slotSetNew );
 
     m_renamePlaylistAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ),
             i18n( "&Rename..." ), this );
-    m_renamePlaylistAction->setProperty( "popupdropper_svg_id", "edit" );
+    m_renamePlaylistAction->setProperty( "popupdropper_svg_id", QStringLiteral("edit") );
     // key shortcut is only for display purposes here, actual one is determined by View in Model/View classes
     m_renamePlaylistAction->setShortcut( Qt::Key_F2 );
     connect( m_renamePlaylistAction, &QAction::triggered, this, &PlaylistBrowserView::slotRename );
 
     m_deletePlaylistAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-remove-amarok") ),
             i18n( "&Delete..." ), this );
-    m_deletePlaylistAction->setProperty( "popupdropper_svg_id", "delete" );
+    m_deletePlaylistAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete") );
     // key shortcut is only for display purposes here, actual one is determined by View in Model/View classes
     m_deletePlaylistAction->setShortcut( Qt::Key_Delete );
     connect( m_deletePlaylistAction, &QAction::triggered, this, &PlaylistBrowserView::slotDelete );
 
     m_removeTracksAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-remove-amarok") ),
             QStringLiteral( "<placeholder>" ), this );
-    m_removeTracksAction->setProperty( "popupdropper_svg_id", "delete" );
+    m_removeTracksAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete") );
     // key shortcut is only for display purposes here, actual one is determined by View in Model/View classes
     m_removeTracksAction->setShortcut( Qt::Key_Delete );
     connect( m_removeTracksAction, &QAction::triggered, this, &PlaylistBrowserView::slotRemoveTracks );
@@ -139,7 +135,7 @@ PlaylistBrowserNS::PlaylistBrowserView::mouseReleaseEvent( QMouseEvent *event )
         return;
     }
 
-    if( event->button() == Qt::MidButton )
+    if( event->button() == Qt::MiddleButton )
     {
         insertIntoPlaylist( index, Playlist::OnMiddleClickOnSelectedItems );
         event->accept();
@@ -162,7 +158,7 @@ void PlaylistBrowserNS::PlaylistBrowserView::startDrag( Qt::DropActions supporte
     if( m_pd && m_pd->isHidden() )
     {
         QActionList actions = actionsFor( selectedIndexes() );
-        foreach( QAction *action, actions )
+        for( QAction *action : actions )
             m_pd->addItem( The::popupDropperFactory()->createItem( action ) );
 
         m_pd->show();
@@ -219,7 +215,7 @@ PlaylistBrowserNS::PlaylistBrowserView::keyPressEvent( QKeyEvent *event )
 void
 PlaylistBrowserNS::PlaylistBrowserView::mouseDoubleClickEvent( QMouseEvent *event )
 {
-    if( event->button() == Qt::MidButton )
+    if( event->button() == Qt::MiddleButton )
     {
         event->accept();
         return;
@@ -267,7 +263,7 @@ void PlaylistBrowserNS::PlaylistBrowserView::contextMenuEvent( QContextMenuEvent
     }
 
     QMenu menu;
-    foreach( QAction *action, actions )
+    for( QAction *action : actions )
         menu.addAction( action );
     menu.exec( mapToGlobal( event->pos() ) );
 
@@ -287,7 +283,7 @@ PlaylistBrowserNS::PlaylistBrowserView::actionsFor( const QModelIndexList &index
     QSet<PlaylistProvider *> providers, writableProviders;
     QActionList actions;
     QModelIndexList newPodcastEpisodes, oldPodcastEpisodes;
-    foreach( const QModelIndex &idx, indexes )
+    for( const QModelIndex &idx : indexes )
     {
         // direct provider actions:
         actions << idx.data( PrettyTreeRoles::DecoratorRole ).value<QActionList>();
@@ -327,11 +323,11 @@ PlaylistBrowserNS::PlaylistBrowserView::actionsFor( const QModelIndexList &index
         m_writableActionProvider = writableProviders.values().first();
 
     // process per-provider actions
-    foreach( PlaylistProvider *provider, providers )
+    for( PlaylistProvider *provider : providers )
     {
         // prepare arguments and get relevant actions
         PlaylistList providerPlaylists;
-        foreach( const PlaylistPtr &playlist, m_actionPlaylists )
+        for( const PlaylistPtr &playlist : m_actionPlaylists )
         {
             if( playlist->provider() == provider )
                 providerPlaylists << playlist;
@@ -339,7 +335,11 @@ PlaylistBrowserNS::PlaylistBrowserView::actionsFor( const QModelIndexList &index
         actions << provider->playlistActions( providerPlaylists );
 
         QMultiHash<PlaylistPtr, int> playlistTracks;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QHashIterator<PlaylistPtr, int> it( m_actionTracks );
+#else
+        QMultiHashIterator<PlaylistPtr, int> it( m_actionTracks );
+#endif
         while( it.hasNext() )
         {
             it.next();
@@ -430,7 +430,7 @@ void
 PlaylistBrowserView::slotSetNew( bool newState )
 {
     QModelIndexList indices = m_setNewAction->data().value<QModelIndexList>();
-    foreach( const QModelIndex &idx, indices )
+    for( const QModelIndex &idx : indices )
         model()->setData( idx, newState, PlaylistBrowserModel::EpisodeIsNewRole );
 }
 
@@ -457,13 +457,13 @@ PlaylistBrowserView::slotDelete()
 
     using namespace Playlists;
     QHash<PlaylistProvider *, PlaylistList> providerPlaylists;
-    foreach( const PlaylistPtr &playlist, m_writableActionPlaylists )
+    for( const PlaylistPtr &playlist : m_writableActionPlaylists )
     {
         if( playlist->provider() )
             providerPlaylists[ playlist->provider() ] << playlist;
     }
     QStringList providerNames;
-    foreach( const PlaylistProvider *provider, providerPlaylists.keys() )
+    for( const PlaylistProvider *provider : providerPlaylists.keys() )
         providerNames << provider->prettyName();
 
     QString deletionString = ( m_writableActionPlaylists.count() == 1 ?
@@ -480,7 +480,7 @@ PlaylistBrowserView::slotDelete()
 
     if( button == QMessageBox::Yes )
     {
-        foreach( PlaylistProvider *provider, providerPlaylists.keys() )
+        for( PlaylistProvider *provider : providerPlaylists.keys() )
             provider->deletePlaylists( providerPlaylists.value( provider ) );
     }
 }
@@ -488,12 +488,12 @@ PlaylistBrowserView::slotDelete()
 void
 PlaylistBrowserView::slotRemoveTracks()
 {
-    foreach( Playlists::PlaylistPtr playlist, m_writableActionTracks.uniqueKeys() )
+    for( Playlists::PlaylistPtr playlist : m_writableActionTracks.uniqueKeys() )
     {
         QList<int> trackIndices = m_writableActionTracks.values( playlist );
         std::sort( trackIndices.begin(), trackIndices.end() );
         int removed = 0;
-        foreach( int trackIndex, trackIndices )
+        for( int trackIndex : trackIndices )
         {
             playlist->removeTrack( trackIndex - removed /* account for already removed */ );
             removed++;
@@ -523,7 +523,7 @@ PlaylistBrowserView::slotExport()
 
     QStringList supportedMimeTypes;
 
-    supportedMimeTypes << QStringLiteral("video/x-ms-asf"); //ASX
+    supportedMimeTypes << QStringLiteral("audio/x-ms-asx"); //ASX
     supportedMimeTypes << QStringLiteral("audio/x-mpegurl"); //M3U
     supportedMimeTypes << QStringLiteral("audio/x-scpls"); //PLS
     supportedMimeTypes << QStringLiteral("application/xspf+xml"); //XSPF
@@ -562,13 +562,13 @@ PlaylistBrowserView::insertIntoPlaylist( Playlist::AddOptions options )
     Meta::TrackList tracks;
 
     // add tracks for fully-selected playlists:
-    foreach( Playlists::PlaylistPtr playlist, m_actionPlaylists )
+    for( Playlists::PlaylistPtr playlist : m_actionPlaylists )
     {
         tracks << playlist->tracks();
     }
 
     // filter-out tracks from playlists that are selected, add lone tracks:
-    foreach( Playlists::PlaylistPtr playlist, m_actionTracks.uniqueKeys() )
+    for( Playlists::PlaylistPtr playlist : m_actionTracks.uniqueKeys() )
     {
         if( m_actionPlaylists.contains( playlist ) )
             continue;
@@ -576,7 +576,7 @@ PlaylistBrowserView::insertIntoPlaylist( Playlist::AddOptions options )
         Meta::TrackList playlistTracks = playlist->tracks();
         QList<int> positions = m_actionTracks.values( playlist );
         std::sort( positions.begin(), positions.end() );
-        foreach( int position, positions )
+        for( int position : positions )
         {
             if( position >= 0 && position < playlistTracks.count() )
                 tracks << playlistTracks.at( position );
