@@ -19,9 +19,6 @@
 
 #include <QAbstractProxyModel>
 #include <QModelIndex>
-#include <QMultiHash>
-#include <QStringList>
-#include <QIcon>
 
 typedef QMap<int, QVariant> ItemData;
 typedef QMap<int, ItemData> RowData;
@@ -127,8 +124,6 @@ class QtGroupingProxy : public QAbstractProxyModel
         QModelIndex m_rootIndex;
         int m_groupedColumn;
 
-        /* debug function */
-        void dumpGroups() const;
 };
 
 #endif //GROUPINGPROXY_H
