@@ -71,14 +71,14 @@ TrackItem::metadataChanged(const Meta::TrackPtr &track )
     {
         setData( album->isCompilation(), AlbumCompilationRole );
         int num = 0;
-        foreach( const Meta::TrackPtr &track, album->tracks() )
+        for( const Meta::TrackPtr &track : album->tracks() )
         {
             if( num < track->trackNumber() )
                 num = track->trackNumber();
         }
         setData( num, AlbumMaxTrackNumberRole );
     }
-    setToolTip( QString( "%1 (%2)" ).arg( track->name(), Meta::msToPrettyTime(track->length()) ) );
+    setToolTip( QStringLiteral( "%1 (%2)" ).arg( track->name(), Meta::msToPrettyTime(track->length()) ) );
 }
 
 void
