@@ -28,8 +28,6 @@
 
 #include <cmath>
 
-#include <KWindowSystem>
-
 #include <QQuickWindow>
 #include <QTimer>
 
@@ -146,7 +144,7 @@ Analyzer::Base::refreshSampleRate()
 KConfigGroup
 Analyzer::Base::config() const
 {
-    return Amarok::config( QStringLiteral( "Context" ) ).group( "Analyzer" );
+    return Amarok::config( QStringLiteral( "Context" ) ).group( QStringLiteral("Analyzer") );
 }
 
 void
