@@ -25,7 +25,6 @@
 #include "core/meta/Meta.h"
 #include "core/support/Debug.h"
 #include "core-impl/capabilities/timecode/TimecodeLoadCapability.h"
-#include "widgets/ProgressWidget.h"
 
 #include <KLocalizedString>
 
@@ -67,7 +66,7 @@ bool Capabilities::TimecodeWriteCapability::writeAutoTimecode( qint64 milisecond
     {
         QScopedPointer<TimecodeLoadCapability> tcl( track->create<TimecodeLoadCapability>() );
         BookmarkList list = tcl->loadTimecodes();
-        foreach( AmarokUrlPtr oldUrl, list )
+        for( AmarokUrlPtr oldUrl : list )
         {
             if( oldUrl->command() == QLatin1String("play")  ) {
                 if( oldUrl->customValue() == QLatin1String("auto timecode") ) {
