@@ -30,7 +30,6 @@
 #include <Solid/Predicate>
 #include <Solid/Device>
 
-#include <QDesktopServices>
 #include <QDir>
 #include <QFile>
 #include <QList>
@@ -43,9 +42,9 @@ MountPointManager::MountPointManager( QObject *parent, QSharedPointer<SqlStorage
     , m_ready( false )
 {
     DEBUG_BLOCK
-    setObjectName( "MountPointManager" );
+    setObjectName( QStringLiteral("MountPointManager") );
 
-    if ( !Amarok::config( "Collection" ).readEntry( "DynamicCollection", true ) )
+    if ( !Amarok::config( QStringLiteral("Collection") ).readEntry( "DynamicCollection", true ) )
     {
         debug() << "Dynamic Collection deactivated in amarokrc, not loading plugins, not connecting signals";
         m_ready = true;
@@ -66,8 +65,8 @@ MountPointManager::handleMusicLocation()
     // to v2.2.2, which did not store the location into config.
     // and also for versions up to 2.7-git that did write the Use MusicLocation entry
 
-    KConfigGroup folders = Amarok::config( "Collection Folders" );
-    const QString entryKey( "Use MusicLocation" );
+    KConfigGroup folders = Amarok::config( QStringLiteral("Collection Folders") );
+    const QString entryKey( QStringLiteral("Use MusicLocation") );
     if( !folders.hasKey( entryKey ) )
         return; // good, already solved, nothing to do
 
@@ -93,8 +92,7 @@ MountPointManager::~MountPointManager()
     DEBUG_BLOCK
 
     m_handlerMapMutex.lock();
-    foreach( DeviceHandler *dh, m_handlerMap )
-        delete dh;
+    qDeleteAll( m_handlerMap );
     m_handlerMapMutex.unlock();
 
     // DeviceHandlerFactories are memory managed using QObject parentship
@@ -109,7 +107,7 @@ MountPointManager::createDeviceFactories()
     factories << new MassStorageDeviceHandlerFactory( this );
     factories << new NfsDeviceHandlerFactory( this );
     factories << new SmbDeviceHandlerFactory( this );
-    foreach( DeviceHandlerFactory *factory, factories )
+    for( DeviceHandlerFactory *factory : factories )
     {
         debug() << "Initializing DeviceHandlerFactory of type:" << factory->type();
         if( factory->canCreateFromMedium() )
@@ -122,7 +120,7 @@ MountPointManager::createDeviceFactories()
 
     Solid::Predicate predicate = Solid::Predicate( Solid::DeviceInterface::StorageAccess );
     QList<Solid::Device> devices = Solid::Device::listFromQuery( predicate );
-    foreach( const Solid::Device &device, devices )
+    for( const Solid::Device &device : devices )
         createHandlerFromDevice( device, device.udi() );
 
     m_ready = true;
@@ -135,7 +133,7 @@ MountPointManager::getIdForUrl( const QUrl &url )
     int mountPointLength = 0;
     int id = -1;
     m_handlerMapMutex.lock();
-    foreach( DeviceHandler *dh, m_handlerMap )
+    for( DeviceHandler *dh : m_handlerMap )
     {
         if ( url.path().startsWith( dh->getDevicePath() ) && mountPointLength < dh->getDevicePath().length() )
         {
@@ -177,7 +175,7 @@ MountPointManager::getMountPointForId( const int id ) const
     }
     else
         //TODO better error handling
-        mountPoint = '/';
+        mountPoint = QLatin1Char('/');
     return mountPoint;
 }
 
@@ -211,7 +209,7 @@ MountPointManager::getAbsolutePath( const int deviceId, const QString& relativeP
         else
         {
             m_handlerMapMutex.unlock();
-            const QStringList lastMountPoint = m_storage->query( QString( "SELECT lastmountpoint FROM devices WHERE id = %1" )
+            const QStringList lastMountPoint = m_storage->query( QStringLiteral( "SELECT lastmountpoint FROM devices WHERE id = %1" )
                                                                  .arg( deviceId ) );
             if ( lastMountPoint.isEmpty() )
             {
@@ -231,7 +229,7 @@ MountPointManager::getAbsolutePath( const int deviceId, const QString& relativeP
     }
 
     if( QFileInfo( absoluteUrl.toLocalFile() ).isDir() )
-        absoluteUrl.setPath( absoluteUrl.adjusted( QUrl::StripTrailingSlash ).path() + '/' );
+        absoluteUrl.setPath( absoluteUrl.adjusted( QUrl::StripTrailingSlash ).path() + QLatin1Char('/') );
 
     return absoluteUrl.toLocalFile();
 }
@@ -281,15 +279,15 @@ MountPointManager::collectionFolders() const
 
     //TODO max: cache data
     QStringList result;
-    KConfigGroup folders = Amarok::config( "Collection Folders" );
+    KConfigGroup folders = Amarok::config( QStringLiteral("Collection Folders") );
     const IdList ids = getMountedDeviceIds();
 
-    foreach( int id, ids )
+    for( int id : ids )
     {
         const QStringList rpaths = folders.readEntry( QString::number( id ), QStringList() );
-        foreach( const QString &strIt, rpaths )
+        for( const QString &strIt : rpaths )
         {
-            const QUrl url = QUrl::fromLocalFile( ( strIt == "./" ) ? getMountPointForId( id ) : getAbsolutePath( id, strIt ) );
+            const QUrl url = QUrl::fromLocalFile( ( strIt == QStringLiteral("./") ) ? getMountPointForId( id ) : getAbsolutePath( id, strIt ) );
             const QString absPath = url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
             if ( !result.contains( absPath ) )
                 result.append( absPath );
@@ -303,7 +301,7 @@ void
 MountPointManager::setCollectionFolders( const QStringList &folders )
 {
     typedef QMap<int, QStringList> FolderMap;
-    KConfigGroup folderConf = Amarok::config( "Collection Folders" );
+    KConfigGroup folderConf = Amarok::config( QStringLiteral("Collection Folders") );
     FolderMap folderMap;
 
     for( const QString &folder : folders )
@@ -340,11 +338,11 @@ MountPointManager::slotDeviceAdded( const QString &udi )
     DEBUG_BLOCK
     Solid::Predicate predicate = Solid::Predicate( Solid::DeviceInterface::StorageAccess );
     QList<Solid::Device> devices = Solid::Device::listFromQuery( predicate );
-    //Looking for a specific udi in predicate seems flaky/buggy; the foreach loop barely
+    //Looking for a specific udi in predicate seems flaky/buggy; the for loop barely
     //takes any time, so just be safe
     bool found = false;
     debug() << "looking for udi " << udi;
-    foreach( const Solid::Device &device, devices )
+    for( const Solid::Device &device : devices )
     {
         if( device.udi() == udi )
         {
@@ -361,7 +359,11 @@ MountPointManager::slotDeviceRemoved( const QString &udi )
 {
     DEBUG_BLOCK
     m_handlerMapMutex.lock();
-    foreach( DeviceHandler *dh, m_handlerMap )
+    // Actually this copy isn't probably necessary as the function returns right after any
+    // alteration of the looped m_handlerMap, but I'm definitely not confident enough & not
+    // able to test well enough to loop it here raw
+    const auto map = m_handlerMap;
+    for( DeviceHandler *dh : map )
     {
         if( dh->deviceMatchesUdi( udi ) )
         {
@@ -384,7 +386,7 @@ void MountPointManager::createHandlerFromDevice( const Solid::Device& device, co
     if ( device.isValid() )
     {
         debug() << "Device added and mounted, checking handlers";
-        foreach( DeviceHandlerFactory *factory, m_mediumFactories )
+        for( DeviceHandlerFactory *factory : m_mediumFactories )
         {
             if( factory->canHandle( device ) )
             {
