@@ -34,12 +34,10 @@
 #include "SqlCollectionLocation.h"
 #include "SqlQueryMaker.h"
 #include "SqlScanResultProcessor.h"
-#include "SvgHandler.h"
 #include "MainWindow.h"
 
 #include "collectionscanner/BatchFile.h"
 
-#include <QApplication>
 #include <QDir>
 #include <QMessageBox>
 #include <QStandardPaths>
@@ -90,13 +88,13 @@ protected:
 
         // -- query all known directories
         QString deviceIds;
-        foreach( int id, idList )
+        for( int id : idList )
         {
             if( !deviceIds.isEmpty() )
-                deviceIds += ',';
+                deviceIds += QLatin1Char(',');
             deviceIds += QString::number( id );
         }
-        QString query = QString( "SELECT deviceid, dir, changedate FROM directories WHERE deviceid IN (%1);" );
+        QString query = QStringLiteral( "SELECT deviceid, dir, changedate FROM directories WHERE deviceid IN (%1);" );
 
         QStringList values = m_collection->sqlStorage()->query( query.arg( deviceIds ) );
         for( QListIterator<QString> iter( values ); iter.hasNext(); )
@@ -120,9 +118,9 @@ protected:
         QList<QPair<QString, uint> > knownDirs = getKnownDirs();
         if( !knownDirs.isEmpty() )
         {
-            QString path = QStandardPaths::writableLocation( QStandardPaths::GenericDataLocation ) + "/amarok/amarokcollectionscanner_batchscan.xml";
+            QString path = QStandardPaths::writableLocation( QStandardPaths::GenericDataLocation ) + QStringLiteral("/amarok/amarokcollectionscanner_batchscan.xml");
             while( QFile::exists( path ) )
-                path += '_';
+                path += QLatin1Char('_');
 
             CollectionScanner::BatchFile batchfile;
             batchfile.setTimeDefinitions( knownDirs );
@@ -295,13 +293,13 @@ SqlCollection::~SqlCollection()
 QString
 SqlCollection::uidUrlProtocol() const
 {
-    return "amarok-sqltrackuid";
+    return QStringLiteral("amarok-sqltrackuid");
 }
 
 QString
 SqlCollection::generateUidUrl( const QString &hash )
 {
-    return uidUrlProtocol() + "://" + hash;
+    return uidUrlProtocol() + QStringLiteral("://") + hash;
 }
 
 QueryMaker*
@@ -330,7 +328,7 @@ SqlCollection::possiblyContainsTrack( const QUrl &url ) const
 {
     if( url.isLocalFile() )
     {
-        foreach( const QString &folder, collectionFolders() )
+        for( const QString &folder : collectionFolders() )
         {
             QUrl q = QUrl::fromLocalFile( folder );
             if( q.isParentOf( url ) || q.matches( url , QUrl::StripTrailingSlash) )
@@ -347,7 +345,7 @@ SqlCollection::trackForUrl( const QUrl &url )
 {
     if( url.scheme() == uidUrlProtocol() )
         return m_registry->getTrackFromUid( url.url() );
-    else if( url.scheme() == "file" )
+    else if( url.scheme() == QStringLiteral("file") )
         return m_registry->getTrack( url.path() );
     else
         return Meta::TrackPtr();
@@ -381,7 +379,7 @@ SqlCollection::location()
 void
 SqlCollection::slotDeviceAdded( int id )
 {
-    QString query = "select count(*) from tracks inner join urls on tracks.url = urls.id where urls.deviceid = %1";
+    QString query = QStringLiteral("select count(*) from tracks inner join urls on tracks.url = urls.id where urls.deviceid = %1");
     QStringList rs = m_sqlStorage->query( query.arg( id ) );
     if( !rs.isEmpty() )
     {
@@ -400,7 +398,7 @@ SqlCollection::slotDeviceAdded( int id )
 void
 SqlCollection::slotDeviceRemoved( int id )
 {
-    QString query = "select count(*) from tracks inner join urls on tracks.url = urls.id where urls.deviceid = %1";
+    QString query = QStringLiteral("select count(*) from tracks inner join urls on tracks.url = urls.id where urls.deviceid = %1");
     QStringList rs = m_sqlStorage->query( query.arg( id ) );
     if( !rs.isEmpty() )
     {
@@ -445,11 +443,11 @@ SqlCollection::dumpDatabaseContent()
 {
     DatabaseUpdater updater( this );
 
-    QStringList tables = m_sqlStorage->query( "select table_name from INFORMATION_SCHEMA.tables WHERE table_schema='amarok'" );
-    foreach( const QString &table, tables )
+    QStringList tables = m_sqlStorage->query( QStringLiteral( "select table_name from INFORMATION_SCHEMA.tables WHERE table_schema='amarok'" ) );
+    for( const QString &table : tables )
     {
         QString filePath =
-            QDir::home().absoluteFilePath( table + '-' + QDateTime::currentDateTime().toString( Qt::ISODate ) + ".csv" );
+            QDir::home().absoluteFilePath( table + QLatin1Char('-') + QDateTime::currentDateTime().toString( Qt::ISODate ) + QStringLiteral(".csv") );
         updater.writeCSVFile( table, filePath, true );
     }
 }
