@@ -38,11 +38,13 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
+#include <QRegularExpression>
 #include <QStorageInfo>
 
 #include <KFileItem>
 #include <KJob>
 #include <KIO/DeleteJob>
+#include <KIO/FileCopyJob>
 #include <KIO/Job>
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -88,7 +90,7 @@ SqlCollectionLocation::isWritable() const
     bool path_exists_with_space = false;
     bool path_exists_writable = false;
     QStringList folders = actualLocation();
-    foreach( const QString &path, folders )
+    for( const QString &path : folders )
     {
         float free_space = QStorageInfo( path ).bytesAvailable();
         if( free_space <= 0 )
@@ -245,7 +247,7 @@ SqlCollectionLocation::insert( const Meta::TrackPtr &track, const QString &path
             metaTrack->setReplayGain( modes[i], track->replayGain( modes[i] ) );
 
     Meta::LabelList labels = track->labels();
-    foreach( Meta::LabelPtr label, labels )
+    for( Meta::LabelPtr label : labels )
         metaTrack->addLabel( label );
 
     if( fileTags.value( Meta::valFormat, int(Amarok::Unknown) ).toInt() != int(Amarok::Unknown) )
@@ -284,12 +286,12 @@ SqlCollectionLocation::showDestinationDialog( const Meta::TrackList &tracks,
     setGoingToRemoveSources( removeSources );
 
     KIO::filesize_t transferSize = 0;
-    foreach( Meta::TrackPtr track, tracks )
+    for( Meta::TrackPtr track : tracks )
         transferSize += track->filesize();
 
     const QStringList actual_folders = actualLocation(); // the folders in the collection
     QStringList available_folders; // the folders which have freespace available
-    foreach(const QString &path, actual_folders)
+    for(const QString &path : actual_folders)
     {
         if( path.isEmpty() )
             continue;
@@ -436,7 +438,7 @@ void SqlCollectionLocation::slotTransferJobFinished( KJob* job )
     }
     // filter the list of destinations to only include tracks
     // that were successfully copied
-    foreach( const Meta::TrackPtr &track, m_destinations.keys() )
+    for( const Meta::TrackPtr &track : m_destinations.keys() )
     {
         if( QFile::exists( m_destinations[ track ] ) )
             insert( track, m_destinations[ track ] );
@@ -454,7 +456,7 @@ void SqlCollectionLocation::slotTransferJobAborted()
     m_transferjob->kill();
     // filter the list of destinations to only include tracks
     // that were successfully copied
-    foreach( const Meta::TrackPtr &track, m_destinations.keys() )
+    for( const Meta::TrackPtr &track : m_destinations.keys() )
     {
         if( QFile::exists( m_destinations[ track ] ) )
             insert( track, m_destinations[ track ] ); // was already copied, so have to insert it in the db
@@ -510,7 +512,7 @@ bool SqlCollectionLocation::startNextJob( const Transcoding::Configuration &conf
         src.setPath( QDir::cleanPath(src.path()) );
         // KIO::file_copy in KF5 needs scheme
         if (src.isRelative() && src.host().isEmpty()) {
-            src.setScheme("file");
+            src.setScheme(QStringLiteral("file"));
         }
 
         bool hasMoodFile = QFile::exists( moodFile( src ).toLocalFile() );
@@ -533,7 +535,7 @@ bool SqlCollectionLocation::startNextJob( const Transcoding::Configuration &conf
         QDir dir = destInfo.dir();
         if( !dir.exists() )
         {
-            if( !dir.mkpath( "." ) )
+            if( !dir.mkpath( QStringLiteral(".") ) )
             {
                 warning() << "Could not create directory " << dir;
                 source()->transferError(track, i18n( "Could not create directory: %1", dir.path() ) );
@@ -674,7 +676,7 @@ SqlCollectionLocation::moodFile( const QUrl &track ) const
     QUrl moodPath = track;
     QString fileName = moodPath.fileName();
     moodPath = moodPath.adjusted(QUrl::RemoveFilename);
-    moodPath.setPath(moodPath.path() +  '.' + fileName.replace( QRegExp( "(\\.\\w{2,5})$" ), ".mood" ) );
+    moodPath.setPath(moodPath.path() + QLatin1Char('.') + fileName.replace( QRegularExpression( QStringLiteral("(\\.\\w{2,5})$" )), QStringLiteral(".mood") ) );
     return moodPath;
 }
 
@@ -717,7 +719,7 @@ void TransferJob::start()
     if( m_location == nullptr )
     {
         setError( 1 );
-        setErrorText( "Location is null!" );
+        setErrorText( QStringLiteral("Location is null!") );
         emitResult();
         return;
     }
@@ -765,7 +767,7 @@ bool TransferJob::doKill()
 {
     DEBUG_BLOCK
     m_killed = true;
-    foreach( KJob* job, subjobs() )
+    for( KJob* job : subjobs() )
     {
         job->kill();
     }
