@@ -48,7 +48,6 @@
 #include <QDateTime>
 #include <QDir>
 #include <QFile>
-#include <QMultiHash>
 #include <QReadWriteLock>
 #include <QReadLocker>
 #include <QWriteLocker>
@@ -73,7 +72,7 @@ SqlTrack::getTrackReturnValues()
 {
     //do not use any weird column names that contains commas: this will break getTrackReturnValuesCount()
     // NOTE: when changing this, always check that SqlTrack::TrackReturnIndex enum remains valid
-    return "urls.id, urls.deviceid, urls.rpath, urls.directory, urls.uniqueid, "
+    return QStringLiteral("urls.id, urls.deviceid, urls.rpath, urls.directory, urls.uniqueid, "
            "tracks.id, tracks.title, tracks.comment, "
            "tracks.tracknumber, tracks.discnumber, "
            "statistics.score, statistics.rating, "
@@ -88,19 +87,19 @@ SqlTrack::getTrackReturnValues()
            "albums.name, albums.id, albums.artist, " // TODO: again here
            "genres.name, genres.id, " // TODO: again here
            "composers.name, composers.id, " // TODO: again here
-           "years.name, years.id"; // TODO: again here
+           "years.name, years.id"); // TODO: again here
 }
 
 QString
 SqlTrack::getTrackJoinConditions()
 {
-    return "LEFT JOIN tracks ON urls.id = tracks.url "
+    return QStringLiteral("LEFT JOIN tracks ON urls.id = tracks.url "
            "LEFT JOIN statistics ON urls.id = statistics.url "
            "LEFT JOIN artists ON tracks.artist = artists.id "
            "LEFT JOIN albums ON tracks.album = albums.id "
            "LEFT JOIN genres ON tracks.genre = genres.id "
            "LEFT JOIN composers ON tracks.composer = composers.id "
-           "LEFT JOIN years ON tracks.year = years.id";
+           "LEFT JOIN years ON tracks.year = years.id");
 }
 
 int
@@ -330,7 +329,7 @@ SqlTrack::setUidUrl( const QString &uid )
     QString newid = uid;
     QString protocol;
     if( m_collection )
-        protocol = m_collection->uidUrlProtocol()+"://";
+        protocol = m_collection->uidUrlProtocol()+QStringLiteral("://");
     if( !newid.startsWith( protocol ) )
         newid.prepend( protocol );
 
@@ -405,7 +404,7 @@ SqlTrack::setAlbumArtist( const QString &newAlbumArtist )
     if( m_album.isNull() )
         return;
 
-    if( !newAlbumArtist.compare( "Various Artists", Qt::CaseInsensitive ) ||
+    if( !newAlbumArtist.compare( QStringLiteral("Various Artists"), Qt::CaseInsensitive ) ||
         !newAlbumArtist.compare( i18n( "Various Artists" ), Qt::CaseInsensitive ) )
     {
         commitIfInNonBatchUpdate( Meta::valCompilation, true );
@@ -474,7 +473,7 @@ SqlTrack::type() const
     return m_url.isLocalFile()
            ? Amarok::FileTypeSupport::toString( m_filetype )
             // don't localize. This is used in different files to identify streams, see EngineController quirks
-           : "stream";
+           : QStringLiteral("stream");
 }
 
 void
@@ -1061,26 +1060,26 @@ SqlTrack::updatePlaylistsToDb( const FieldHash &fields, const QString &oldUid )
 
     // keep this in sync with SqlPlaylist::saveTracks()!
     if( fields.contains( Meta::valUrl ) )
-        tags << QString( "url='%1'" ).arg( storage->escape( m_url.path() ) );
+        tags << QStringLiteral( "url='%1'" ).arg( storage->escape( m_url.path() ) );
     if( fields.contains( Meta::valTitle ) )
-        tags << QString( "title='%1'" ).arg( storage->escape( m_title ) );
+        tags << QStringLiteral( "title='%1'" ).arg( storage->escape( m_title ) );
     if( fields.contains( Meta::valAlbum ) )
-        tags << QString( "album='%1'" ).arg( m_album ? storage->escape( m_album->prettyName() ) : "" );
+        tags << QStringLiteral( "album='%1'" ).arg( m_album ? storage->escape( m_album->prettyName() ) : QStringLiteral("") );
     if( fields.contains( Meta::valArtist ) )
-        tags << QString( "artist='%1'" ).arg( m_artist ? storage->escape( m_artist->prettyName() ) : "" );
+        tags << QStringLiteral( "artist='%1'" ).arg( m_artist ? storage->escape( m_artist->prettyName() ) : QStringLiteral("") );
     if( fields.contains( Meta::valLength ) )
-        tags << QString( "length=%1").arg( QString::number( m_length ) );
+        tags << QStringLiteral( "length=%1").arg( QString::number( m_length ) );
     if( fields.contains( Meta::valUniqueId ) )
     {
         // SqlPlaylist mirrors uniqueid to url, update it too, bug 312128
-        tags << QString( "url='%1'" ).arg( storage->escape( m_uid ) );
-        tags << QString( "uniqueid='%1'" ).arg( storage->escape( m_uid ) );
+        tags << QStringLiteral( "url='%1'" ).arg( storage->escape( m_uid ) );
+        tags << QStringLiteral( "uniqueid='%1'" ).arg( storage->escape( m_uid ) );
     }
 
     if( !tags.isEmpty() )
     {
-        QString update = "UPDATE playlist_tracks SET %1 WHERE uniqueid = '%2';";
-        update = update.arg( tags.join( ", " ), storage->escape( oldUid ) );
+        QString update = QStringLiteral("UPDATE playlist_tracks SET %1 WHERE uniqueid = '%2';");
+        update = update.arg( tags.join( QStringLiteral(", ") ), storage->escape( oldUid ) );
         storage->query( update );
     }
 }
@@ -1095,12 +1094,12 @@ SqlTrack::updateEmbeddedCoversToDb( const FieldHash &fields, const QString &oldU
     QString tags;
 
     if( fields.contains( Meta::valUniqueId ) )
-        tags += QString( ",path='%1'" ).arg( storage->escape( m_uid ) );
+        tags += QStringLiteral( ",path='%1'" ).arg( storage->escape( m_uid ) );
 
     if( !tags.isEmpty() )
     {
         tags = tags.remove(0, 1); // the first character is always a ','
-        QString update = "UPDATE images SET %1 WHERE path = '%2';";
+        QString update = QStringLiteral("UPDATE images SET %1 WHERE path = '%2';");
         update = update.arg( tags, storage->escape( oldUid ) );
         storage->query( update );
     }
@@ -1112,11 +1111,11 @@ SqlTrack::prettyTitle( const QString &filename ) //static
     QString s = filename; //just so the code is more readable
 
     //remove .part extension if it exists
-    if (s.endsWith( ".part" ))
+    if (s.endsWith( QStringLiteral(".part") ))
         s = s.left( s.length() - 5 );
 
     //remove file extension, s/_/ /g and decode %2f-like sequences
-    s = s.left( s.lastIndexOf( QLatin1Char('.') ) ).replace( '_', ' ' );
+    s = s.left( s.lastIndexOf( QLatin1Char('.') ) ).replace( QLatin1Char('_'), QLatin1Char(' ') );
     s = QUrl::fromPercentEncoding( s.toLatin1() );
 
     return s;
@@ -1149,21 +1148,21 @@ SqlTrack::cachedLyrics() const
 void
 SqlTrack::setCachedLyrics( const QString &lyrics )
 {
-    QString query = QString( "SELECT count(*) FROM lyrics WHERE url = %1").arg( m_urlId );
+    QString query = QStringLiteral( "SELECT count(*) FROM lyrics WHERE url = %1").arg( m_urlId );
     const QStringList queryResult = m_collection->sqlStorage()->query( query );
     if( queryResult.isEmpty() )
         return;  // error in the query?
 
     if( queryResult.first().toInt() == 0 )
     {
-        QString insert = QString( "INSERT INTO lyrics( url, lyrics ) VALUES ( %1, '%2' )" )
+        QString insert = QStringLiteral( "INSERT INTO lyrics( url, lyrics ) VALUES ( %1, '%2' )" )
                             .arg( QString::number( m_urlId ),
                                   m_collection->sqlStorage()->escape( lyrics ) );
-        m_collection->sqlStorage()->insert( insert, "lyrics" );
+        m_collection->sqlStorage()->insert( insert, QStringLiteral("lyrics") );
     }
     else
     {
-        QString update = QString( "UPDATE lyrics SET lyrics = '%1' WHERE url = %2" )
+        QString update = QStringLiteral( "UPDATE lyrics SET lyrics = '%1' WHERE url = %2" )
                             .arg( m_collection->sqlStorage()->escape( lyrics ),
                                   QString::number( m_urlId ) );
         m_collection->sqlStorage()->query( update );
@@ -1252,12 +1251,12 @@ SqlTrack::addLabel( const Meta::LabelPtr &label )
             return;
         }
 
-        QString countQuery = "SELECT COUNT(*) FROM urls_labels WHERE url = %1 AND label = %2;";
+        QString countQuery = QStringLiteral("SELECT COUNT(*) FROM urls_labels WHERE url = %1 AND label = %2;");
         QStringList countRs = m_collection->sqlStorage()->query( countQuery.arg( QString::number( m_urlId ), QString::number( sqlLabel->id() ) ) );
         if( !countRs.isEmpty() && countRs.first().toInt() == 0 )
         {
-            QString insert = "INSERT INTO urls_labels(url,label) VALUES (%1,%2);";
-            m_collection->sqlStorage()->insert( insert.arg( QString::number( m_urlId ), QString::number( sqlLabel->id() ) ), "urls_labels" );
+            QString insert = QStringLiteral("INSERT INTO urls_labels(url,label) VALUES (%1,%2);");
+            m_collection->sqlStorage()->insert( insert.arg( QString::number( m_urlId ), QString::number( sqlLabel->id() ) ), QStringLiteral("urls_labels") );
 
             if( m_labelsInCache )
             {
@@ -1295,7 +1294,7 @@ SqlTrack::removeLabel( const Meta::LabelPtr &label )
     }
     if( sqlLabel )
     {
-        QString query = "DELETE FROM urls_labels WHERE label = %2 and url = (SELECT url FROM tracks WHERE id = %1);";
+        QString query = QStringLiteral("DELETE FROM urls_labels WHERE label = %2 and url = (SELECT url FROM tracks WHERE id = %1);");
         m_collection->sqlStorage()->query( query.arg( QString::number( m_trackId ), QString::number( sqlLabel->id() ) ) );
         if( m_labelsInCache )
         {
@@ -1457,7 +1456,7 @@ SqlArtist::createCapabilityInterface( Capabilities::Capability::Type type )
 
 
 //--------------- class Album ---------------------------------
-const QString SqlAlbum::AMAROK_UNSET_MAGIC = QString( "AMAROK_UNSET_MAGIC" );
+const QString SqlAlbum::AMAROK_UNSET_MAGIC = QStringLiteral( "AMAROK_UNSET_MAGIC" );
 
 SqlAlbum::SqlAlbum( Collections::SqlCollection *collection, int id, const QString &name, int artist )
     : Album()
@@ -1530,7 +1529,7 @@ SqlAlbum::tracks()
     else
     {
         // Wait for tracks to be loaded
-        forever
+        for(;;)
         {
             QMutexLocker locker( &m_mutex );
             if( m_tracksLoaded == Loaded )
@@ -1684,7 +1683,7 @@ SqlAlbum::setImage( const QImage &image )
     QString path = largeDiskCachePath();
     // make sure not to overwrite existing images
     while( QFile(path).exists() )
-        path += '_'; // not that nice but it shouldn't happen that often.
+        path += QLatin1Char('_'); // not that nice but it shouldn't happen that often.
 
     image.save( path, "JPG", -1 );
     setImage( path );
@@ -1702,7 +1701,7 @@ SqlAlbum::setImage( const QImage &image )
 
         // - set the image for each track
         Meta::TrackList myTracks = tracks();
-        foreach( Meta::TrackPtr metaTrack, myTracks )
+        for( Meta::TrackPtr metaTrack : myTracks )
         {
             // the song needs to be at least one mb big or we won't set an image
             // that means that the new image will increase the file size by less than 2%
@@ -1729,15 +1728,15 @@ SqlAlbum::removeImage()
     // Update the database image path
     // Set the album image to a magic value which will tell Amarok not to fetch it automatically
     const int unsetId = unsetImageId();
-    QString query = "UPDATE albums SET image = %1 WHERE id = %2";
+    QString query = QStringLiteral("UPDATE albums SET image = %1 WHERE id = %2");
     m_collection->sqlStorage()->query( query.arg( QString::number( unsetId ), QString::number( m_id ) ) );
 
     // From here on we check if there are any remaining references to that particular image in the database
     // If there aren't, then we should remove the image path from the database ( and possibly delete the file? )
     // If there are, we need to leave it since other albums will reference this particular image path.
     //
-    query = "SELECT count( albums.id ) FROM albums "
-                    "WHERE albums.image = %1";
+    query = QStringLiteral("SELECT count( albums.id ) FROM albums "
+                    "WHERE albums.image = %1");
     QStringList res = m_collection->sqlStorage()->query( query.arg( QString::number( m_imageId ) ) );
 
     if( !res.isEmpty() )
@@ -1747,25 +1746,25 @@ SqlAlbum::removeImage()
         // If there are no more references to this particular image, then we should clean up
         if( references <= 0 )
         {
-            query = "DELETE FROM images WHERE id = %1";
+            query = QStringLiteral("DELETE FROM images WHERE id = %1");
             m_collection->sqlStorage()->query( query.arg( QString::number( m_imageId ) ) );
 
             // remove the large cover only if it was cached.
-            QDir largeCoverDir( Amarok::saveLocation( "albumcovers/large/" ) );
+            QDir largeCoverDir( Amarok::saveLocation( QStringLiteral("albumcovers/large/") ) );
             if( QFileInfo(m_imagePath).absoluteDir() == largeCoverDir )
                 QFile::remove( m_imagePath );
 
             // remove all cache images
-            QString key = md5sum( QString(), QString(), m_imagePath );
-            QDir        cacheDir( Amarok::saveLocation( "albumcovers/cache/" ) );
+            QString key = QLatin1String( md5sum( QString(), QString(), m_imagePath ) );
+            QDir        cacheDir( Amarok::saveLocation( QStringLiteral("albumcovers/cache/") ) );
             QStringList cacheFilter;
-            cacheFilter << QString( "*@" ) + key;
+            cacheFilter << QStringLiteral( "*@" ) + key;
             QStringList cachedImages = cacheDir.entryList( cacheFilter );
 
-            foreach( const QString &image, cachedImages )
+            for( const QString &image : cachedImages )
             {
                 bool r = QFile::remove( cacheDir.filePath( image ) );
-                debug() << "deleting cached image: " << image << " : " + ( r ? QStringLiteral("ok") : QStringLiteral("fail") );
+                debug() << "deleting cached image: " << image << " : " << ( r ? QStringLiteral("ok") : QStringLiteral("fail") );
             }
 
             CoverCache::invalidateAlbum( this );
@@ -1788,7 +1787,7 @@ SqlAlbum::unsetImageId() const
     if( m_unsetImageId >= 0 )
         return m_unsetImageId;
 
-    QString query = "SELECT id FROM images WHERE path = '%1'";
+    QString query = QStringLiteral("SELECT id FROM images WHERE path = '%1'");
     QStringList res = m_collection->sqlStorage()->query( query.arg( AMAROK_UNSET_MAGIC ) );
 
     // We already have the AMAROK_UNSET_MAGIC variable in the database
@@ -1799,9 +1798,9 @@ SqlAlbum::unsetImageId() const
     else
     {
         // We need to create this value
-        query = QString( "INSERT INTO images( path ) VALUES ( '%1' )" )
+        query = QStringLiteral( "INSERT INTO images( path ) VALUES ( '%1' )" )
                          .arg( m_collection->sqlStorage()->escape( AMAROK_UNSET_MAGIC ) );
-        m_unsetImageId = m_collection->sqlStorage()->insert( query, "images" );
+        m_unsetImageId = m_collection->sqlStorage()->insert( query, QStringLiteral("images") );
     }
     return m_unsetImageId;
 }
@@ -1833,9 +1832,9 @@ QByteArray
 SqlAlbum::md5sum( const QString& artist, const QString& album, const QString& file ) const
 {
     // FIXME: All existing image stores have been invalidated.
-    return QCryptographicHash::hash( artist.toLower().toUtf8() + QByteArray( "#" ) +
+    return QCryptographicHash::hash( QByteArray( artist.toLower().toUtf8() + QByteArray( "#" ) +
                                      album.toLower().toUtf8() + QByteArray( "?" ) +
-                                     file.toUtf8(),
+                                     file.toUtf8() ),
                                      QCryptographicHash::Md5
     ).toHex();
 }
@@ -1848,8 +1847,8 @@ SqlAlbum::largeDiskCachePath() const
     if( artist.isEmpty() && m_name.isEmpty() )
         return QString();
 
-    QDir largeCoverDir( Amarok::saveLocation( "albumcovers/large/" ) );
-    const QString key = md5sum( artist, m_name, QString() );
+    QDir largeCoverDir( Amarok::saveLocation( QStringLiteral("albumcovers/large/") ) );
+    const QString key = QLatin1String( md5sum( artist, m_name, QString() ) );
 
     if( !key.isEmpty() )
         return largeCoverDir.filePath( key );
@@ -1860,9 +1859,9 @@ SqlAlbum::largeDiskCachePath() const
 QString
 SqlAlbum::scaledDiskCachePath( int size ) const
 {
-    const QByteArray widthKey = QByteArray::number( size ) + '@';
-    QDir cacheCoverDir( Amarok::saveLocation( "albumcovers/cache/" ) );
-    QString key = md5sum( QString(), QString(), m_imagePath );
+    const QString widthKey = QString::number( size ) + QLatin1Char('@');
+    QDir cacheCoverDir( Amarok::saveLocation( QStringLiteral("albumcovers/cache/") ) );
+    QString key = QLatin1String( md5sum( QString(), QString(), m_imagePath ) );
 
     if( !cacheCoverDir.exists( widthKey + key ) )
     {
@@ -1876,11 +1875,11 @@ SqlAlbum::scaledDiskCachePath( int size ) const
         else
         {
             QString oldKey;
-            oldKey = md5sum( artist, m_name, m_imagePath );
+            oldKey = QLatin1String( md5sum( artist, m_name, m_imagePath ) );
             if( cacheCoverDir.exists( widthKey + oldKey ) )
                 cacheCoverDir.remove( widthKey + oldKey );
 
-            oldKey = md5sum( artist, m_name, QString() );
+            oldKey = QLatin1String( md5sum( artist, m_name, QString() ) );
             if( cacheCoverDir.exists( widthKey + oldKey ) )
                 cacheCoverDir.remove( widthKey + oldKey );
         }
@@ -1896,7 +1895,7 @@ SqlAlbum::largeImagePath()
         return m_imagePath;
 
     // Look up in the database
-    QString query = "SELECT images.id, images.path FROM images, albums WHERE albums.image = images.id AND albums.id = %1;"; // TODO: shouldn't we do a JOIN here?
+    QString query = QStringLiteral("SELECT images.id, images.path FROM images, albums WHERE albums.image = images.id AND albums.id = %1;"); // TODO: shouldn't we do a JOIN here?
     QStringList res = m_collection->sqlStorage()->query( query.arg( m_id ) );
     if( !res.isEmpty() )
     {
@@ -1910,7 +1909,7 @@ SqlAlbum::largeImagePath()
         // embedded image (e.g. id3v2 APIC
         // We store embedded images as unique ids in the database
         // we will get the real image later on from the track.
-        if( m_imagePath.startsWith( m_collection->uidUrlProtocol()+"://" ) )
+        if( m_imagePath.startsWith( m_collection->uidUrlProtocol()+QStringLiteral("://") ) )
             return m_imagePath;
 
         // normal file
@@ -1943,15 +1942,15 @@ SqlAlbum::setImage( const QString &path )
     if( m_imagePath == path )
         return;
 
-    QString query = "SELECT id FROM images WHERE path = '%1'";
+    QString query = QStringLiteral("SELECT id FROM images WHERE path = '%1'");
     query = query.arg( m_collection->sqlStorage()->escape( path ) );
     QStringList res = m_collection->sqlStorage()->query( query );
 
     if( res.isEmpty() )
     {
-        QString insert = QString( "INSERT INTO images( path ) VALUES ( '%1' )" )
+        QString insert = QStringLiteral( "INSERT INTO images( path ) VALUES ( '%1' )" )
         .arg( m_collection->sqlStorage()->escape( path ) );
-        m_imageId = m_collection->sqlStorage()->insert( insert, "images" );
+        m_imageId = m_collection->sqlStorage()->insert( insert, QStringLiteral("images") );
     }
     else
         m_imageId = res.first().toInt();
@@ -2001,7 +2000,7 @@ SqlAlbum::setCompilation( bool compilation )
             changes.insert( Meta::valCompilation, 1);
 
             Meta::TrackList myTracks = tracks();
-            foreach( Meta::TrackPtr metaTrack, myTracks )
+            for( Meta::TrackPtr metaTrack : myTracks )
             {
                 SqlTrack* sqlTrack = static_cast<SqlTrack*>(metaTrack.data());
 
@@ -2023,7 +2022,7 @@ SqlAlbum::setCompilation( bool compilation )
             changes.insert( Meta::valCompilation, 0);
 
             Meta::TrackList myTracks = tracks();
-            foreach( Meta::TrackPtr metaTrack, myTracks )
+            for( Meta::TrackPtr metaTrack : myTracks )
             {
                 SqlTrack* sqlTrack = static_cast<SqlTrack*>(metaTrack.data());
                 Meta::ArtistPtr trackArtist = sqlTrack->artist();
