@@ -27,9 +27,7 @@
 #include <QTimer>
 #include <QList>
 
-class SqlStorage;
 
-class TestScanResultProcessorFull;
 class TestSqlAlbum;
 class TestSqlArtist;
 class TestSqlTrack;
@@ -80,11 +78,12 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlRegistry : public QObject
     Q_OBJECT
 
     public:
-        SqlRegistry(Collections::SqlCollection *collection);
-        virtual ~SqlRegistry();
+        explicit SqlRegistry(Collections::SqlCollection *collection);
+        ~SqlRegistry() override;
 
         /** Searches a directory entry in the scanned directories
             This function searches an existing directory entry.
+            @param path the directory path
             @param mtime if mtime is != 0 then the mtime of the entry is updated
             @returns the directory id
          */
@@ -133,7 +132,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlRegistry : public QObject
         /** Unblocks one blockDatabaseUpdate call. */
         void unblockDatabaseUpdate();
 
-    private slots:
+    private Q_SLOTS:
         /** empytCache clears up the different hash tables by unrefing all pointers that are no longer ref'd by anyone else.
             SqlRegistry is calling this function periodically.
             This is no free ticket for modifying the database directly as
@@ -148,7 +147,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlRegistry : public QObject
         /** Updates the uid of an already cached track.
             @return true if the update was successful.
         */
-        bool updateCachedUrl( const QString &oldUrl, const QString &newUrl );
+        bool updateCachedUrl( const QString &oldPath, const QString &newPath );
 
         /** Updates the uid of an already cached track.
             @return true if the update was successful.
@@ -161,7 +160,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlRegistry : public QObject
          * is normally called by SqlTrack. Do not call directly unless you know what you
          * do.
          */
-        void removeTrack( int urlId, const QString uid );
+        void removeTrack( int urlId, const QString &uid );
 
         // --- functions needed to commit a track
 
