@@ -28,7 +28,6 @@
 #include "collectionscanner/Playlist.h"
 #include "core/support/Debug.h"
 #include "core-impl/collections/db/MountPointManager.h"
-#include "core-impl/collections/db/sql/SqlQueryMaker.h"
 #include "playlistmanager/PlaylistManager.h"
 
 #include <KMessageBox>
@@ -81,7 +80,7 @@ SqlScanResultProcessor::scanSucceeded()
 void
 SqlScanResultProcessor::displayMessages()
 {
-    QString errorList = m_messages.join( "</li><li>" ).replace( '\n', "<br>" );
+    QString errorList = m_messages.join( QStringLiteral("</li><li>") ).replace( QLatin1Char('\n'), QStringLiteral("<br>") );
     QString text = i18n( "<ul><li>%1</li></ul>"
                          "In most cases this means that not all of your tracks were imported.<br>"
                          "See <a href='http://userbase.kde.org/Amarok/Manual/Various/TroubleshootingAndCommonProblems#Duplicate_Tracks'>"
@@ -155,7 +154,7 @@ SqlScanResultProcessor::commitAlbum( CollectionScanner::Album *album )
     m_albumIds.insert( album, metaAlbum->id() );
 
     // --- add all tracks
-    foreach( CollectionScanner::Track *track, album->tracks() )
+    for( CollectionScanner::Track *track : album->tracks() )
         commitTrack( track, album );
 
     // --- set the cover if we have one
@@ -197,7 +196,7 @@ SqlScanResultProcessor::commitTrack( CollectionScanner::Track *track,
     {
         warning() << "commitTrack(): got track with empty unique id from the scanner,"
                   << "not adding it";
-        m_messages.append( QString( "Not adding track %1 because it has no unique id." ).
+        m_messages.append( QStringLiteral( "Not adding track %1 because it has no unique id." ).
                              arg(track->path()) );
         return;
     }
@@ -209,11 +208,10 @@ SqlScanResultProcessor::commitTrack( CollectionScanner::Track *track,
     if( m_foundTracks.contains( uid ) )
     {
         const UrlEntry old = m_urlsCache.value( m_uidCache.value( uid ) );
-        const char *pattern = I18N_NOOP( "Duplicates found, the second file will be ignored:\n%1\n%2" );
 
         // we want translated version for GUI and non-translated for debug log
-        warning() << "commitTrack():" << QString( pattern ).arg( old.path, track->path() );
-        m_messages.append( i18n( pattern, old.path, track->path() ) );
+        warning() << "commitTrack():" << QLatin1String( "Duplicates found, the second file will be ignored:\n%1\n%2" ).arg( old.path, track->path() );
+        m_messages.append( i18n( "Duplicates found, the second file will be ignored:\n%1\n%2", old.path, track->path() ) );
         return;
     }
 
@@ -259,7 +257,7 @@ SqlScanResultProcessor::commitTrack( CollectionScanner::Track *track,
 
     if( !metaTrack )
     {
-        QString text = QString( "Something went wrong when importing track %1, metaTrack "
+        QString text = QStringLiteral( "Something went wrong when importing track %1, metaTrack "
                 "is null while it shouldn't be." ).arg( track->path() );
         warning() << "commitTrack():" << text.toLocal8Bit().data();
         m_messages.append( text );
@@ -384,7 +382,7 @@ SqlScanResultProcessor::deleteDeletedDirectories()
     }
 
     // -- check if the have been found during the scan
-    foreach( const DirectoryEntry &e, toCheck )
+    for( const DirectoryEntry &e : toCheck )
     {
         /* we need to match directories by their (absolute) path, otherwise following
          * scenario triggers statistics loss (bug 298275):
@@ -415,7 +413,7 @@ SqlScanResultProcessor::deleteDeletedDirectories()
         if( deleteThisDir )
         {
             deleteDeletedTracks( e.dirId );
-            QString query = QString( "DELETE FROM directories WHERE id = %1;" ).arg( e.dirId );
+            QString query = QStringLiteral( "DELETE FROM directories WHERE id = %1;" ).arg( e.dirId );
             storage->query( query );
         }
     }
@@ -439,7 +437,7 @@ SqlScanResultProcessor::deleteDeletedTracks( int directoryId )
     QList<int> urlIds = m_directoryCache.values( directoryId );
 
     // -- check if the tracks have been found during the scan
-    foreach( int urlId, urlIds )
+    for( int urlId : urlIds )
     {
         Q_ASSERT( m_urlsCache.contains( urlId ) );
         const UrlEntry &entry = m_urlsCache[ urlId ];
@@ -462,7 +460,7 @@ SqlScanResultProcessor::findBestUrlId( const QString &uid, const QString &path )
     if( urlIds.size() == 1 )
         return urlIds.at( 0 ); // normal operation
 
-    foreach( int testedUrlId, urlIds )
+    for( int testedUrlId : urlIds )
     {
         Q_ASSERT( m_urlsCache.contains( testedUrlId ) );
         if( m_urlsCache[ testedUrlId ].path == path )
@@ -488,7 +486,7 @@ SqlScanResultProcessor::relocateTracksToNewDirectory( int oldDirId, int newDirId
 
     // sanity checking, not strictly needed, but imagine new device appearing in the
     // middle of the scan, so rather prevent db corruption:
-    QStringList res = storage->query( QString( "SELECT deviceid FROM directories "
+    QStringList res = storage->query( QStringLiteral( "SELECT deviceid FROM directories "
                                                "WHERE id = %1" ).arg( newDirId ) );
     if( res.count() != 1 )
     {
@@ -498,7 +496,7 @@ SqlScanResultProcessor::relocateTracksToNewDirectory( int oldDirId, int newDirId
     }
     int newDirDeviceId = res.at( 0 ).toInt();
 
-    foreach( int urlId, urlIds )
+    for( int urlId : urlIds )
     {
         Q_ASSERT( m_urlsCache.contains( urlId ) );
         UrlEntry entry = m_urlsCache.value( urlId );
@@ -546,15 +544,15 @@ SqlScanResultProcessor::mountedDirectories() const
     // -- get a list of all mounted device ids
     QList<int> idList = m_collection->mountPointManager()->getMountedDeviceIds();
     QString deviceIds;
-    foreach( int id, idList )
+    for( int id : idList )
     {
         if ( !deviceIds.isEmpty() )
-            deviceIds += ',';
+            deviceIds += QLatin1Char(',');
         deviceIds += QString::number( id );
     }
 
     // -- get all (mounted) directories
-    QString query = QString( "SELECT id, deviceid, dir FROM directories "
+    QString query = QStringLiteral( "SELECT id, deviceid, dir FROM directories "
                              "WHERE deviceid IN (%1)" ).arg( deviceIds );
     QStringList res = storage->query( query );
 
@@ -577,9 +575,9 @@ SqlScanResultProcessor::deletedDirectories() const
     auto storage = m_collection->sqlStorage();
 
     QHash<int, DirectoryEntry> idToDirEntryMap; // for faster processing during filtering
-    foreach( int directoryId, m_scannedDirectoryIds )
+    for( int directoryId : m_scannedDirectoryIds )
     {
-        QString query = QString( "SELECT deviceid, dir FROM directories WHERE id = %1" )
+        QString query = QStringLiteral( "SELECT deviceid, dir FROM directories WHERE id = %1" )
                 .arg( directoryId );
         QStringList res = storage->query( query );
         if( res.count() != 2 )
@@ -591,7 +589,7 @@ SqlScanResultProcessor::deletedDirectories() const
         int deviceId = res.at( 0 ).toInt();
         QString dir = res.at( 1 );
         // select all child directories
-        query = QString( "SELECT id, deviceid, dir FROM directories WHERE deviceid = %1 "
+        query = QStringLiteral( "SELECT id, deviceid, dir FROM directories WHERE deviceid = %1 "
                 "AND dir LIKE '%2/%'" ).arg( deviceId ).arg( storage->escape( dir ) );
         res = storage->query( query );
         for( int i = 0; i < res.count(); )
@@ -607,7 +605,7 @@ SqlScanResultProcessor::deletedDirectories() const
     // now we must filter out all found directories *and their children*, because the
     // children are *not* in m_foundDirectories and deleteDeletedDirectories() would
     // remove them erroneously
-    foreach( int foundDirectoryId, m_foundDirectories )
+    for( int foundDirectoryId : m_foundDirectories )
     {
         if( idToDirEntryMap.contains( foundDirectoryId ) )
         {
@@ -619,7 +617,8 @@ SqlScanResultProcessor::deletedDirectories() const
             QMutableHashIterator<int, DirectoryEntry> it( idToDirEntryMap );
             while( it.hasNext() )
             {
-                const DirectoryEntry &e = it.next().value();
+                it.next();
+                const DirectoryEntry &e = it.value();
                 if( e.deviceId == existingDeviceId && e.dir.startsWith( existingPath ) )
                     it.remove();
             }
