@@ -153,7 +153,7 @@ Track::setTitle( const QString &newTitle )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->title );
-    m_track->title = g_strdup( newTitle.toUtf8() );
+    m_track->title = g_strdup( newTitle.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valTitle, newTitle );
 }
 
@@ -183,7 +183,7 @@ Track::prettyUrl() const
     QString artistName = artist() ? artist()->prettyName() : i18n( "Unknown Artist" );
     QString trackName = !name().isEmpty() ? name() : i18n( "Unknown track" );
 
-    return  QString( "%1: %2 - %3" ).arg( collName, artistName, trackName );
+    return QStringLiteral( "%1: %2 - %3" ).arg( collName, artistName, trackName );
 }
 
 QString
@@ -221,7 +221,7 @@ Track::setAlbum( const QString &newAlbum )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->album );
-    m_track->album = g_strdup( newAlbum.toUtf8() );
+    m_track->album = g_strdup( newAlbum.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valAlbum, newAlbum );
 }
 
@@ -230,7 +230,7 @@ Track::setAlbumArtist( const QString &newAlbumArtist )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->albumartist );
-    m_track->albumartist = g_strdup( newAlbumArtist.toUtf8() );
+    m_track->albumartist = g_strdup( newAlbumArtist.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valAlbumArtist, newAlbumArtist );
 }
 
@@ -267,14 +267,14 @@ Track::setImage( const QImage &newImage )
 
         QTemporaryFile tempImageFile;
         tempImageFile.setAutoRemove( false ); // file will be removed in ~Track()
-        tempImageFile.setFileTemplate( QDir::tempPath() + "/XXXXXX.png" );
+        tempImageFile.setFileTemplate( QDir::tempPath() + QStringLiteral("/XXXXXX.png") );
         // we save the file to disk rather than pass image data to save several megabytes of RAM
         if( tempImageFile.open() )
             m_tempImageFilePath = tempImageFile.fileName();
         if( tempImageFile.isOpen() && image.save( &tempImageFile, "PNG" ) )
             /* this function remembers image path, it also forgets previous images (if any)
              * and sets artwork_size, artwork_count and has_artwork m_track fields */
-            itdb_track_set_thumbnails( m_track, QFile::encodeName( m_tempImageFilePath ) );
+            itdb_track_set_thumbnails( m_track, QFile::encodeName( m_tempImageFilePath ).constData() );
     }
     commitIfInNonBatchUpdate( Meta::valImage, newImage );
 }
@@ -291,7 +291,7 @@ Track::setArtist( const QString &newArtist )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->artist );
-    m_track->artist = g_strdup( newArtist.toUtf8() );
+    m_track->artist = g_strdup( newArtist.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valArtist, newArtist );
 }
 
@@ -307,7 +307,7 @@ Track::setComposer( const QString &newComposer )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->composer );
-    m_track->composer = g_strdup( newComposer.toUtf8() );
+    m_track->composer = g_strdup( newComposer.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valComposer, newComposer );
 }
 
@@ -323,7 +323,7 @@ Track::setGenre( const QString &newGenre )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->genre );
-    m_track->genre = g_strdup( newGenre.toUtf8() );
+    m_track->genre = g_strdup( newGenre.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valGenre, newGenre );
 }
 
@@ -366,7 +366,7 @@ void Track::setComment( const QString &newComment )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->comment );
-    m_track->comment = g_strdup( newComment.toUtf8() );
+    m_track->comment = g_strdup( newComment.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valComment, newComment );
 }
 
@@ -611,7 +611,7 @@ Track::setType( const QString &newType )
 {
     QWriteLocker locker( &m_trackLock );
     g_free( m_track->filetype );
-    m_track->filetype = g_strdup( newType.toUtf8() );
+    m_track->filetype = g_strdup( newType.toUtf8().constData() );
     commitIfInNonBatchUpdate( Meta::valFormat, newType );
 }
 
