@@ -22,6 +22,7 @@
 #include "core/meta/Statistics.h"
 #include "core/meta/TrackEditor.h"
 
+#include <QPointer>
 #include <QReadWriteLock>
 
 #include <glib.h>
@@ -33,7 +34,7 @@ class IpodCollection;
 namespace IpodMeta
 {
     /**
-     * An iPod track. album, artist, composer etc. are invisible to ouside world, they are
+     * An iPod track. album, artist, composer etc. are invisible to outside world, they are
      * proxied in the MemoMeta track. All methods in this class are thread-safe with a few
      * exceptions that are noted in relevant method docstrings.
      */
@@ -42,7 +43,7 @@ namespace IpodMeta
         public:
             /**
              * Constructs an iPod track from an existing libgpod track structure. Caller
-             * must guarantee that these are already added to the collection's itdb databse.
+             * must guarantee that these are already added to the collection's itdb database.
              */
             explicit Track( Itdb_Track *ipodTrack );
 
@@ -54,73 +55,73 @@ namespace IpodMeta
             virtual ~Track();
 
             // Meta::Base methods:
-            virtual QString name() const;
+            QString name() const override;
 
             // Meta::Track methods:
-            virtual KUrl playableUrl() const;
-            virtual QString prettyUrl() const;
-            virtual QString uidUrl() const;
-            virtual QString notPlayableReason() const;
+            QUrl playableUrl() const override;
+            QString prettyUrl() const override;
+            QString uidUrl() const override;
+            QString notPlayableReason() const override;
 
-            virtual Meta::AlbumPtr album() const;
-            virtual Meta::ArtistPtr artist() const;
-            virtual Meta::ComposerPtr composer() const;
-            virtual Meta::GenrePtr genre() const;
-            virtual Meta::YearPtr year() const;
+            Meta::AlbumPtr album() const override;
+            Meta::ArtistPtr artist() const override;
+            Meta::ComposerPtr composer() const override;
+            Meta::GenrePtr genre() const override;
+            Meta::YearPtr year() const override;
 
-            virtual qreal bpm() const;
-            virtual QString comment() const;
+            qreal bpm() const override;
+            QString comment() const override;
 
-            virtual qint64 length() const;
-            virtual int filesize() const;
-            virtual int sampleRate() const;
-            virtual int bitrate() const;
+            qint64 length() const override;
+            int filesize() const override;
+            int sampleRate() const override;
+            int bitrate() const override;
 
-            virtual QDateTime createDate() const;
-            virtual QDateTime modifyDate() const;
+            QDateTime createDate() const override;
+            QDateTime modifyDate() const override;
 
-            virtual int trackNumber() const;
-            virtual int discNumber() const;
+            int trackNumber() const override;
+            int discNumber() const override;
 
-            virtual qreal replayGain( Meta::ReplayGainTag mode ) const;
-            virtual QString type() const;
+            qreal replayGain( Meta::ReplayGainTag mode ) const override;
+            QString type() const override;
 
-            virtual bool inCollection() const;
-            virtual Collections::Collection* collection() const;
+            bool inCollection() const override;
+            Collections::Collection* collection() const override;
 
-            virtual Meta::TrackEditorPtr editor();
-            virtual Meta::StatisticsPtr statistics();
+            Meta::TrackEditorPtr editor() override;
+            Meta::StatisticsPtr statistics() override;
 
             // Meta::TrackEditor methods:
-            virtual void setAlbum( const QString &newAlbum );
-            virtual void setAlbumArtist( const QString &newAlbumArtist );
-            virtual void setArtist( const QString &newArtist );
-            virtual void setComposer( const QString &newComposer );
-            virtual void setGenre( const QString &newGenre );
-            virtual void setYear( int newYear );
-            virtual void setTitle( const QString &newTitle );
-            virtual void setComment( const QString &newComment );
-            virtual void setTrackNumber( int newTrackNumber );
-            virtual void setDiscNumber( int newDiscNumber );
-            virtual void setBpm( const qreal newBpm );
+            void setAlbum( const QString &newAlbum ) override;
+            void setAlbumArtist( const QString &newAlbumArtist ) override;
+            void setArtist( const QString &newArtist ) override;
+            void setComposer( const QString &newComposer ) override;
+            void setGenre( const QString &newGenre ) override;
+            void setYear( int newYear ) override;
+            void setTitle( const QString &newTitle ) override;
+            void setComment( const QString &newComment ) override;
+            void setTrackNumber( int newTrackNumber ) override;
+            void setDiscNumber( int newDiscNumber ) override;
+            void setBpm( const qreal newBpm ) override;
 
             // Meta::Statistics methods:
-            virtual int rating() const;
-            virtual void setRating( int newRating );
+            int rating() const override;
+            void setRating( int newRating ) override;
 
-            virtual QDateTime lastPlayed() const;
-            virtual void setLastPlayed( const QDateTime &time );
+            QDateTime lastPlayed() const override;
+            void setLastPlayed( const QDateTime &time ) override;
 
-            virtual QDateTime firstPlayed() const;
-            virtual void setFirstPlayed( const QDateTime &time );
+            QDateTime firstPlayed() const override;
+            void setFirstPlayed( const QDateTime &time ) override;
 
-            virtual int playCount() const;
-            virtual int recentPlayCount() const;
-            virtual void setPlayCount( const int playcount );
+            int playCount() const override;
+            int recentPlayCount() const override;
+            void setPlayCount( const int playcount ) override;
 
             // Combined Meta::TrackEditor, Meta::Statistics methods:
-            virtual void beginUpdate();
-            virtual void endUpdate();
+            void beginUpdate() override;
+            void endUpdate() override;
 
             // IpodMeta::Track methods:
             /**
@@ -145,7 +146,7 @@ namespace IpodMeta
              * @param mountPoint a path where iPod is mounted, e.g. /media/MyiPod in local
              * encoding (use QFile::encodeName())
              * @param filePath full absolute path to copied file, must be in form
-             * <@param mountPoint>/iPod_Control/Music/... - it is recommended to use
+             * <@p mountPoint>/iPod_Control/Music/... - it is recommended to use
              * itdb_cp_get_dest_filename() to construct the filename
              *
              * @return true if the track was "accepted", false if not in which case you
@@ -157,7 +158,7 @@ namespace IpodMeta
              * Set collection this track belongs to. If collection is not null, (re)set
              * the mount point stored in track. (affects playableUrl())
              */
-            void setCollection( QWeakPointer<IpodCollection> collection );
+            void setCollection( QPointer<IpodCollection> collection );
 
             // Methods for copy constructor:
             void setIsCompilation( bool newIsCompilation );
@@ -187,7 +188,7 @@ namespace IpodMeta
              * IpodCollection's memory management is out of our control, therefore the
              * weak pointer.
              */
-            QWeakPointer<IpodCollection> m_coll;
+            QPointer<IpodCollection> m_coll;
 
             /**
              * While mount point is accessible through m_track->itdb-> ..., we want to
@@ -239,11 +240,11 @@ namespace IpodMeta
     class Artist : public Meta::Artist
     {
         public:
-            Artist( const QString &name ) : m_name( name ) {}
+            explicit Artist( const QString &name ) : m_name( name ) {}
             virtual ~Artist() {}
 
-            virtual QString name() const { return m_name; }
-            virtual Meta::TrackList tracks() { return Meta::TrackList(); }
+            QString name() const override { return m_name; }
+            Meta::TrackList tracks() override { return Meta::TrackList(); }
 
         private:
             QString m_name;
@@ -256,27 +257,27 @@ namespace IpodMeta
     class Album : public Meta::Album
     {
         public:
-            Album( Track *track );
+            explicit Album( Track *track );
 
-            virtual QString name() const;
+            QString name() const override;
             // dummy, iPod tracks are supposed to be proxied by MemoryMeta which handles this
-            virtual Meta::TrackList tracks() { return Meta::TrackList(); }
+            Meta::TrackList tracks() override { return Meta::TrackList(); }
 
-            virtual bool isCompilation() const;
-            virtual bool canUpdateCompilation() const;
-            virtual void setCompilation( bool isCompilation );
+            bool isCompilation() const override;
+            bool canUpdateCompilation() const override;
+            void setCompilation( bool isCompilation ) override;
 
-            virtual bool hasAlbumArtist() const;
-            virtual Meta::ArtistPtr albumArtist() const;
+            bool hasAlbumArtist() const override;
+            Meta::ArtistPtr albumArtist() const override;
 
-            virtual bool hasImage( int size = 0 ) const;
-            virtual QImage image( int size = 0 ) const;
-            virtual bool canUpdateImage() const;
-            virtual void setImage( const QImage &image );
-            virtual void removeImage();
+            bool hasImage( int size = 0 ) const override;
+            QImage image( int size = 0 ) const override;
+            bool canUpdateImage() const override;
+            void setImage( const QImage &image ) override;
+            void removeImage() override;
 
         private:
-            KSharedPtr<Track> m_track;
+            AmarokSharedPointer<Track> m_track;
     };
 
     /**
@@ -286,11 +287,11 @@ namespace IpodMeta
     class Composer : public Meta::Composer
     {
         public:
-            Composer( const QString &name ) : m_name( name ) {}
+            explicit Composer( const QString &name ) : m_name( name ) {}
             virtual ~Composer() {}
 
-            virtual QString name() const { return m_name; }
-            virtual Meta::TrackList tracks() { return Meta::TrackList(); }
+            QString name() const override { return m_name; }
+            Meta::TrackList tracks() override { return Meta::TrackList(); }
 
         private:
             QString m_name;
@@ -303,11 +304,11 @@ namespace IpodMeta
     class Genre : public Meta::Genre
     {
         public:
-            Genre( const QString &name ) : m_name( name ) {}
+            explicit Genre( const QString &name ) : m_name( name ) {}
             virtual ~Genre() {}
 
-            virtual QString name() const { return m_name; }
-            virtual Meta::TrackList tracks() { return Meta::TrackList(); }
+            QString name() const override { return m_name; }
+            Meta::TrackList tracks() override { return Meta::TrackList(); }
 
         private:
             QString m_name;
@@ -320,11 +321,11 @@ namespace IpodMeta
     class Year : public Meta::Year
     {
         public:
-            Year( const QString &name ) : m_name( name ) {}
+            explicit Year( const QString &name ) : m_name( name ) {}
             virtual ~Year() {}
 
-            virtual QString name() const { return m_name; }
-            virtual Meta::TrackList tracks() { return Meta::TrackList(); }
+            QString name() const override { return m_name; }
+            Meta::TrackList tracks() override { return Meta::TrackList(); }
 
         private:
             QString m_name;
