@@ -20,8 +20,9 @@
 #include "core-impl/playlists/providers/user/UserPlaylistProvider.h"
 #include "MediaDevicePlaylist.h"
 
-#include <klocale.h>
-#include <kicon.h>
+#include <QIcon>
+
+#include <KLocalizedString>
 
 namespace Collections {
     class MediaDeviceCollection;
@@ -33,32 +34,32 @@ class AMAROK_EXPORT MediaDeviceUserPlaylistProvider : public Playlists::UserPlay
 {
     Q_OBJECT
     public:
-        MediaDeviceUserPlaylistProvider( Collections::MediaDeviceCollection *collection );
-        ~MediaDeviceUserPlaylistProvider();
+        explicit MediaDeviceUserPlaylistProvider( Collections::MediaDeviceCollection *collection );
+        ~MediaDeviceUserPlaylistProvider() override;
 
         /* PlaylistProvider functions */
-        virtual QString prettyName() const { return i18n( "Media Device playlists" ); };
-        virtual KIcon icon() const { return KIcon( "multimedia-player" ); }
+        QString prettyName() const override { return i18n( "Media Device playlists" ); }
+        QIcon icon() const override { return QIcon::fromTheme( QStringLiteral("multimedia-player") ); }
 
         /* Playlists::UserPlaylistProvider functions */
-        virtual Playlists::PlaylistList playlists();
+        Playlists::PlaylistList playlists() override;
 
         virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks );
-        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks, const QString& name );
+        Playlists::PlaylistPtr save( const Meta::TrackList &tracks, const QString& name ) override;
 
-        virtual bool isWritable() { return true; }
-        virtual void renamePlaylist( Playlists::PlaylistPtr playlist, const QString &newName );
-        virtual bool deletePlaylists( const Playlists::PlaylistList &playlistlist );
+        bool isWritable() override { return true; }
+        void renamePlaylist(Playlists::PlaylistPtr playlist, const QString &newName ) override;
+        bool deletePlaylists( const Playlists::PlaylistList &playlistlist ) override;
 
         /// MediaDevice-specific Functions
 
         void addMediaDevicePlaylist( Playlists::MediaDevicePlaylistPtr &playlist );
         void removePlaylist( Playlists::MediaDevicePlaylistPtr &playlist );
 
-        public slots:
-            void sendUpdated() { emit updated(); }
+        public Q_SLOTS:
+            void sendUpdated() { Q_EMIT updated(); }
 
-        signals:
+        Q_SIGNALS:
             void playlistSaved( const Playlists::MediaDevicePlaylistPtr &playlist, const QString &name );
             void playlistRenamed( const Playlists::MediaDevicePlaylistPtr &playlist );
             void playlistsDeleted( const Playlists::MediaDevicePlaylistList &playlistlist );
