@@ -46,54 +46,54 @@ class AMAROK_EXPORT TrackCounter : public CustomReturnFunction
 {
     public:
         TrackCounter();
-        virtual ~TrackCounter();
+        ~TrackCounter() override;
 
-        virtual QString value( const Meta::TrackList &tracks ) const;
+        QString value( const Meta::TrackList &tracks ) const override;
 };
 
 class AMAROK_EXPORT ArtistCounter : public CustomReturnFunction
 {
     public:
         ArtistCounter();
-        virtual ~ArtistCounter();
+        ~ArtistCounter() override;
 
-        virtual QString value( const Meta::TrackList &tracks ) const;
+        QString value( const Meta::TrackList &tracks ) const override;
 };
 
 class AMAROK_EXPORT GenreCounter : public CustomReturnFunction
 {
     public:
         GenreCounter();
-        virtual ~GenreCounter();
+        ~GenreCounter() override;
 
-        virtual QString value( const Meta::TrackList &tracks ) const;
+        QString value( const Meta::TrackList &tracks ) const override;
 };
 
 class AMAROK_EXPORT ComposerCounter : public CustomReturnFunction
 {
     public:
         ComposerCounter();
-        virtual ~ComposerCounter();
+        ~ComposerCounter() override;
 
-        virtual QString value( const Meta::TrackList &tracks ) const;
+        QString value( const Meta::TrackList &tracks ) const override;
 };
 
 class AMAROK_EXPORT AlbumCounter : public CustomReturnFunction
 {
     public:
         AlbumCounter();
-        virtual ~AlbumCounter();
+        ~AlbumCounter() override;
 
-        virtual QString value( const Meta::TrackList &tracks ) const;
+        QString value( const Meta::TrackList &tracks ) const override;
 };
 
 class AMAROK_EXPORT YearCounter : public CustomReturnFunction
 {
     public:
         YearCounter();
-        virtual ~YearCounter();
+        ~YearCounter() override;
 
-        virtual QString value( const Meta::TrackList &tracks ) const;
+        QString value( const Meta::TrackList &tracks ) const override;
 };
 
 class AMAROK_EXPORT CustomReturnValue
@@ -109,16 +109,16 @@ class AMAROK_EXPORT TitleReturnValue : public CustomReturnValue
 {
     public:
         TitleReturnValue();
-        virtual ~TitleReturnValue();
-        virtual QString value( const Meta::TrackPtr &track ) const;
+        ~TitleReturnValue() override;
+        QString value( const Meta::TrackPtr &track ) const override;
 };
 
 class AMAROK_EXPORT UrlReturnValue : public CustomReturnValue
 {
     public:
         UrlReturnValue();
-        virtual ~UrlReturnValue();
-        virtual QString value( const Meta::TrackPtr &track ) const;
+        ~UrlReturnValue() override;
+        QString value( const Meta::TrackPtr &track ) const override;
 };
 
 
