@@ -123,7 +123,7 @@ AndContainerMemoryFilter::filterMatches( const Meta::TrackPtr &track ) const
     if( m_filters.isEmpty() )
         return false;
 
-    foreach( MemoryFilter *filter, m_filters )
+    for( MemoryFilter *filter : m_filters )
     {
         if( filter && !filter->filterMatches( track ) )
             return false;
@@ -146,7 +146,7 @@ OrContainerMemoryFilter::filterMatches( const Meta::TrackPtr &track ) const
     if( m_filters.isEmpty() )
         return false;
 
-    foreach( MemoryFilter *filter, m_filters )
+    for( const MemoryFilter *filter : m_filters )
     {
         if( filter && filter->filterMatches( track ) )
             return true;
@@ -252,12 +252,12 @@ LabelFilter::LabelFilter( const QString &filter, bool matchBegin, bool matchEnd
 {
     QString pattern;
     if( matchBegin )
-        pattern += '^';
+        pattern += QLatin1Char('^');
     pattern += filter;
     if( matchEnd )
-        pattern += '$';
+        pattern += QLatin1Char('$');
 
-    m_expression = QRegExp( pattern, Qt::CaseInsensitive );
+    m_expression = QRegularExpression( pattern, QRegularExpression::CaseInsensitiveOption );
 }
 
 LabelFilter::~LabelFilter()
@@ -268,9 +268,9 @@ LabelFilter::~LabelFilter()
 bool
 LabelFilter::filterMatches(const Meta::TrackPtr &track ) const
 {
-    foreach( const Meta::LabelPtr &label, track->labels() )
+    for( const auto &label : track->labels() )
     {
-        if( m_expression.indexIn( label->name() ) != -1 )
+        if( label->name().indexOf( m_expression ) != -1 )
             return true;
     }
     return false;
