@@ -101,7 +101,7 @@ Meta::TrackList
 SqlPodcastEpisode::toTrackList( Podcasts::SqlPodcastEpisodeList episodes )
 {
     Meta::TrackList tracks;
-    foreach( SqlPodcastEpisodePtr sqlEpisode, episodes )
+    for( SqlPodcastEpisodePtr sqlEpisode : episodes )
         tracks << Meta::TrackPtr::dynamicCast( sqlEpisode );
 
     return tracks;
@@ -111,7 +111,7 @@ Podcasts::PodcastEpisodeList
 SqlPodcastEpisode::toPodcastEpisodeList( SqlPodcastEpisodeList episodes )
 {
     Podcasts::PodcastEpisodeList sqlEpisodes;
-    foreach( SqlPodcastEpisodePtr sqlEpisode, episodes )
+    for( SqlPodcastEpisodePtr sqlEpisode : episodes )
         sqlEpisodes << Podcasts::PodcastEpisodePtr::dynamicCast( sqlEpisode );
 
     return sqlEpisodes;
@@ -595,7 +595,7 @@ SqlPodcastChannel::SqlPodcastChannel( Podcasts::SqlPodcastProvider *provider,
 
     updateInDb();
 
-    foreach( Podcasts::PodcastEpisodePtr episode, channel->episodes() )
+    for( Podcasts::PodcastEpisodePtr episode : channel->episodes() )
     {
         episode->setChannel( PodcastChannelPtr( this ) );
         SqlPodcastEpisode *sqlEpisode = new SqlPodcastEpisode( episode );
@@ -757,7 +757,8 @@ SqlPodcastChannel::applyPurge()
     {
         int purgeIndex = 0;
 
-        foreach( SqlPodcastEpisodePtr episode, m_episodes )
+        const auto episodes = m_episodes;
+        for( SqlPodcastEpisodePtr episode : episodes )
         {
             if ( !episode->isKeep() )
             {
@@ -854,7 +855,8 @@ void
 SqlPodcastChannel::deleteFromDb()
 {
     auto sqlStorage = StorageManager::instance()->sqlStorage();
-    foreach( SqlPodcastEpisodePtr sqlEpisode, m_episodes )
+    const auto episodes = m_episodes;
+    for( SqlPodcastEpisodePtr sqlEpisode : episodes )
     {
        sqlEpisode->deleteFromDb();
        m_episodes.removeOne( sqlEpisode );
@@ -881,10 +883,10 @@ SqlPodcastChannel::loadEpisodes()
     //the user want to be shown even if there is no more slot
     if( hasPurge() )
     {
-        command = QString( "(SELECT id, url, channel, localurl, guid, "
+        command = QStringLiteral( "(SELECT id, url, channel, localurl, guid, "
                            "title, subtitle, sequencenumber, description, mimetype, pubdate, "
                            "duration, filesize, isnew, iskeep FROM podcastepisodes WHERE channel = %1 "
-                           "AND iskeep IS FALSE ORDER BY pubdate DESC LIMIT " + QString::number( purgeCount() ) + ") "
+                           "AND iskeep IS FALSE ORDER BY pubdate DESC LIMIT ") + QString::number( purgeCount() ) + QStringLiteral(") "
                            "UNION "
                            "(SELECT id, url, channel, localurl, guid, "
                            "title, subtitle, sequencenumber, description, mimetype, pubdate, "
@@ -895,7 +897,7 @@ SqlPodcastChannel::loadEpisodes()
     }
     else
     {
-        command = QString( "SELECT id, url, channel, localurl, guid, "
+        command = QStringLiteral( "SELECT id, url, channel, localurl, guid, "
                            "title, subtitle, sequencenumber, description, mimetype, pubdate, "
                            "duration, filesize, isnew, iskeep FROM podcastepisodes WHERE channel = %1 "
                            "ORDER BY pubdate DESC;"
