@@ -26,7 +26,7 @@
 #include <QList>
 #include <QObject>
 
-#include <KUrl>
+#include <QUrl>
 
 namespace Collections {
     class Collection;
@@ -45,7 +45,7 @@ namespace Collections {
     - prettyLocation()
     - isWritable()
     - remove( Meta::Track )
-    - copyUrlsToCollection( QMap<Meta::TrackPtr, KUrl> )
+    - copyUrlsToCollection( QMap<Meta::TrackPtr, QUrl> )
 
     Writable collections that are also organizable should reimplement isOrganizable().
     Organizable means that the user is able to decide (to varying degrees, the details
@@ -95,7 +95,7 @@ namespace Collections {
     slotFinishRemove
 */
 
-class AMAROK_CORE_EXPORT CollectionLocation : public QObject
+class AMAROKCORE_EXPORT CollectionLocation : public QObject
 {
     Q_OBJECT
 
@@ -108,8 +108,8 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
 
     public:
         CollectionLocation();
-        CollectionLocation( Collections::Collection *parentCollection );
-        virtual  ~CollectionLocation();
+        explicit CollectionLocation( Collections::Collection *parentCollection );
+         ~CollectionLocation() override;
 
         /**
             Returns a pointer to the collection location's corresponding collection.
@@ -125,7 +125,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         virtual QString prettyLocation() const;
 
         /**
-            Returns a list of machine usable strings representingthe collection location.
+            Returns a list of machine usable strings representing the collection location.
             For example, a local collection would return a list of paths where tracks are
             stored, while an Ampache collection would return a list with one string
             containing the URL of an ampache server. An iPod collection and a MTP device
@@ -155,17 +155,21 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
            Convenience method for copying a single track.
            @see prepareCopy( Meta::TrackList, CollectionLocation* )
         */
-        void prepareCopy( Meta::TrackPtr track, CollectionLocation *destination );
+        void prepareCopy( const Meta::TrackPtr &track, CollectionLocation *destination );
         /**
-           Schedule copying of @param tracks to collection location @param destination.
-           This method takes ownership of the @param destination, you may not reference
+           Schedule copying of @p tracks to collection location @p destination.
+           This method takes ownership of the @p destination, you may not reference
            or delete it after this call. This method returns immediately and the actual
            copy is performed in the event loop and/or another thread.
+           @param tracks tracks
+           @param destination the collection location destination
         */
         void prepareCopy( const Meta::TrackList &tracks, CollectionLocation *destination );
         /**
-           Convenience method for copying tracks based on QueryMaker restults,
-           takes ownership of the @param qm.
+           Convenience method for copying tracks based on QueryMaker results,
+           takes ownership of the @p qm.
+           @param qm the QueryMaker query
+           @param destination the collection destination
            @see prepareCopy( Meta::TrackList, CollectionLocation* )
         */
         void prepareCopy( Collections::QueryMaker *qm, CollectionLocation *destination );
@@ -174,17 +178,21 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
          * Convenience method for moving a single track.
          * @see prepareMove( Meta::TrackList, CollectionLocation* )
          */
-        void prepareMove( Meta::TrackPtr track, CollectionLocation *destination );
+        void prepareMove( const Meta::TrackPtr &track, CollectionLocation *destination );
         /**
-           Schedule moving of @param tracks to collection location @param destination.
-           This method takes ownership of the @param destination, you may not reference
+           Schedule moving of @p tracks to collection location @p destination.
+           This method takes ownership of the @p destination, you may not reference
            or delete it after this call. This method returns immediately and the actual
            move is performed in the event loop and/or another thread.
+           @param tracks tracks
+           @param destination the collection location destination
         */
         void prepareMove( const Meta::TrackList &tracks, CollectionLocation *destination );
         /**
-           Convenience method for moving tracks based on QueryMaker restults,
-           takes ownership of the @param qm.
+           Convenience method for moving tracks based on QueryMaker results,
+           takes ownership of the @p qm.
+           @param qm the QueryMaker query
+           @param destination the collection destination
            @see prepareMove( Meta::TrackList, CollectionLocation* )
         */
         void prepareMove( Collections::QueryMaker *qm, CollectionLocation *destination );
@@ -195,7 +203,8 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         void prepareRemove( const Meta::TrackList &tracks );
         /**
            Convenience method for removing tracks selected by QueryMaker,
-           takes ownership of the @param qm.
+           takes ownership of the @p qm.
+           @param qm the QueryMaker query
            @see prepareRemove( Meta::TrackList )
          */
         void prepareRemove( Collections::QueryMaker *qm );
@@ -203,26 +212,31 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         /**
          * Adds or merges a track to the collection (not to the disk)
          * Inserts a set of TrackPtrs directly into the database without needing to actual move any files
+         * @param track track
+         * @param path path
          * This is a hack required by the DatabaseImporter
          * TODO: Remove this hack
          * @return true if the database entry was inserted, false otherwise
          */
-        virtual bool insert( const Meta::TrackPtr &track, const QString &url );
+        virtual bool insert( const Meta::TrackPtr &track, const QString &path );
 
         /**
           explicitly inform the source collection of successful transfer.
           The source collection will only remove files (if necessary)
           for which this method was called.
+          @param track track
           */
         void transferSuccessful( const Meta::TrackPtr &track );
 
         /**
         * tells the source location that an error occurred during the transfer of the file
+        * @param track track
+        * @param error error
         */
         virtual void transferError( const Meta::TrackPtr &track, const QString &error );
 
-    signals:
-        void startCopy( const QMap<Meta::TrackPtr, KUrl> &sources,
+    Q_SIGNALS:
+        void startCopy( const QMap<Meta::TrackPtr, QUrl> &sources,
                         const Transcoding::Configuration & );
         void finishCopy();
         void startRemove();
@@ -254,7 +268,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         /**
             this method is called on the source location, and should return a list of urls
             which the destination location can copy using KIO. You must call
-            slotGetKIOCopyableUrlsDone( QMap<Meta::TrackPtr, KUrl> ) after retrieving the
+            slotGetKIOCopyableUrlsDone( QMap<Meta::TrackPtr, QUrl> ) after retrieving the
             urls. The order of urls passed to that method has to be the same as the order
             of the tracks passed to this method.
         */
@@ -269,7 +283,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
             successfully copied to destination collection. Only such marked tracks are
             then removed in case of a "move" action.
         */
-        virtual void copyUrlsToCollection( const QMap<Meta::TrackPtr, KUrl> &sources,
+        virtual void copyUrlsToCollection( const QMap<Meta::TrackPtr, QUrl> &sources,
                                            const Transcoding::Configuration &configuration );
 
         /**
@@ -329,7 +343,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
 
         /**
          * Get nice localised string describing the current operation based on transcoding
-         * configuraiton and isGoingToRemoveSources(); meant to be called by destination
+         * configuration and isGoingToRemoveSources(); meant to be called by destination
          * collection.
          *
          * @return "Copy Tracks", "Transcode and Organize Tracks" etc.
@@ -340,6 +354,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
          * Get nice localised string that can be used as progress bar text for the current
          * operation; meant to be called by the destination collection.
          *
+         * @param configuration the transcoding configuration
          * @param trackCount number of tracks in the transfer
          * @param destinationName pretty localised name of the destination collection;
          *        prettyLocation() is used if the string is empty or not specified
@@ -361,25 +376,25 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         virtual bool isHidingRemoveConfirm() const;
         virtual void setHidingRemoveConfirm( bool hideRemoveConfirm );
 
-    protected slots:
+    protected Q_SLOTS:
         /**
          * this slot has to be called from getKIOCopyableUrls( Meta::TrackList )
          * Please note: the order of urls in the argument has to be the same as in the
          * tracklist
          */
-        void slotGetKIOCopyableUrlsDone( const QMap<Meta::TrackPtr, KUrl> &sources );
+        void slotGetKIOCopyableUrlsDone( const QMap<Meta::TrackPtr, QUrl> &sources );
         void slotCopyOperationFinished();
         void slotRemoveOperationFinished();
         void slotShowSourceDialogDone();
         void slotShowRemoveDialogDone();
         void slotShowDestinationDialogDone();
 
-    private slots:
+    private Q_SLOTS:
         void slotShowSourceDialog();  // trick to show dialog in next mainloop iteration
         void slotPrepareOperation( const Meta::TrackList &tracks, bool removeSources,
                                    const Transcoding::Configuration &configuration );
         void slotOperationPrepared();
-        void slotStartCopy( const QMap<Meta::TrackPtr, KUrl> &sources,
+        void slotStartCopy( const QMap<Meta::TrackPtr, QUrl> &sources,
                             const Transcoding::Configuration &configuration );
         void slotFinishCopy();
         void slotStartRemove();
@@ -393,7 +408,6 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         void setupRemoveConnections();
         void startWorkflow( const Meta::TrackList &tracks, bool removeSources );
         void startRemoveWorkflow( const Meta::TrackList &tracks );
-        void startRemove( const Meta::TrackList &tracks );
         void removeSourceTracks( const Meta::TrackList &tracks );
         void setSource( CollectionLocation *source );
 
@@ -403,7 +417,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         CollectionLocation *m_source;
 
         Meta::TrackList getSourceTracks() const { return m_sourceTracks; }
-        void setSourceTracks( Meta::TrackList tracks ) { m_sourceTracks = tracks; }
+        void setSourceTracks( const Meta::TrackList &tracks ) { m_sourceTracks = tracks; }
         Meta::TrackList m_sourceTracks;
 
         Collections::Collection *m_parentCollection;
