@@ -22,11 +22,11 @@
 #include "core/transcoding/TranscodingDefines.h"
 #include "core/transcoding/TranscodingProperty.h"
 
-#include <KConfigGroup>
-
 #include <QMap>
 #include <QVariant>
 
+class KConfigGroup;
+
 namespace Transcoding
 {
 
