@@ -39,7 +39,7 @@ Mp3Format::Mp3Format()
         "Anything below <b>120kb/s</b> might be unsatisfactory for music and anything above "
         "<b>205kb/s</b> is probably overkill.");
     QStringList valueLabels;
-    QByteArray vbr = "VBR ~%1kb/s";
+    char vbr[] = "VBR ~%1kb/s";
     valueLabels
         << i18n( vbr, 80 )
         << i18n( vbr, 100 )
@@ -85,7 +85,7 @@ Mp3Format::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
     parameters << QStringLiteral("-acodec") << QStringLiteral("libmp3lame");
-    foreach( const Property &property, m_propertyList )
+    for( const Property &property : m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
             && configuration.property( property.name() ).type() == property.variantType() )
@@ -104,5 +104,5 @@ Mp3Format::ffmpegParameters( const Configuration &configuration ) const
 bool
 Mp3Format::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... mp3 +.*libmp3lame") ) );
+    return ffmpegOutput.contains( QRegularExpression( QStringLiteral("^ .EA... mp3 +.*libmp3lame") ) );
 }
