@@ -39,7 +39,7 @@ OpusFormat::OpusFormat()
         "Anything below <b>100kb/s</b> might be unsatisfactory for music and anything above "
         "<b>256kb/s</b> is probably overkill.");
     QStringList valueLabels;
-    QByteArray vbr = "VBR ~%1kb/s";
+    char vbr[] = "VBR ~%1kb/s";
     valueLabels
         << i18n( vbr, 32 )
         << i18n( vbr, 64 )
@@ -92,7 +92,7 @@ OpusFormat::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
     parameters << QStringLiteral("-acodec") << QStringLiteral("libopus");
-    foreach( const Property &property, m_propertyList )
+    for( const Property &property : m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
             && configuration.property( property.name() ).type() == property.variantType() )
@@ -117,5 +117,5 @@ OpusFormat::toFfmpegBitrate( int setting ) const
 bool
 OpusFormat::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... opus +.*libopus") ) );
+    return ffmpegOutput.contains( QRegularExpression( QStringLiteral("^ .EA... opus +.*libopus") ) );
 }
