@@ -36,7 +36,7 @@ WmaFormat::WmaFormat()
         "Anything below <b>112kb/s</b> might be unsatisfactory for music and anything above "
         "<b>182kb/s</b> is probably overkill.");
     QStringList valueLabels;
-    const QByteArray cbr = "CBR %1kb/s";
+    const char cbr[] = "CBR %1kb/s";
     valueLabels
         << i18n( cbr, 64 )
         << i18n( cbr, 80 )
@@ -81,7 +81,7 @@ WmaFormat::description() const
 QIcon
 WmaFormat::icon() const
 {
-    return QIcon::fromTheme( "audio-x-generic" );  //TODO: get a *real* icon!
+    return QIcon::fromTheme( QStringLiteral( "audio-x-generic" ) );  //TODO: get a *real* icon!
 }
 
 QStringList
@@ -89,7 +89,7 @@ WmaFormat::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
     parameters << QStringLiteral("-acodec") << QStringLiteral("wmav2");
-    foreach( const Property &property, m_propertyList )
+    for( const Property &property : m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
             && configuration.property( property.name() ).type() == property.variantType() )
@@ -115,5 +115,5 @@ WmaFormat::toFfmpegBitrate( int setting ) const
 bool
 WmaFormat::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... wmav2 +") ) );
+    return ffmpegOutput.contains( QRegularExpression( QStringLiteral("^ .EA... wmav2 +") ) );
 }
