@@ -18,23 +18,25 @@
 #include "DiagnosticDialog.h"
 
 #include "context/ContextView.h"
+#include "core/support/Amarok.h"
 #include "PluginManager.h"
 #include "scripting/scriptmanager/ScriptManager.h"
 
+#include <KAboutData>
+#include <KCoreAddons>
+#include <KLocalizedString>
+#include <KPluginMetaData>
+
 #include <QApplication>
 #include <QClipboard>
 #include <QDialogButtonBox>
 #include <QDir>
 #include <QPlainTextEdit>
+#include <QPluginLoader>
 #include <QPushButton>
 #include <QSettings>
 #include <QVBoxLayout>
 
-#include <KAboutData>
-#include <KCoreAddons>
-#include <KLocalizedString>
-#include <KPluginInfo>
-
 #include <algorithm>
 #include <phonon/pulsesupport.h>
 
@@ -99,7 +101,7 @@ const QString
 DiagnosticDialog::generateReport( const KAboutData *aboutData )
 {
     // Get scripts -- we have to assemble 3 lists into one
-    KPluginInfo::List aScripts;
+    QVector<KPluginMetaData> aScripts;
     const auto aScriptManager = ScriptManager::instance();
     aScripts.append( aScriptManager->scripts( QStringLiteral( "Generic" ) ) );
     aScripts.append( aScriptManager->scripts( QStringLiteral( "Lyrics" ) ) );
@@ -107,10 +109,10 @@ DiagnosticDialog::generateReport( const KAboutData *aboutData )
 
     // Format the data to be readable
     QString aScriptString;
-    foreach( KPluginInfo aInfo, aScripts )
+    for( KPluginMetaData aInfo : aScripts )
     {
-        if( aInfo.isPluginEnabled() )
-            aScriptString += "   " + aInfo.name() + " (" + aInfo.version() + ")\n";
+        if( aInfo.isEnabled( Amarok::config( QStringLiteral("Scripts") ) ) )
+            aScriptString += QStringLiteral("   ") + aInfo.name() + QStringLiteral(" (") + aInfo.version() + QStringLiteral(")\n");
     }
 
 
@@ -124,7 +126,7 @@ DiagnosticDialog::generateReport( const KAboutData *aboutData )
     QString aPluginString;
     for( const auto &aInfo : qAsConst(aPlugins) )
     {
-        aPluginString += "   " + aInfo.name() + " (" + aInfo.version() + ")\n";
+        aPluginString += QStringLiteral("   ") + aInfo.name() + QStringLiteral(" (") + aInfo.version() + QStringLiteral(")\n");
     }
 
     // Get applets
@@ -134,7 +136,7 @@ DiagnosticDialog::generateReport( const KAboutData *aboutData )
     for ( const QString &applet : appletList )
     {
         // Currently we cannot extract the applet version number this way
-        appletString += "   " + applet + '\n';
+        appletString += QStringLiteral("   ") + applet + QLatin1Char('\n');
     }
 
     const BackendDescriptor aPhononBackend = getPreferredBackend();
@@ -153,8 +155,8 @@ DiagnosticDialog::generateReport( const KAboutData *aboutData )
 
                KAboutData::applicationData().displayName(), aboutData->version(),      // Amarok
                KCoreAddons::versionString(),                        // KDE Frameworks
-               qVersion(),                                          // Qt
-               Phonon::phononVersion(),                             // Phonon
+               QLatin1String(qVersion()),                           // Qt
+               QLatin1String(Phonon::phononVersion()),              // Phonon
                aPhononBackend.name,
                aPhononBackend.version,
                aPhononBackend.website,                              // & Backend
@@ -171,8 +173,8 @@ const BackendDescriptor
 DiagnosticDialog::getPreferredBackend() const
 {
     QList<QString> iidPreference;
-    QSettings settings("kde.org", "libphonon");
-    const int size = settings.beginReadArray("Backends");
+    QSettings settings(QStringLiteral("kde.org"), QStringLiteral("libphonon"));
+    const int size = settings.beginReadArray(QStringLiteral("Backends"));
     for (int i = 0; i < size; ++i) {
         settings.setArrayIndex(i);
         iidPreference.append(settings.value(QStringLiteral("iid")).toString());
@@ -184,7 +186,7 @@ DiagnosticDialog::getPreferredBackend() const
 
     QList<struct BackendDescriptor> backendList;
 
-    foreach (const QString &path, paths) {
+    for(const QString &path : paths) {
         const QString libPath = path + suffix;
         const QDir dir(libPath);
         if (!dir.exists()) {
