@@ -25,6 +25,9 @@
 
 #include "amarok_export.h" // we are exporting it for the tests
 
+#include <ThreadWeaver/Queue>
+#include <ThreadWeaver/Job>
+
 #include <QObject>
 #include <QPointer>
 
@@ -43,26 +46,26 @@ namespace Dynamic
 
         public:
             /** Creates a new random playlist */
-            BiasedPlaylist( QObject *parent = 0 );
+            explicit BiasedPlaylist( QObject *parent = nullptr );
 
             /** Creates a new playlist from an xml stream */
-            BiasedPlaylist( QXmlStreamReader *reader, QObject *parent = 0 );
+            explicit BiasedPlaylist( QXmlStreamReader *reader, QObject *parent = nullptr );
 
-            ~BiasedPlaylist();
+            ~BiasedPlaylist() override;
 
-            void toXml( QXmlStreamWriter *writer ) const;
+            void toXml( QXmlStreamWriter *writer ) const override;
 
-            void requestTracks(int);
+            void requestTracks(int) override;
 
             BiasPtr bias() const;
 
-        public slots:
-            virtual void requestAbort();
+        public Q_SLOTS:
+            void requestAbort() override;
 
-        private slots:
+        private Q_SLOTS:
             void solverFinished();
             void biasChanged();
-            void biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBias );
+            void biasReplaced( const Dynamic::BiasPtr &oldBias, const Dynamic::BiasPtr &newBias );
 
         private:
             /** Starts the BiasSolver (if not already running) and requests a couple of new tracks. */
@@ -84,4 +87,3 @@ namespace Dynamic
 // Q_DECLARE_METATYPE( Dynamic::BiasedPlaylistPtr )
 
 #endif
-
