@@ -36,7 +36,6 @@
 #include "playlist/PlaylistActions.h"
 
 #include <QIcon>
-
 #include <QFile>
 #include <QBuffer>
 #include <QByteArray>
@@ -291,7 +290,7 @@ Dynamic::DynamicModel::data( const QModelIndex& i, int role ) const
             {
                 // find the factory for the bias
                 QList<Dynamic::AbstractBiasFactory*> factories = Dynamic::BiasFactory::factories();
-                foreach( Dynamic::AbstractBiasFactory* factory, factories )
+                for( const Dynamic::AbstractBiasFactory* factory : factories )
                 {
                     if( factory->name() == indexBias->name() )
                         return factory->i18nDescription();
@@ -801,7 +800,7 @@ Dynamic::DynamicModel::savePlaylists( const QString &filename )
     xmlWriter.writeAttribute(QStringLiteral("version"), QStringLiteral("2") );
     xmlWriter.writeAttribute(QStringLiteral("current"), QString::number( m_activePlaylistIndex ) );
 
-    foreach( Dynamic::DynamicPlaylist *playlist, m_playlists )
+    for( const Dynamic::DynamicPlaylist *playlist : m_playlists )
     {
         xmlWriter.writeStartElement(QStringLiteral("playlist"));
         playlist->toXml( &xmlWriter );
@@ -819,8 +818,7 @@ Dynamic::DynamicModel::loadPlaylists( const QString &filename )
 {
     // -- clear all the old playlists
     beginResetModel();
-    foreach( Dynamic::DynamicPlaylist* playlist, m_playlists )
-        delete playlist;
+    qDeleteAll( m_playlists );
     m_playlists.clear();
 
     // -- open the file
@@ -853,7 +851,7 @@ Dynamic::DynamicModel::loadPlaylists( const QString &filename )
 
         if( xmlReader.isStartElement() )
         {
-            QStringRef name = xmlReader.name();
+            QStringView name = xmlReader.name();
             if( name == QLatin1String("playlist") )
             {
                 Dynamic::BiasedPlaylist *playlist =  new Dynamic::BiasedPlaylist( &xmlReader, this );
@@ -900,8 +898,7 @@ Dynamic::DynamicModel::initPlaylists()
 {
     // -- clear all the old playlists
     beginResetModel();
-    foreach( Dynamic::DynamicPlaylist* playlist, m_playlists )
-        delete playlist;
+    qDeleteAll( m_playlists );
     m_playlists.clear();
 
     Dynamic::BiasedPlaylist *playlist;
@@ -929,7 +926,7 @@ Dynamic::DynamicModel::initPlaylists()
     Dynamic::IfElseBias *ifElse = new Dynamic::IfElseBias();
     playlist->bias()->replace( Dynamic::BiasPtr( ifElse ) );
     ifElse->appendBias( Dynamic::BiasPtr( new Dynamic::AlbumPlayBias() ) );
-    query = Meta::shortI18nForField( Meta::valTrackNr ) + ":1";
+    query = Meta::shortI18nForField( Meta::valTrackNr ) + QStringLiteral(":1");
     ifElse->appendBias( Dynamic::BiasPtr( new Dynamic::SearchQueryBias( query ) ) );
     insertPlaylist( 2, playlist );
 
@@ -980,7 +977,7 @@ Dynamic::DynamicModel::serializeIndex( QDataStream *stream, const QModelIndex& i
         current = current.parent();
     }
 
-    foreach( int row, rows )
+    for( int row : rows )
         *stream << row;
     *stream << -1;
 }
@@ -1103,10 +1100,10 @@ static QString
 biasToString( Dynamic::BiasPtr bias, int level )
 {
     QString result;
-    result += QStringLiteral(" ").repeated(level) + bias->toString() + ' ' + QString::number(quintptr(bias.data()), 16) + '\n';
+    result += QStringLiteral(" ").repeated(level) + bias->toString() + QLatin1Char(' ') + QString::number(quintptr(bias.data()), 16) + QLatin1Char('\n');
     if( Dynamic::AndBias* aBias = qobject_cast<Dynamic::AndBias*>(bias.data()) )
     {
-        foreach( Dynamic::BiasPtr bias2, aBias->biases() )
+        for( Dynamic::BiasPtr bias2 : aBias->biases() )
             result += biasToString( bias2, level + 1 );
     }
     return result;
@@ -1117,9 +1114,9 @@ Dynamic::DynamicModel::toString()
 {
     QString result;
 
-    foreach( Dynamic::DynamicPlaylist* playlist, m_playlists )
+    for( Dynamic::DynamicPlaylist *playlist : m_playlists )
     {
-        result += playlist->title() + ' ' + QString::number(quintptr(playlist), 16) + '\n';
+        result += playlist->title() + QLatin1Char(' ') + QString::number(quintptr(playlist), 16) + QLatin1Char('\n');
         if( Dynamic::BiasedPlaylist* bPlaylist = qobject_cast<Dynamic::BiasedPlaylist*>(playlist ) )
             result += biasToString( bPlaylist->bias(), 1 );
     }
