@@ -18,8 +18,8 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
-#ifndef AMAROK_METATAGBIAS_H
-#define AMAROK_METATAGBIAS_H
+#ifndef AMAROK_TAGMATCHBIAS_H
+#define AMAROK_TAGMATCHBIAS_H
 
 #include "amarok_export.h"
 #include "core/collections/QueryMaker.h"
@@ -37,7 +37,7 @@ namespace Dynamic
 
     class TagMatchBias;
 
-    /** An abstract bias that will check matching tracks agains the results from a query maker.
+    /** An abstract bias that will check matching tracks against the results from a query maker.
         You can use this base class for writing your own biases.
         In all cases you have to implement newQuery which creates a
         QueryMaker and starts it.
@@ -49,27 +49,27 @@ namespace Dynamic
         public:
             SimpleMatchBias();
 
-            virtual void fromXml( QXmlStreamReader *reader );
-            virtual void toXml( QXmlStreamWriter *writer ) const;
+            void fromXml( QXmlStreamReader *reader ) override;
+            void toXml( QXmlStreamWriter *writer ) const override;
 
-            virtual TrackSet matchingTracks( const Meta::TrackList& playlist,
+            TrackSet matchingTracks( const Meta::TrackList& playlist,
                                              int contextCount, int finalCount,
-                                             const TrackCollectionPtr universe ) const;
+                                             const TrackCollectionPtr &universe ) const override;
 
-            virtual bool trackMatches( int position,
+            bool trackMatches( int position,
                                        const Meta::TrackList& playlist,
-                                       int contextCount ) const;
+                                       int contextCount ) const override;
 
             /** Is the result inverted (e.g. does NOT contain) */
             bool isInvert() const;
             void setInvert( bool value );
 
-        public slots:
-            virtual void invalidate();
+        public Q_SLOTS:
+            void invalidate() override;
 
-        protected slots:
+        protected Q_SLOTS:
             /** Called when we get new uids from the query maker */
-            virtual void updateReady( QStringList uids );
+            virtual void updateReady( const QStringList &uids );
 
             /** Called when the querymaker is finished */
             virtual void updateFinished();
@@ -108,9 +108,9 @@ namespace Dynamic
         Q_OBJECT
 
         public:
-            TagMatchBiasWidget( Dynamic::TagMatchBias* bias, QWidget* parent = 0 );
+            explicit TagMatchBiasWidget( Dynamic::TagMatchBias* bias, QWidget* parent = nullptr );
 
-        private slots:
+        private Q_SLOTS:
             void syncControlsToBias();
             void syncBiasToControls();
 
@@ -130,25 +130,25 @@ namespace Dynamic
         public:
             TagMatchBias();
 
-            virtual void fromXml( QXmlStreamReader *reader );
-            virtual void toXml( QXmlStreamWriter *writer ) const;
+            void fromXml( QXmlStreamReader *reader ) override;
+            void toXml( QXmlStreamWriter *writer ) const override;
 
             static QString sName();
-            virtual QString name() const;
-            virtual QString toString() const;
+            QString name() const override;
+            QString toString() const override;
 
-            virtual QWidget* widget( QWidget* parent = 0 );
+            QWidget* widget( QWidget* parent = nullptr ) override;
 
-            virtual bool trackMatches( int position,
+            bool trackMatches( int position,
                                        const Meta::TrackList& playlist,
-                                       int contextCount ) const;
+                                       int contextCount ) const override;
 
 
             MetaQueryWidget::Filter filter() const;
             void setFilter( const MetaQueryWidget::Filter &filter );
 
-        protected slots:
-            virtual void newQuery();
+        protected Q_SLOTS:
+            void newQuery() override;
 
         protected:
             static QString nameForCondition( MetaQueryWidget::FilterCondition cond );
@@ -164,10 +164,10 @@ namespace Dynamic
     class AMAROK_EXPORT TagMatchBiasFactory : public Dynamic::AbstractBiasFactory
     {
         public:
-            virtual QString i18nName() const;
-            virtual QString name() const;
-            virtual QString i18nDescription() const;
-            virtual BiasPtr createBias();
+            QString i18nName() const override;
+            QString name() const override;
+            QString i18nDescription() const override;
+            BiasPtr createBias() override;
     };
 
 }
