@@ -19,6 +19,8 @@
 #include "ImporterManager.h"
 #include "core/support/Debug.h"
 
+#include <QRandomGenerator>
+
 using namespace StatSyncing;
 
 ImporterProvider::ImporterProvider( const QVariantMap &config, ImporterManager *manager )
@@ -26,9 +28,9 @@ ImporterProvider::ImporterProvider( const QVariantMap &config, ImporterManager *
     , m_manager( manager )
 {
     if( !m_config.contains( QStringLiteral("uid") ) )
-        m_config.insert( QStringLiteral("uid"), qrand() );
+        m_config.insert( QStringLiteral("uid"), QRandomGenerator::global()->generate() );
 
-    if( m_manager == 0 )
+    if( m_manager == nullptr )
         warning() << __PRETTY_FUNCTION__ << "manager pointer is not set";
 }
 
@@ -70,7 +72,7 @@ ProviderConfigWidget*
 ImporterProvider::configWidget()
 {
     Q_ASSERT( m_manager );
-    return m_manager ? m_manager->configWidget( m_config ) : 0;
+    return m_manager ? m_manager->configWidget( m_config ) : nullptr;
 }
 
 void
