@@ -31,6 +31,7 @@
 
 #include <QAuthenticator>
 #include <QNetworkAccessManager>
+#include <QRegularExpression>
 #include <QTimer>
 #include <QUrlQuery>
 
@@ -100,7 +101,7 @@ MusicBrainzFinder::isRunning() const
 void
 MusicBrainzFinder::run( const Meta::TrackList &tracks )
 {
-    foreach( const Meta::TrackPtr &track, tracks )
+    for( const Meta::TrackPtr &track : tracks )
         m_requests.append( qMakePair( track, compileTrackRequest( track ) ) );
 
     m_timer->start();
@@ -174,7 +175,7 @@ MusicBrainzFinder::gotReply( QNetworkReply *reply )
     {
         if( reply->error() == QNetworkReply::NoError )
         {
-            QString document( reply->readAll() );
+            QByteArray document( reply->readAll() );
             MusicBrainzXmlParser *parser = new MusicBrainzXmlParser( document );
             m_parsers.insert( parser, m_replies.value( reply ) );
 
@@ -227,7 +228,7 @@ MusicBrainzFinder::parsingDone( ThreadWeaver::JobPointer _parser )
             }
 
             lengthTolerance *= 1000;
-            foreach( QVariantMap track, parser->tracks.values() )
+            for( QVariantMap track : parser->tracks.values() )
             {
 #define SIMILARITY( k ) similarity( metadata.value( k ).toString().toLower(), \
                                     track.value( k ).toString().toLower() )
@@ -252,7 +253,7 @@ MusicBrainzFinder::parsingDone( ThreadWeaver::JobPointer _parser )
                 if( track.contains( MusicBrainz::RELEASELIST ) )
                 {
                     // We try to send as many tracks as are the related releases.
-                    foreach( const QString &releaseID,
+                    for( const QString &releaseID :
                              track.value( MusicBrainz::RELEASELIST ).toStringList() )
                     {
                         /*
@@ -295,7 +296,7 @@ MusicBrainzFinder::parsingDone( ThreadWeaver::JobPointer _parser )
                          * result in duplicated entries (which is bad for several
                          * reasons).
                          */
-                        foreach( const QVariant &info,
+                        for( const QVariant &info :
                                  track.value( MusicBrainz::TRACKINFO ).toMap().value( releaseID ).toList() )
                         {
                             QVariantMap trackInfo = info.toMap();
@@ -434,7 +435,7 @@ MusicBrainzFinder::parsingDone( ThreadWeaver::JobPointer _parser )
         QString releaseGroupID = parser->releaseGroups.keys().first();
         mb_releaseGroups.insert( releaseGroupID,
                                  parser->releaseGroups.value( releaseGroupID ) );
-        foreach( const TrackInfo &trackInfo, mb_queuedTracks.value( releaseGroupID ) )
+        for( const TrackInfo &trackInfo : mb_queuedTracks.value( releaseGroupID ) )
             sendTrack( trackInfo.first, trackInfo.second );
         mb_queuedTracks.remove( releaseGroupID );
     }
@@ -508,9 +509,9 @@ MusicBrainzFinder::checkDone()
          * Sending an empty result makes the user aware of the fact that the track will
          * not be tagged.
          */
-        foreach( const QList<TrackInfo> &trackInfoList,
+        for( const QList<TrackInfo> &trackInfoList :
                  mb_queuedTracks.values() )
-            foreach( const TrackInfo &trackInfo, trackInfoList )
+            for( const TrackInfo &trackInfo : trackInfoList )
                 sendTrack( trackInfo.first, QVariantMap() );
 
         debug() << "There is no queued request. Stopping timer.";
@@ -530,7 +531,7 @@ MusicBrainzFinder::guessMetadata( const Meta::TrackPtr &track ) const
         ( track->album().isNull() || track->album()->name().isEmpty() ) )
     {
         Meta::FieldHash tags = Meta::Tag::TagGuesser::guessTags( track->playableUrl().fileName() );
-        foreach( const quint64 &key, tags.keys() )
+        for( const quint64 key : tags.keys() )
         {
             switch( key )
             {
@@ -568,7 +569,7 @@ MusicBrainzFinder::guessMetadata( const Meta::TrackPtr &track ) const
         metadata.insert( Meta::Field::TRACKNUMBER, track->trackNumber() );
 
     debug() << "Guessed track info:";
-    foreach( const QString &tag, metadata.keys() )
+    for( const QString &tag : metadata.keys() )
         debug() << '\t' << tag << ":\t" << metadata.value( tag ).toString();
 
     return metadata;
@@ -581,13 +582,13 @@ MusicBrainzFinder::compileTrackRequest( const Meta::TrackPtr &track )
     QVariantMap metadata = guessMetadata( track );
 
     // These characters are not considered in the query, and some of them can break it.
-    QRegExp unsafe( "[.,:;!?()\\[\\]{}\"]" );
+    QRegularExpression unsafe( QStringLiteral("[.,:;!?()\\[\\]{}\"]") );
     // http://lucene.apache.org/core/old_versioned_docs/versions/3_4_0/queryparsersyntax.html#Escaping Special Characters
-    QRegExp special( "([+\\-!(){}\\[\\]\\^\"~*?:\\\\]|&&|\\|\\|)" );
-    QString escape( "\\\\1" );
+    QRegularExpression special( QStringLiteral("([+\\-!(){}\\[\\]\\^\"~*?:\\\\]|&&|\\|\\|)") );
+    QString escape( QStringLiteral("\\\\1") );
     // We use fuzzy search to bypass typos and small mistakes.
-    QRegExp endOfWord( "([a-zA-Z0-9])(\\s|$)" );
-    QString fuzzy( "\\1~\\2" );
+    QRegularExpression endOfWord( QStringLiteral("([a-zA-Z0-9])(\\s|$)") );
+    QString fuzzy( QStringLiteral("\\1~\\2") );
     /*
      * The query results in:
      * ("track~ title~"^20 track~ title~) AND artist:("artist~ name~"^2 artist~ name~) AND release:("album~ name~"^7 album~ name~)
@@ -600,20 +601,20 @@ MusicBrainzFinder::compileTrackRequest( const Meta::TrackPtr &track )
      */
 #define VALUE( k ) metadata.value( k ).toString().remove( unsafe ).replace( special, escape ).replace( endOfWord, fuzzy )
     if( metadata.contains( Meta::Field::TITLE ) )
-        queryString += QString( "(\"%1\"^20 %1)" ).arg( VALUE( Meta::Field::TITLE ) );
+        queryString += QStringLiteral( "(\"%1\"^20 %1)" ).arg( VALUE( Meta::Field::TITLE ) );
     if( metadata.contains( Meta::Field::ARTIST ) )
-        queryString += QString( " AND artist:(\"%1\"^2 %1)" ).arg( VALUE( Meta::Field::ARTIST ) );
+        queryString += QStringLiteral( " AND artist:(\"%1\"^2 %1)" ).arg( VALUE( Meta::Field::ARTIST ) );
     if( metadata.contains( Meta::Field::ALBUM ) )
-        queryString += QString( " AND release:(\"%1\"^7 %1)" ).arg( VALUE( Meta::Field::ALBUM ) );
+        queryString += QStringLiteral( " AND release:(\"%1\"^7 %1)" ).arg( VALUE( Meta::Field::ALBUM ) );
 #undef VALUE
 
     m_parsedMetadata.insert( track, metadata );
 
     QUrl url;
     QUrlQuery query;
-    url.setPath( mb_pathPrefix + "/recording" );
-    query.addQueryItem( "limit", "10" );
-    query.addQueryItem( "query", queryString );
+    url.setPath( mb_pathPrefix + QStringLiteral("/recording") );
+    query.addQueryItem( QStringLiteral("limit"), QStringLiteral("10") );
+    query.addQueryItem( QStringLiteral("query"), queryString );
     url.setQuery( query );
 
     return compileRequest( url );
@@ -624,8 +625,8 @@ MusicBrainzFinder::compilePUIDRequest( const QString &puid )
 {
     QUrl url;
     QUrlQuery query;
-    url.setPath( mb_pathPrefix + "/recording" );
-    query.addQueryItem( "query", "puid:" + puid );
+    url.setPath( mb_pathPrefix + QStringLiteral("/recording") );
+    query.addQueryItem( QStringLiteral("query"), QStringLiteral("puid:") + puid );
     url.setQuery( query );
 
     return compileRequest( url );
@@ -636,8 +637,8 @@ MusicBrainzFinder::compileReleaseGroupRequest( const QString &releaseGroupID )
 {
     QUrl url;
     QUrlQuery query;
-    url.setPath( mb_pathPrefix + "/release-group/" + releaseGroupID );
-    query.addQueryItem( "inc", "artists" );
+    url.setPath( mb_pathPrefix + QStringLiteral("/release-group/") + releaseGroupID );
+    query.addQueryItem( QStringLiteral("inc"), QStringLiteral("artists") );
     url.setQuery( query );
 
     return compileRequest( url );
@@ -646,7 +647,7 @@ MusicBrainzFinder::compileReleaseGroupRequest( const QString &releaseGroupID )
 QNetworkRequest
 MusicBrainzFinder::compileRequest( QUrl &url )
 {
-    url.setScheme( "http" );
+    url.setScheme( QStringLiteral("http") );
     url.setHost( mb_host );
     url.setPort( mb_port );
 
