@@ -24,20 +24,20 @@
 
 #include <KActionMenu>
 #include <KLocalizedString>
-#include <QStandardPaths>
 
 #include <QContextMenuEvent>
 #include <QDesktopServices>
 #include <QMenu>
 #include <QSortFilterProxyModel>
+#include <QStandardPaths>
 #include <QUrl>
 
 MusicBrainzTagsView::MusicBrainzTagsView( QWidget *parent )
     : QTreeView( parent )
 {
-    m_artistIcon = QIcon::fromTheme( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/mb_aicon.png" ) );
-    m_releaseIcon = QIcon::fromTheme( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/mb_licon.png" ) );
-    m_trackIcon = QIcon::fromTheme( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/mb_ticon.png" ) );
+    m_artistIcon = QIcon::fromTheme( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/mb_aicon.png") ) );
+    m_releaseIcon = QIcon::fromTheme( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/mb_licon.png") ) );
+    m_trackIcon = QIcon::fromTheme( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/mb_ticon.png") ) );
 }
 
 MusicBrainzTagsModel *
@@ -76,7 +76,7 @@ MusicBrainzTagsView::contextMenuEvent( QContextMenuEvent *event )
 
     if( model->rowCount() > 1 && !index.data( MusicBrainzTagsModel::ReleasesRole ).isNull() )
     {
-        QAction *action = new QAction( QIcon::fromTheme( "filename-album-amarok" ),
+        QAction *action = new QAction( QIcon::fromTheme( QStringLiteral("filename-album-amarok") ),
                                        i18n( "Choose Best Matches from This Album" ), menu );
         connect( action, &QAction::triggered, this, &MusicBrainzTagsView::chooseBestMatchesFromRelease );
         menu->addAction( action );
@@ -91,9 +91,9 @@ MusicBrainzTagsView::contextMenuEvent( QContextMenuEvent *event )
         KActionMenu *action = new KActionMenu( m_artistIcon, i18n( "Go to Artist Page" ), menu );
         if( artists.size() > 1 )
         {
-            foreach( const QVariant &id, artists.keys() )
+            for( const QString &id : artists.keys() )
             {
-                QAction *subAction = new QAction( artists.value( id.toString() ).toString(), action );
+                QAction *subAction = new QAction( artists.value( id ).toString(), action );
                 subAction->setData( id );
                 connect( subAction, &QAction::triggered, this, &MusicBrainzTagsView::openArtistPage );
                 action->addAction( subAction );
@@ -199,7 +199,7 @@ MusicBrainzTagsView::openArtistPage() const
     if( artistID.isEmpty() )
         return;
 
-    QString url = QString( "http://musicbrainz.org/artist/%1.html" ).arg( artistID );
+    QString url = QString( QStringLiteral("http://musicbrainz.org/artist/%1.html") ).arg( artistID );
 
     QDesktopServices::openUrl( QUrl::fromUserInput(url) );
 }
@@ -215,7 +215,7 @@ MusicBrainzTagsView::openReleasePage() const
     if( releaseID.isEmpty() )
         return;
 
-    QString url = QString( "http://musicbrainz.org/release/%1.html" ).arg( releaseID );
+    QString url = QString( QStringLiteral("http://musicbrainz.org/release/%1.html") ).arg( releaseID );
 
     QDesktopServices::openUrl( QUrl::fromUserInput(url) );
 }
@@ -231,7 +231,7 @@ MusicBrainzTagsView::openTrackPage() const
     if( trackID.isEmpty() )
         return;
 
-    QString url = QString( "http://musicbrainz.org/recording/%1.html" ).arg( trackID );
+    QString url = QString( QStringLiteral("http://musicbrainz.org/recording/%1.html") ).arg( trackID );
 
     QDesktopServices::openUrl( QUrl::fromUserInput(url) );
 }
