@@ -23,16 +23,10 @@
 
 #define DEBUG_PREFIX "Playlist::Controller"
 
-// WORKAROUND for QTBUG-25960. Required for Qt versions < 4.8.5 in combination with libc++.
-#define QT_NO_STL 1
-    #include <qiterator.h>
-#undef QT_NO_STL
-
 #include "PlaylistController.h"
 
 #include "EngineController.h"
 #include "amarokconfig.h"
-#include "core/collections/QueryMaker.h"
 #include "core/support/Debug.h"
 #include "core-impl/meta/cue/CueFileSupport.h"
 #include "core-impl/meta/file/File.h"
@@ -43,8 +37,6 @@
 #include "playlist/PlaylistModelStack.h"
 #include "playlistmanager/PlaylistManager.h"
 
-#include <QAction>
-
 #include <algorithm>
 #include <typeinfo>
 
@@ -188,7 +180,7 @@ Controller::insertOptioned( Meta::TrackList list, AddOptions options )
         if( options.testFlag( PrependToQueue ) ) // PrependToQueue implies Queue
         {
             // append current queue to new queue and remove it
-            foreach( const quint64 id, Actions::instance()->queue() )
+            for( const quint64 id : Actions::instance()->queue() )
             {
                 Actions::instance()->dequeue( id );
                 ids << id;
@@ -334,7 +326,7 @@ Controller::removeRows( QList<int>& topModelRows )
 {
     DEBUG_BLOCK
     RemoveCmdList bottomModelCmds;
-    foreach( int topModelRow, topModelRows )
+    for( int topModelRow : topModelRows )
     {
         if( m_topModel->rowExists( topModelRow ) )
         {
@@ -359,7 +351,7 @@ Controller::removeDeadAndDuplicates()
 
     QList<int> topModelRowsToRemove;
 
-    foreach( Meta::TrackPtr unique, m_topModel->tracks() )
+    for( Meta::TrackPtr unique : m_topModel->tracks() )
     {
         QList<int> trackRows = m_topModel->allRowsForTrack( unique ).values();
 
@@ -454,7 +446,7 @@ Controller::moveRows( QList<int>& from, int to )
 
     int originalTo = to;
 
-    foreach ( int f, from )
+    for ( int f : from )
     {
         if( f < originalTo )
             to--; // since we are moving an item down in the list, this item will no longer count towards the target row
@@ -641,7 +633,7 @@ Controller::insertionHelper( int bottomModelRow, Meta::TrackList& tl )
 
     InsertCmdList bottomModelCmds;
 
-    foreach( Meta::TrackPtr t, modifiedList )
+    for( Meta::TrackPtr t : modifiedList )
         bottomModelCmds.append( InsertCmd( t, bottomModelRow++ ) );
 
     if( bottomModelCmds.size() > 0 )
