@@ -39,7 +39,7 @@ SortWidget::SortWidget( QWidget *parent )
     m_layout->setContentsMargins( 0, 0, 0, 0 );
 
     BreadcrumbItemButton *rootItem = new BreadcrumbItemButton(
-            QIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/playlist-sorting-16.png" ) ) ),
+            QIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral( "amarok/images/playlist-sorting-16.png" ) ) ) ),
             QString(), this );
     rootItem->setToolTip( i18n( "Clear the playlist sorting configuration." ) );
     m_layout->addWidget( rootItem );
@@ -162,8 +162,8 @@ SortWidget::sortPath() const
     {
         QString name( qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->name() );
         Qt::SortOrder sortOrder = qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->sortOrder();
-        QString level = name + '_' + ( sortOrder ? "des" : "asc" );
-        path.append( ( i == m_ribbon->count() - 1 ) ? level : ( level + '-' ) );
+        QString level = name + QLatin1Char('_') + ( sortOrder ? QStringLiteral("des") : QStringLiteral("asc") );
+        path.append( ( i == m_ribbon->count() - 1 ) ? level : ( level + QLatin1Char('-') ) );
     }
     return path;
 }
@@ -172,11 +172,13 @@ void
 SortWidget::readSortPath( const QString &sortPath )
 {
     trimToLevel();
+    if( sortPath.length() == 0) //avoid a warning by not confusing following code with empty string splitting
+        return;
 
     QStringList levels = sortPath.split( QLatin1Char('-') );
-    foreach( const QString &level, levels )
+    for( const QString &level : levels )
     {
-        QStringList levelParts = level.split( '_' );
+        QStringList levelParts = level.split( QLatin1Char('_') );
     /*
      * Check whether the configuration is valid. If indexOf
      * returns -1, the entry is corrupted. We can't use columnForName
@@ -205,8 +207,8 @@ SortWidget::prettySortPath() const
     {
         QString prettyName( qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->prettyName() );
         Qt::SortOrder sortOrder = qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->sortOrder();
-        QString prettyLevel = prettyName + ( sortOrder ? "↓" : "↑" );
-        prettyPath.append( ( i == m_ribbon->count() - 1 ) ? prettyLevel : ( prettyLevel + " > " ) );
+        QString prettyLevel = prettyName + ( sortOrder ? QStringLiteral("↓") : QStringLiteral("↑") );
+        prettyPath.append( ( i == m_ribbon->count() - 1 ) ? prettyLevel : ( prettyLevel + QStringLiteral(" > ") ) );
         //TODO: see how this behaves on RTL systems
     }
     return prettyPath;
