@@ -18,36 +18,35 @@
 #define INLINEEDITORWIDGET_H
 
 #include "playlist/layouts/LayoutItemConfig.h"
-
-#include <KHBox>
+#include "widgets/BoxWidget.h"
 
 #include <QModelIndex>
 #include <QSplitter>
 
 /**
-    An inline editor for a playlist item. Relies on the same item layout configuration as is used by the delegate, and strives to have a simmilar look.
+    An inline editor for a playlist item. Relies on the same item layout configuration as is used by the delegate, and strives to have a similar look.
 */
-class InlineEditorWidget : public KHBox
+class InlineEditorWidget : public BoxWidget
 {
     Q_OBJECT
 
 public:
-    InlineEditorWidget( QWidget * parent, const QModelIndex &index, Playlist::PlaylistLayout layout, int height, int width );
-    ~InlineEditorWidget();
+    InlineEditorWidget(QWidget * parent, const QModelIndex &index, const Playlist::PlaylistLayout &layout, int height, int width );
+    ~InlineEditorWidget() override;
 
     QMap<int, QString> changedValues();
 
-signals:
+Q_SIGNALS:
     void editingDone( InlineEditorWidget * editor );
 
-protected slots:
+protected Q_SLOTS:
     void editValueChanged();
     void ratingValueChanged();
     void splitterMoved( int pos, int index );
 
 private:
     void createChildWidgets();
-    bool eventFilter( QObject *obj, QEvent *event );
+    bool eventFilter( QObject *obj, QEvent *event ) override;
 
     QPersistentModelIndex m_index;
     Playlist::PlaylistLayout m_layout;
