@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2008-2011 Soren Harward <stharward@gmail.com>                          *
+ * Copyright (c) 2008-2012 Soren Harward <stharward@gmail.com>                          *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -41,31 +41,27 @@ namespace ConstraintTypes {
             static Constraint* createNew(ConstraintNode*);
             static ConstraintFactoryEntry* registerMe();
 
-            virtual QWidget* editWidget() const;
-            virtual void toXml(QDomDocument&, QDomElement&) const;
+            QWidget* editWidget() const override;
+            void toXml(QDomDocument&, QDomElement&) const override;
 
-            virtual QString getName() const;
+            QString getName() const override;
 
-            virtual double satisfaction(const Meta::TrackList&) const;
-            virtual quint32 suggestInitialPlaylistSize() const;
+            double satisfaction(const Meta::TrackList&) const override;
+            quint32 suggestPlaylistSize() const override;
 
-        private slots:
+        private Q_SLOTS:
             void setComparison( const int );
             void setDuration( const int );
             void setStrictness( const int );
 
         private:
             PlaylistDuration(QDomElement&, ConstraintNode*);
-            PlaylistDuration(ConstraintNode*);
+            explicit PlaylistDuration(ConstraintNode*);
 
             // constraint parameters
             qint64 m_duration; // time in msec
             int m_comparison;
             double m_strictness;
-
-            // convenience functions
-            QString comparisonToString() const;
-
     };
 
     class PlaylistDurationEditWidget : public QWidget {
@@ -74,13 +70,13 @@ namespace ConstraintTypes {
         public:
             PlaylistDurationEditWidget( const int, const int, const int );
 
-        signals:
+        Q_SIGNALS:
             void updated();
             void durationChanged( const int );
             void comparisonChanged( const int );
             void strictnessChanged( const int );
 
-        private slots:
+        private Q_SLOTS:
             void on_timeEdit_Duration_timeChanged( const QTime& );
             void on_comboBox_Comparison_currentIndexChanged( const int );
             void on_slider_Strictness_valueChanged( const int );
