@@ -17,28 +17,16 @@
 
 #include "SqlUserPlaylistProvider.h"
 
-#include "SvgHandler.h"
-#include "browsers/playlistbrowser/UserPlaylistModel.h"
 #include <core/storage/SqlStorage.h>
-#include "core/playlists/PlaylistFormat.h"
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 #include "core-impl/storage/StorageManager.h"
-#include "core-impl/playlists/types/file/m3u/M3UPlaylist.h"
-#include "core-impl/playlists/types/file/pls/PLSPlaylist.h"
-#include "core-impl/playlists/types/file/xspf/XSPFPlaylist.h"
 #include "core-impl/playlists/types/file/PlaylistFileSupport.h"
 
-#include <QAction>
-#include <QIcon>
-#include <QInputDialog>
-#include <QLabel>
 #include <QMap>
-#include <QUrl>
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KConfigGroup>
 
 static const int USERPLAYLIST_DB_VERSION = 3;
 // a database updater has been added in checkTables(). Use that when updating db version
@@ -69,7 +57,7 @@ Playlists::PlaylistList
 SqlUserPlaylistProvider::playlists()
 {
     Playlists::PlaylistList playlists;
-    foreach( Playlists::SqlPlaylistPtr sqlPlaylist, m_root->allChildPlaylists() )
+    for( Playlists::SqlPlaylistPtr sqlPlaylist : m_root->allChildPlaylists() )
     {
         playlists << Playlists::PlaylistPtr::staticCast( sqlPlaylist );
     }
@@ -92,7 +80,7 @@ bool
 SqlUserPlaylistProvider::deletePlaylists( const Playlists::PlaylistList &playlistList )
 {
     Playlists::SqlPlaylistList sqlPlaylists;
-    foreach( Playlists::PlaylistPtr playlist, playlistList )
+    for( Playlists::PlaylistPtr playlist : playlistList )
     {
         Playlists::SqlPlaylistPtr sqlPlaylist =
             Playlists::SqlPlaylistPtr::dynamicCast( playlist );
@@ -106,7 +94,7 @@ bool
 SqlUserPlaylistProvider::deleteSqlPlaylists( Playlists::SqlPlaylistList playlistList )
 {
     //this delete is not confirmed, has to be done by the slot connected to the delete action.
-    foreach( Playlists::SqlPlaylistPtr sqlPlaylist, playlistList )
+    for( Playlists::SqlPlaylistPtr sqlPlaylist : playlistList )
     {
         if( sqlPlaylist )
         {
@@ -157,7 +145,7 @@ Playlists::SqlPlaylistGroupPtr
 SqlUserPlaylistProvider::group( const QString &name )
 {
     DEBUG_BLOCK
-    Playlists::SqlPlaylistGroupPtr group;
+    Playlists::SqlPlaylistGroupPtr newGroup;
 
     if( name.isEmpty() )
         return m_root;
@@ -165,7 +153,7 @@ SqlUserPlaylistProvider::group( const QString &name )
     //clear the root first to force a reload.
     m_root->clear();
 
-    foreach( const Playlists::SqlPlaylistGroupPtr &group, m_root->allChildGroups() )
+    for( const Playlists::SqlPlaylistGroupPtr &group : m_root->allChildGroups() )
     {
         debug() << group->name();
         if( group->name() == name )
@@ -176,10 +164,10 @@ SqlUserPlaylistProvider::group( const QString &name )
     }
 
     debug() << "Creating a new group " << name;
-    group = new Playlists::SqlPlaylistGroup( name, m_root, this );
-    group->save();
+    newGroup = new Playlists::SqlPlaylistGroup( name, m_root, this );
+    newGroup->save();
 
-    return group;
+    return newGroup;
 }
 
 void
@@ -193,31 +181,31 @@ SqlUserPlaylistProvider::createTables()
         debug() << "No SQL Storage available!";
         return;
     }
-    sqlStorage->query( QString( "CREATE TABLE playlist_groups ("
-            " id " + sqlStorage->idType() +
-            ", parent_id INTEGER"
-            ", name " + sqlStorage->textColumnType() +
-            ", description " + sqlStorage->textColumnType() + " ) ENGINE = MyISAM;" ) );
+    sqlStorage->query( QStringLiteral( "CREATE TABLE playlist_groups ("
+            " id ") + sqlStorage->idType() +
+            QStringLiteral(", parent_id INTEGER"
+            ", name ") + sqlStorage->textColumnType() +
+            QStringLiteral(", description ") + sqlStorage->textColumnType() + QStringLiteral(" ) ENGINE = MyISAM;" ) );
     sqlStorage->query( QStringLiteral("CREATE INDEX parent_podchannel ON playlist_groups( parent_id );") );
 
 
-    sqlStorage->query( QString( "CREATE TABLE playlists ("
-            " id " + sqlStorage->idType() +
-            ", parent_id INTEGER"
-            ", name " + sqlStorage->textColumnType() +
-            ", urlid " + sqlStorage->exactTextColumnType() + " ) ENGINE = MyISAM;" ) );
+    sqlStorage->query( QStringLiteral( "CREATE TABLE playlists ("
+            " id ") + sqlStorage->idType() +
+            QStringLiteral(", parent_id INTEGER"
+            ", name ") + sqlStorage->textColumnType() +
+            QStringLiteral(", urlid ") + sqlStorage->exactTextColumnType() + QStringLiteral(" ) ENGINE = MyISAM;" ) );
     sqlStorage->query( QStringLiteral("CREATE INDEX parent_playlist ON playlists( parent_id );") );
 
-    sqlStorage->query( QString( "CREATE TABLE playlist_tracks ("
-            " id " + sqlStorage->idType() +
-            ", playlist_id INTEGER "
+    sqlStorage->query( QStringLiteral( "CREATE TABLE playlist_tracks ("
+            " id ") + sqlStorage->idType() +
+            QStringLiteral(", playlist_id INTEGER "
             ", track_num INTEGER "
-            ", url " + sqlStorage->exactTextColumnType() +
-            ", title " + sqlStorage->textColumnType() +
-            ", album " + sqlStorage->textColumnType() +
-            ", artist " + sqlStorage->textColumnType() +
-            ", length INTEGER "
-            ", uniqueid " + sqlStorage->textColumnType(128) + ") ENGINE = MyISAM;" ) );
+            ", url ") + sqlStorage->exactTextColumnType() +
+            QStringLiteral(", title ") + sqlStorage->textColumnType() +
+            QStringLiteral(", album ") + sqlStorage->textColumnType() +
+            QStringLiteral(", artist ") + sqlStorage->textColumnType() +
+            QStringLiteral(", length INTEGER "
+            ", uniqueid ") + sqlStorage->textColumnType(128) + QStringLiteral(") ENGINE = MyISAM;" ) );
 
     sqlStorage->query( QStringLiteral("CREATE INDEX parent_playlist_tracks ON playlist_tracks( playlist_id );") );
     sqlStorage->query( QStringLiteral("CREATE INDEX playlist_tracks_uniqueid ON playlist_tracks( uniqueid );") );
@@ -266,8 +254,8 @@ SqlUserPlaylistProvider::checkTables()
         //debug() << "creating Playlist Tables";
         createTables();
 
-        sqlStorage->query( "INSERT INTO admin(component,version) "
-                "VALUES('" + key + "'," + QString::number( USERPLAYLIST_DB_VERSION ) + ");" );
+        sqlStorage->query( QStringLiteral("INSERT INTO admin(component,version) "
+                "VALUES('") + key + QStringLiteral("',") + QString::number( USERPLAYLIST_DB_VERSION ) + QStringLiteral(");") );
     }
     else
     {
@@ -276,7 +264,7 @@ SqlUserPlaylistProvider::checkTables()
         {
             case 2:
                 upgradeVersion2to3();
-                sqlStorage->query( "UPDATE admin SET version = '" + QString::number( USERPLAYLIST_DB_VERSION )  + "' WHERE component = '" + key + "';" );
+                sqlStorage->query( QStringLiteral("UPDATE admin SET version = '") + QString::number( USERPLAYLIST_DB_VERSION )  + QStringLiteral("' WHERE component = '") + key + QStringLiteral("';") );
             case 3: // current version
                break;
             default:
@@ -306,7 +294,7 @@ Playlists::SqlPlaylistList
 SqlUserPlaylistProvider::toSqlPlaylists( Playlists::PlaylistList playlists )
 {
     Playlists::SqlPlaylistList sqlPlaylists;
-    foreach( Playlists::PlaylistPtr playlist, playlists )
+    for( Playlists::PlaylistPtr playlist : playlists )
     {
         Playlists::SqlPlaylistPtr sqlPlaylist =
             Playlists::SqlPlaylistPtr::dynamicCast( playlist );
