@@ -49,10 +49,10 @@ AmarokScriptCodeCompletionModel::completionInvoked( KTextEditor::View *view, con
     beginResetModel();
     m_completionList.clear();
     const QString &currentText = view->document()->text( range );
-    foreach( const QString &completionItem, m_autoCompleteStrings )
+    for( const QString &completionItem : m_autoCompleteStrings )
     {
         int index = completionItem.indexOf( currentText, Qt::CaseInsensitive ) + currentText.length();
-        if( index != -1 && !QStringRef( &completionItem, index, completionItem.size()-index ).contains( QLatin1Char('.') ) && completionItem != currentText )
+        if( index != -1 && !completionItem.mid(index, completionItem.size()-index ).contains( QLatin1Char('.') ) && completionItem != currentText )
             m_completionList << completionItem;
     }
     setRowCount( m_completionList.count() );
