@@ -22,7 +22,6 @@
 #include "core/support/Debug.h"
 #include "ScriptEditorDocument.h"
 
-#include <KMessageBox>
 #include <KTextEditor/View>
 
 #include <QFile>
@@ -31,8 +30,6 @@
 #include <QTextStream>
 #include <QDir>
 #include <QPlainTextEdit>
-#include <QMessageLogContext>
-#include <QStringBuilder>
 
 
 using namespace ScriptConsoleNS;
@@ -84,13 +81,13 @@ ScriptConsoleItem::~ScriptConsoleItem()
         m_error->deleteLater();
 }
 
-KPluginInfo
+KPluginMetaData
 ScriptConsoleItem::createSpecFile( const QString &name, const QString &category, const QString &path )
 {
-    QString specs = QString( "[Desktop Entry]"
+    QString specs = QStringLiteral( "[Desktop Entry]"
                             "\nIcon=\"\""
                             "\nType=script"
-                            "\nServiceTypes=KPluginInfo"
+                            "\nServiceTypes=KPluginMetaData"
                             "\nName=%1"
                             "\nComment=Amarok console script"
                             "\nX-KDE-PluginInfo-Name=%1"
@@ -103,13 +100,13 @@ ScriptConsoleItem::createSpecFile( const QString &name, const QString &category,
     QFile file( specPath );
     if( !file.open( QIODevice::WriteOnly ) )
     {
-        debug() << "Couldn't write to " + path;
-        return KPluginInfo();
+        debug() << "Couldn't write to " << path;
+        return KPluginMetaData();
     }
     QTextStream stream( &file );
     stream << specs;
     file.close();
-    return KPluginInfo( specPath );
+    return KPluginMetaData( specPath );
 }
 
 bool
@@ -189,7 +186,7 @@ ScriptConsoleItem::handleError( QJSValue *result )
 {
     QString errorString = QStringLiteral( "Script Error: %1 (line: %2)" )
                         .arg( result->toString() )
-                        .arg( result->property("lineNumber").toInt() );
+                        .arg( result->property(QStringLiteral("lineNumber")).toInt() );
 
     return errorString;
 }
