@@ -33,33 +33,33 @@ public:
     InfoParserBase();
 
      /**
-     * Fetches info about artist and emits info( Qstring )
+     * Fetches info about artist and emits info( QString )
      * with a ready to show html page when the info is ready
      * @param artist The artist to get info about
      */
-    virtual void getInfo( Meta::ArtistPtr artist ) = 0;
+    virtual void getInfo( const Meta::ArtistPtr &artist ) = 0;
 
     /**
      * Overloaded function
-     * Fetches info about album and emits info( Qstring )
+     * Fetches info about album and emits info( QString )
      * with a ready to show html page when the info is ready
-     * @param url The album to get info about
+     * @param album The album to get info about
      */
-    virtual void getInfo( Meta::AlbumPtr album ) = 0;
+    virtual void getInfo( const Meta::AlbumPtr &album ) = 0;
 
     /**
      * Overloaded function
-     * Fetches info about track and emits info( Qstring )
+     * Fetches info about track and emits info( QString )
      * with a ready to show html page when the info is ready
-     * @param url The track to get info about
+     * @param track The track to get info about
      */
-    virtual void getInfo( Meta::TrackPtr track ) = 0;
+    virtual void getInfo( const Meta::TrackPtr &track ) = 0;
 
     void showLoading( const QString &message );
 
-signals:
+Q_SIGNALS:
     /**
-     * Signal emmited when new html info is ready to be shown
+     * Signal emitted when new html info is ready to be shown
      * @param info The string containing the html formatted information
      */
     void info( const QString &info );
