@@ -20,13 +20,11 @@
 
 #include "ServiceCollection.h"
 
-#include "ServiceCollectionLocation.h"
 #include "amarokconfig.h"
-#include "ServiceMetaBase.h"
 #include "core/support/Debug.h"
-#include "support/MemoryQueryMaker.h"
-//#include "reader.h"
-
+#include "core-impl/collections/support/MemoryQueryMaker.h"
+#include "services/ServiceCollectionLocation.h"
+#include "services/ServiceMetaBase.h"
 
 using namespace Collections;
 
@@ -85,11 +83,11 @@ ServiceBase * ServiceCollection::service()
 
 void ServiceCollection::emitUpdated()
 {
-    emit( updated() );
+    Q_EMIT( updated() );
 }
 
 
-void ServiceCollection::addTrack( Meta::TrackPtr trackPtr )
+void ServiceCollection::addTrack( const Meta::TrackPtr &trackPtr )
 {
     m_mc->addTrack( trackPtr );
     const Meta::ServiceTrackPtr track = Meta::ServiceTrackPtr::dynamicCast( trackPtr );
@@ -98,7 +96,7 @@ void ServiceCollection::addTrack( Meta::TrackPtr trackPtr )
         m_trackIdMap.insert( track->id(), trackPtr );
 }
 
-void ServiceCollection::addArtist( Meta::ArtistPtr artistPtr )
+void ServiceCollection::addArtist( const Meta::ArtistPtr &artistPtr )
 {
     m_mc->addArtist( artistPtr );
     const Meta::ServiceArtistPtr artist = Meta::ServiceArtistPtr::dynamicCast( artistPtr );
@@ -107,7 +105,7 @@ void ServiceCollection::addArtist( Meta::ArtistPtr artistPtr )
         m_artistIdMap.insert( artist->id(), artistPtr );
 }
 
-void ServiceCollection::addAlbum( Meta::AlbumPtr albumPtr )
+void ServiceCollection::addAlbum( const Meta::AlbumPtr &albumPtr )
 {
     m_mc->addAlbum( albumPtr );
     const Meta::ServiceAlbumPtr album = Meta::ServiceAlbumPtr::dynamicCast( albumPtr );
@@ -116,7 +114,7 @@ void ServiceCollection::addAlbum( Meta::AlbumPtr albumPtr )
         m_albumIdMap.insert( album->id(), albumPtr );
 }
 
-void ServiceCollection::addGenre( Meta::GenrePtr genrePtr )
+void ServiceCollection::addGenre( const Meta::GenrePtr &genrePtr )
 {
     m_mc->addGenre( genrePtr );
     const Meta::ServiceGenrePtr genre = Meta::ServiceGenrePtr::dynamicCast( genrePtr );
@@ -146,5 +144,4 @@ Meta::GenrePtr ServiceCollection::genreById( int id )
 }
 
 
-#include "ServiceCollection.moc"
 
