@@ -22,8 +22,6 @@
 #include <QSet>
 
 class ServiceBase;
-class ServiceBrowser;
-class ServiceFactory;
 namespace Plugins {
     class PluginFactory;
 }
@@ -45,9 +43,9 @@ public:
      * Load any services that are configured to be loaded.
      * Unload any services that have been switched off.
      */
-    void setFactories( const QList<Plugins::PluginFactory*> &factories );
+    void setFactories( const QList<QSharedPointer<Plugins::PluginFactory> > &factories );
 
-public slots:
+public Q_SLOTS:
     QStringList loadedServices() const;
     QStringList loadedServiceNames() const;
     QString serviceDescription( const QString &service );
@@ -57,16 +55,16 @@ public slots:
 private:
     static ServicePluginManager* s_instance;
     ServicePluginManager();
-    ~ServicePluginManager();
+    ~ServicePluginManager() override;
 
     Q_DISABLE_COPY( ServicePluginManager )
 
     /** The list of currently set factories.
      *  Note: the PluginManager owns the pointers.
      */
-    QList<Plugins::PluginFactory*> m_factories;
+    QList<QSharedPointer<Plugins::PluginFactory> > m_factories;
 
-private slots:
+private Q_SLOTS:
     void slotNewService( ServiceBase *newService);
     void slotRemoveService( ServiceBase *removedService );
 };
