@@ -30,12 +30,12 @@ class LastfmInfoParser : public InfoParserBase
 
     public:
         LastfmInfoParser() : InfoParserBase() {}
-        ~LastfmInfoParser() {}
-        virtual void getInfo(Meta::TrackPtr track);
-        virtual void getInfo(Meta::AlbumPtr album);
-        virtual void getInfo(Meta::ArtistPtr artist);
+        ~LastfmInfoParser() override {}
+        void getInfo(const Meta::TrackPtr &track) override;
+        void getInfo(const Meta::AlbumPtr &album) override;
+        void getInfo(const Meta::ArtistPtr &artist) override;
 
-    private slots:
+    private Q_SLOTS:
         void onGetTrackInfo();
         void onGetAlbumInfo();
         void onGetArtistInfo();
