@@ -47,11 +47,14 @@ GpodderServiceFactory::~GpodderServiceFactory()
 void
 GpodderServiceFactory::init()
 {
+    if( m_initialized )
+        return;
+
     ServiceBase *service = createGpodderService();
     if( service )
     {
         m_initialized = true;
-        emit newService( service );
+        Q_EMIT newService( service );
     }
 }
 
@@ -64,7 +67,7 @@ GpodderServiceFactory::name()
 KConfigGroup
 GpodderServiceFactory::config()
 {
-    return Amarok::config( GpodderServiceConfig::configSectionName() );
+    return Amarok::config( QLatin1String(GpodderServiceConfig::configSectionName()) );
 }
 
 void
@@ -77,7 +80,7 @@ GpodderServiceFactory::slotCreateGpodderService()
         if( service )
         {
             m_initialized = true;
-            emit newService( service );
+            Q_EMIT newService( service );
         }
     }
 }
@@ -89,7 +92,7 @@ GpodderServiceFactory::slotRemoveGpodderService()
         return;
 
     m_initialized = false;
-    emit removeService( activeServices().first() );
+    Q_EMIT removeService( activeServices().first() );
 }
 
 ServiceBase *
@@ -220,7 +223,7 @@ GpodderService::polish()
     m_subscribeButton = new QPushButton();
     m_subscribeButton->setParent( m_bottomPanel );
     m_subscribeButton->setText( i18n( "Subscribe" ) );
-    m_subscribeButton->setObjectName( "subscribeButton" );
+    m_subscribeButton->setObjectName( QStringLiteral("subscribeButton") );
     m_subscribeButton->setIcon( QIcon::fromTheme( QStringLiteral("get-hot-new-stuff-amarok") ) );
 
     m_subscribeButton->setEnabled( true );
@@ -262,7 +265,7 @@ GpodderService::enableGpodderProvider( const QString &username )
 
     QString deviceName = QLatin1String( "amarok-" ) % QHostInfo::localHostName();
 
-    debug() << QString( "Enabling GpodderProvider( Username: %1 - Device: %1 )" )
+    debug() << QStringLiteral( "Enabling GpodderProvider( Username: %1 - Device: %1 )" )
                         .arg( username )
                         .arg( deviceName );
 
