@@ -29,8 +29,6 @@
 #include "widgets/SearchWidget.h"
 
 #include <QAction>
-#include <QDesktopServices>
-#include <QHBoxLayout>
 #include <QMenuBar>
 #include <QStandardPaths>
 #include <QTemporaryFile>
@@ -51,6 +49,9 @@ JamendoServiceFactory::JamendoServiceFactory()
 
 void JamendoServiceFactory::init()
 {
+    if( m_initialized )
+        return;
+
     ServiceBase* service = new JamendoService( this, "Jamendo.com" );
     m_initialized = true;
     emit newService( service );
