@@ -56,7 +56,7 @@ void
 LastFmTreeView::contextMenuEvent ( QContextMenuEvent* event )
 {
     m_currentItems.clear();
-    foreach ( const QModelIndex &i, selectedIndexes() )
+    for( const QModelIndex &i : selectedIndexes() )
     {
         if ( i.isValid() )
             m_currentItems << i;
@@ -70,7 +70,7 @@ LastFmTreeView::contextMenuEvent ( QContextMenuEvent* event )
 
     actions += &separator;
     QMenu menu;
-    foreach ( QAction * action, actions )
+    for( QAction * action : actions )
         menu.addAction ( action );
 
     menu.exec ( event->globalPos() );
@@ -94,8 +94,8 @@ QActionList LastFmTreeView::createBasicActions( const QModelIndexList & indices
         {
             if ( m_appendAction == nullptr )
             {
-                m_appendAction = new QAction ( QIcon::fromTheme( "media-track-add-amarok" ), i18n ( "&Add to Playlist" ), this );
-                m_appendAction->setProperty( "popupdropper_svg_id", "append" );
+                m_appendAction = new QAction ( QIcon::fromTheme( QStringLiteral("media-track-add-amarok") ), i18n ( "&Add to Playlist" ), this );
+                m_appendAction->setProperty( "popupdropper_svg_id", QStringLiteral("append") );
                 connect ( m_appendAction, &QAction::triggered, this, &LastFmTreeView::slotAppendChildTracks );
             }
 
@@ -103,8 +103,8 @@ QActionList LastFmTreeView::createBasicActions( const QModelIndexList & indices
 
             if ( m_loadAction == nullptr )
             {
-                m_loadAction = new QAction ( QIcon::fromTheme( "folder-open" ), i18nc ( "Replace the currently loaded tracks with these", "&Replace Playlist" ), this );
-                m_appendAction->setProperty( "popupdropper_svg_id", "load" );
+                m_loadAction = new QAction ( QIcon::fromTheme( QStringLiteral("folder-open") ), i18nc ( "Replace the currently loaded tracks with these", "&Replace Playlist" ), this );
+                m_appendAction->setProperty( "popupdropper_svg_id", QStringLiteral("load") );
                 connect ( m_loadAction, &QAction::triggered, this, &LastFmTreeView::slotReplacePlaylistByChildTracks );
             }
             actions.append ( m_loadAction );
@@ -157,12 +157,12 @@ LastFmTreeView::startDrag(Qt::DropActions supportedActions)
         font.setPointSize( 16 );
         font.setBold( true );
 
-        foreach( QAction * action, actions )
+        for( QAction * action : actions )
             m_pd->addItem( The::popupDropperFactory()->createItem( action ) );
 
 
         m_currentItems.clear();
-        foreach( const QModelIndex &index, indices )
+        for( const QModelIndex &index : indices )
         {
             if( index.isValid() && index.internalPointer() )
                 m_currentItems << index;
@@ -175,7 +175,7 @@ LastFmTreeView::startDrag(Qt::DropActions supportedActions)
         {
             morePud = The::popupDropperFactory()->createPopupDropper( nullptr, true );
 
-            foreach( QAction * action, actions )
+            for( QAction * action : actions )
                 morePud->addItem( The::popupDropperFactory()->createItem( action ) );
         }
         else
@@ -231,7 +231,7 @@ LastFmTreeView::playChildTracks ( const QModelIndexList &items, Playlist::AddOpt
 {
     debug() << "LASTFM current items : " << items.size();
     Meta::TrackList list;
-    foreach ( const QModelIndex &item, items )
+    for ( const QModelIndex &item : items )
     {
         Meta::TrackPtr track = model()->data(item, LastFm::TrackRole).value< Meta::TrackPtr >();
         if ( track )
