@@ -18,16 +18,13 @@
 #ifndef MP3TUNESMETA_H
 #define MP3TUNESMETA_H
 
-
 #include "../ServiceMetaBase.h"
 #include "../ServiceAlbumCoverDownloader.h"
 
-#include <KStandardDirs>
-
 #include <QDateTime>
+#include <QList>
 #include <QString>
 #include <QStringList>
-#include <QList>
 
 
 namespace Meta
@@ -38,7 +35,7 @@ class Mp3TunesTrack  : public ServiceTrack
 
     public:
 
-        Mp3TunesTrack( const QString& title );
+        explicit Mp3TunesTrack( const QString& title );
 
         virtual QString sourceName();
         virtual QString sourceDescription();
@@ -55,10 +52,9 @@ class Mp3TunesAlbum  : public ServiceAlbumWithCover
 private:
     QString m_coverURL;
 
-
 public:
-    Mp3TunesAlbum( const QString &name );
-    Mp3TunesAlbum( const QStringList &resultRow );
+    explicit Mp3TunesAlbum( const QString &name );
+    explicit Mp3TunesAlbum( const QStringList &resultRow );
 
     ~Mp3TunesAlbum();
 
@@ -66,10 +62,6 @@ public:
 
     virtual void setCoverUrl( const QString &coverURL );
     virtual QString coverUrl() const;
-
-    virtual QList< QAction *> customActions();
-
-
 };
 
 }
