@@ -222,7 +222,7 @@ void ScriptableServiceQueryMaker::handleResult( const Meta::TrackList &tracks )
     Meta::TrackList ret;
     if( m_convertToMultiTracks )
     {
-        foreach( const Meta::TrackPtr &track, tracks )
+        for( const Meta::TrackPtr &track : tracks )
         {
             using namespace Meta;
             const ScriptableServiceTrack *serviceTrack =
@@ -272,7 +272,7 @@ void ScriptableServiceQueryMaker::fetchArtists()
         {
             Meta::ArtistList allArtists = m_collection->artistMap().values();
 
-            foreach ( Meta::ArtistPtr artistPtr, allArtists )
+            for( Meta::ArtistPtr artistPtr : allArtists )
             {
                 Meta::ScriptableServiceArtist *scArtist = dynamic_cast<Meta::ScriptableServiceArtist *> ( artistPtr.data() );
                 if ( scArtist && scArtist->genreId() == d->parentId )
@@ -366,7 +366,7 @@ void ScriptableServiceQueryMaker::slotScriptComplete()
             {
                 Meta::ArtistList allArtists = m_collection->artistMap().values();
 
-                foreach ( Meta::ArtistPtr artistPtr, allArtists )
+                for( Meta::ArtistPtr artistPtr : allArtists )
                 {
                     Meta::ScriptableServiceArtist *scArtist = dynamic_cast<Meta::ScriptableServiceArtist *> ( artistPtr.data() );
 
@@ -429,8 +429,8 @@ QueryMaker * ScriptableServiceQueryMaker::addFilter( qint64 value, const QString
     if ( value == Meta::valTitle )
     {
         //I am sure there is a really good reason to add this space, as nothing works if it is removed, but WHY?!?
-        d->filter += filter + ' ';
-        d->filter = d->filter.replace( ' ', QLatin1String("%20") );
+        d->filter += filter + QLatin1Char(' ');
+        d->filter = d->filter.replace( QLatin1Char(' '), QLatin1String("%20") );
     }
 
     int level = 0;
