@@ -24,7 +24,7 @@
 #include "core/transcoding/TranscodingFormat.h"
 #include "core/transcoding/TranscodingConfiguration.h"
 
-#include <KDialog>
+#include <KPageDialog>
 
 class QListWidget;
 
@@ -32,23 +32,28 @@ namespace Transcoding
 {
 
 /**
- * A KDialog for initiating a transcoding operation.
+ * A QDialog for initiating a transcoding operation.
  * @author Téo Mrnjavac <teo@kde.org>
  */
-class AMAROK_TRANSCODING_EXPORT AssistantDialog : public KDialog
+class AMAROK_TRANSCODING_EXPORT AssistantDialog : public KPageDialog
 {
     Q_OBJECT
 public:
     /**
      * Create transcoding assistant dialog. Only encoders that encode to one of the
-     * @param playableFileTypes will be enabled.
+     * @p playableFileTypes will be enabled.
+     * @param playableFileTypes the playable file types
      * @param saveSupported true if transcoding config preference can be saved
      * @param operation whether this is copying or moving
      * @param destCollectionName name of the destination collection
+     * @param prevConfiguration previous configuration
+     * @param parent the parent widget
      */
     AssistantDialog( const QStringList &playableFileTypes, bool saveSupported,
                      Collections::CollectionLocationDelegate::OperationType operation,
-                     const QString &destCollectionName, QWidget *parent = 0 );
+                     const QString &destCollectionName,
+                     const Configuration &prevConfiguration,
+                     QWidget *parent = nullptr );
 
     Configuration configuration() const { return m_configuration; }
 
@@ -59,14 +64,14 @@ public:
 
 private:
     inline void populateFormatList();
+    Configuration::TrackSelection trackSelection() const;
 
-    Encoder m_defaultEncoder;
     Configuration m_configuration;
     bool m_save;
     QStringList m_playableFileTypes;
     Ui::AssistantDialog ui;
 
-private slots:
+private Q_SLOTS:
     void onJustCopyClicked();
     void onTranscodeClicked();
     void onFormatSelect( QListWidgetItem *item );
