@@ -20,12 +20,11 @@
 #include "core/transcoding/TranscodingProperty.h"
 #include "core/transcoding/TranscodingController.h"
 
-#include <QIcon>
 #include <KLocalizedString>
 
 #include <QHBoxLayout>
+#include <QIcon>
 #include <QLabel>
-#include <QSpinBox>
 
 namespace Transcoding
 {
@@ -34,7 +33,7 @@ OptionsStackedWidget::OptionsStackedWidget( QWidget *parent )
     : QStackedWidget( parent )
 {
     initWelcomePage();
-    foreach( const Encoder &encoder, Amarok::Components::transcodingController()->availableEncoders() )
+    for( const Encoder &encoder : Amarok::Components::transcodingController()->availableEncoders() )
     {
         Format *format = Amarok::Components::transcodingController()->format( encoder );
         m_pagesMap.insert( encoder, initCodecPage( format ) );
@@ -74,7 +73,7 @@ OptionsStackedWidget::initCodecPage( Format *format )
     QVBoxLayout *mainLayout = new QVBoxLayout( codecWidget );
     mainLayout->addStretch( 1 );
 
-    foreach( Property property, format->propertyList() )
+    for( Property property : format->propertyList() )
     {
         PropertyWidget *propertyWidget = PropertyWidget::create( property, codecWidget );
         mainLayout->addWidget( propertyWidget->widget() );
@@ -92,7 +91,7 @@ OptionsStackedWidget::configuration( const Configuration::TrackSelection trackSe
     Encoder encoder = m_pagesMap.key( currentIndex() );
     Configuration configuration = Configuration( encoder, trackSelection );
 
-    foreach( PropertyWidget *propertyWidget, m_propertyWidgetsMap.value( encoder ) )
+    for( PropertyWidget *propertyWidget : m_propertyWidgetsMap.value( encoder ) )
     {
         configuration.addProperty( propertyWidget->name(), propertyWidget->value() );
     }
