@@ -25,11 +25,11 @@ class AmarokDockWidget : public QDockWidget
     Q_OBJECT
 
 public:
-    explicit AmarokDockWidget( const QString & title, QWidget * parent = 0, Qt::WindowFlags flags = 0 );
+    explicit AmarokDockWidget( const QString & title, QWidget * parent = nullptr, Qt::WindowFlags flags = {} );
 
     void setMovable( bool movable );
 
-protected slots:
+protected Q_SLOTS:
     void slotVisibilityChanged( bool visible );
 
 protected:
