@@ -25,7 +25,7 @@
 #include <KLocalizedString>
 
 #include <QPainter>
-#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 BookmarkPopup::BookmarkPopup (QWidget* parent, const QString &label, BookmarkTriangle* triangle )
         : QWidget ( parent )
@@ -41,7 +41,7 @@ BookmarkPopup::BookmarkPopup (QWidget* parent, const QString &label, BookmarkTri
     m_overDelete = false;
     m_isEditMode = false;
 
-    m_deleteIcon = QIcon::fromTheme( "edit-delete" );
+    m_deleteIcon = QIcon::fromTheme( QStringLiteral("edit-delete") );
     adjustWidth();
 
     m_edit = new QLineEdit ( m_label, nullptr );
@@ -81,7 +81,7 @@ void BookmarkPopup::adjustWidth()
     m_lineHeight = fm.height();
     int line1Width = fm.horizontalAdvance ( i18n ( "Bookmark" ) ) + 40; //padding and space for delete icon
     int line2Width = fm.horizontalAdvance ( m_label ) + 8 ;
-    m_height = 44;
+    m_height = m_lineHeight * 2 + 10;
     m_width = qMax ( line1Width, line2Width ) + 2 * margin;
     resize ( m_width, m_height );
     m_deleteIconRect = QRect ( m_width - 20, 4, 16, 16 );
@@ -103,7 +103,7 @@ void BookmarkPopup::paintEvent ( QPaintEvent* event )
     p.drawPixmap ( m_deleteIconRect.x(), m_deleteIconRect.y(), m_deleteIcon.pixmap ( 16 ) );
 
     p.setOpacity ( 1 );
-    p.drawPixmap ( 5, 1, The::svgHandler()->renderSvg ( "bookmarks", 6, 20, "bookmarks" ) );
+    p.drawPixmap ( 5, 1, The::svgHandler()->renderSvg ( QStringLiteral("bookmarks"), 6, 20, QStringLiteral("bookmarks") ) );
 
     p.setPen ( Qt::gray );
     rect = QRect ( 15, 3, m_width, m_lineHeight );
@@ -161,7 +161,11 @@ void BookmarkPopup::mouseMoveEvent ( QMouseEvent * event )
     }
 }
 
-void BookmarkPopup::enterEvent ( QEvent* )
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void BookmarkPopup::enterEvent ( QEvent * )
+#else
+void BookmarkPopup::enterEvent ( QEnterEvent * )
+#endif
 {
     m_hasMouseOver = true;
 }
