@@ -55,7 +55,11 @@ class BreadcrumbItemButton : public Amarok::ElidingButton
         void setDisplayHintEnabled(DisplayHint hint, bool enable);
         bool isDisplayHintEnabled(DisplayHint hint) const;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         void enterEvent(QEvent* event) override;
+#else
+        void enterEvent(QEnterEvent* event) override;
+#endif
         void leaveEvent(QEvent* event) override;
 
         void paintEvent(QPaintEvent* event) override;
