@@ -18,24 +18,20 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
-#ifndef AMAROK_METAQUERY_H
-#define AMAROK_METAQUERY_H
+#ifndef AMAROK_METAQUERYWIDGET_H
+#define AMAROK_METAQUERYWIDGET_H
 
 #include <QWidget>
-#include <QWeakPointer>
+#include <QPointer>
 #include "core/meta/forward_declarations.h"
 #include "core/meta/support/MetaConstants.h"
 
-class QFrame;
-class QGridLayout;
+#include <KComboBox>
+#include <QSpinBox>
+
 class QHBoxLayout;
-class QVBoxLayout;
 class QLabel;
-class QToolButton;
-class KComboBox;
-class KIntSpinBox;
-class KToolBar;
-class KVBox;
+class QVBoxLayout;
 
 namespace Collections
 {
@@ -50,16 +46,24 @@ class TimeDistanceWidget : public QWidget
     Q_OBJECT
 
 public:
-    TimeDistanceWidget( QWidget *parent = 0 );
+    explicit TimeDistanceWidget( QWidget *parent = nullptr );
     qint64 timeDistance() const;
     void setTimeDistance( qint64 value );
-    void connectChanged( QObject *receiver, const char *slot );
+
+    template<class Receiver, class Func>
+    void connectChanged( Receiver receiver, Func slot )
+    {
+        connect( m_timeEdit, QOverload<int>::of(&QSpinBox::valueChanged),
+                 receiver, slot );
+        connect( m_unitSelection, QOverload<int>::of(&QComboBox::currentIndexChanged),
+                 receiver, slot );
+    }
 
 protected:
-    KIntSpinBox *m_timeEdit;
-    KComboBox *m_unitSelection;
+    QSpinBox *m_timeEdit;
+    QComboBox *m_unitSelection;
 
-private slots:
+private Q_SLOTS:
     void slotUpdateComboBoxLabels( int value );
 };
 
@@ -71,11 +75,12 @@ class MetaQueryWidget : public QWidget
 
     public:
         /** Creates a MetaQueryWidget which can be used to select one meta query filter.
+         *  @param parent The parent widget
          *  @param onlyNumeric If set to true the widget will only display numeric fields.
          *  @param noCondition If set to true no condition can be selected.
          */
-        explicit MetaQueryWidget( QWidget* parent = 0, bool onlyNumeric = false, bool noCondition = false );
-        ~MetaQueryWidget();
+        explicit MetaQueryWidget( QWidget* parent = nullptr, bool onlyNumeric = false, bool noCondition = false );
+        ~MetaQueryWidget() override;
 
         enum FilterCondition
         {
@@ -141,12 +146,13 @@ class MetaQueryWidget : public QWidget
         static bool isDate( qint64 field );
 
         /** Returns a localized text of the condition.
-            @param field Needed in order to test whether the field is a date, numeric or a string since the texts differ slightly
+         *  @param condition The condition
+         *  @param field Needed in order to test whether the field is a date, numeric or a string since the texts differ slightly
         */
         static QString conditionToString( FilterCondition condition, qint64 field );
 
 
-    public slots:
+    public Q_SLOTS:
         void setFilter(const MetaQueryWidget::Filter &value);
 
         void setField( const qint64 field );
@@ -155,10 +161,10 @@ class MetaQueryWidget : public QWidget
         bool isFieldSelectorHidden() const;
         void setFieldSelectorHidden( const bool hidden );
 
-    signals:
+    Q_SIGNALS:
         void changed(const MetaQueryWidget::Filter &value);
 
-    private slots:
+    private Q_SLOTS:
         void fieldChanged( int );
         void compareChanged( int );
         void valueChanged( const QString& );
@@ -173,7 +179,7 @@ class MetaQueryWidget : public QWidget
         void numValueTimeDistanceChanged();
         void numValueFormatChanged( int );
 
-        void populateComboBox( QStringList );
+        void populateComboBox(const QStringList & );
         void comboBoxPopulated();
 
     private:
@@ -191,7 +197,7 @@ class MetaQueryWidget : public QWidget
         void makeMetaComboSelection( qint64 field );
 
         void makeFormatComboSelection();
-        void makeGenericNumberSelection( qint64 field, const QString& unit = "" );
+        void makeGenericNumberSelection( qint64 field, const QString& unit = QLatin1String("") );
         void makePlaycountSelection();
         void makeRatingSelection();
         void makeLengthSelection();
@@ -208,15 +214,15 @@ class MetaQueryWidget : public QWidget
         QVBoxLayout* m_layoutValueLabels;
         QVBoxLayout* m_layoutValueValues;
 
-        KComboBox*   m_fieldSelection;
+        QComboBox*   m_fieldSelection;
         QLabel*      m_andLabel;
-        KComboBox*   m_compareSelection;
+        QComboBox*   m_compareSelection;
         QWidget*     m_valueSelection1;
         QWidget*     m_valueSelection2;
 
         Filter m_filter;
 
-        QMap< QObject*, QWeakPointer<KComboBox> > m_runningQueries;
+        QMap< QObject*, QPointer<KComboBox> > m_runningQueries;
 };
 
 #endif
