@@ -41,50 +41,50 @@ namespace Amarok
         Q_OBJECT
 
         public:
-            PrettyTreeView( QWidget *parent = 0 );
-            virtual ~PrettyTreeView();
+            explicit PrettyTreeView( QWidget *parent = nullptr );
+            ~PrettyTreeView() override;
+        /**
+         * Return pointer to decorator action which was most recently mouse-pressed
+         * or null it mouse button was released since then. Used by PrettyTreeDelegate.
+         */
+        QAction *pressedDecoratorAction() const;
 
-        public slots:
+        public Q_SLOTS:
             /* There is a need to overload even this edit() variant, otherwise it hides
-             * QAbstactItemView's implementation. Note that it is NOT safe to do anything
+             * QAbstractItemView's implementation. Note that it is NOT safe to do anything
              * special in this method, as it is not virtual.
              * bool edit( const QModelIndex &index, EditTrigger trigger, QEvent *event )
              * IS virtual. */
             void edit( const QModelIndex &index );
 
-            /**
-             * Return pointer to decorator action which was most recently mouse-pressed
-             * or null it mouse buttom was released since then. Used by PrettyTreeDelegate.
-             */
-            QAction *pressedDecoratorAction() const;
 
         protected:
-            bool edit( const QModelIndex &index, EditTrigger trigger, QEvent *event );
-            void drawRow( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const;
+            bool edit( const QModelIndex &index, EditTrigger trigger, QEvent *event ) override;
+            void drawRow( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const override;
 
             /**
              * Reimplemented to trigger item redraw in case mouse is over an item which
              * has decorator actions.
              */
-            void mouseMoveEvent( QMouseEvent *event );
+            void mouseMoveEvent( QMouseEvent *event ) override;
 
             /**
              * Reimplemented to handle expanding with single-click mouse setting event
              * when it is clicked outside the arrow and for consistency with
              * mouseReleaseEvent() in case of decorator actions.
              */
-            void mousePressEvent( QMouseEvent *event );
+            void mousePressEvent( QMouseEvent *event ) override;
 
             /**
              * Reimplemented to handle expanding with single-click mouse setting event
              * when it is clicked outside the arrow and to handle clicking on decorator
              * actions */
-            void mouseReleaseEvent( QMouseEvent *event );
+            void mouseReleaseEvent( QMouseEvent *event ) override;
 
             /**
              * Reimplemented to show proper tooltips for decorator actions.
              */
-            bool viewportEvent( QEvent *event );
+            bool viewportEvent( QEvent *event ) override;
 
             /**
              * Get dectorator action (little action icon as seen for example in collection
@@ -92,7 +92,7 @@ namespace Amarok
              */
             QAction *decoratorActionAt( const QModelIndex &idx, const QPoint &pos );
 
-        private slots:
+        protected Q_SLOTS:
             virtual void newPalette( const QPalette &palette );
 
         private:
