@@ -20,7 +20,6 @@
 
 #include <QLabel>
 
-class QMouseEvent;
 
 class TimeLabel : public QLabel
 {
@@ -36,7 +35,7 @@ public:
     void setText( const QString &text ); 
 
 protected:
-    virtual QSize sizeHint() const;
+    QSize sizeHint() const override;
 
 private:
     bool m_showTime;
