@@ -33,7 +33,11 @@ public:
     QSize sizeHint() const override;
 protected:
     bool eventFilter( QObject *o, QEvent *e ) override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void enterEvent( QEvent * ) override;
+#else
+    void enterEvent( QEnterEvent * ) override;
+#endif
     void leaveEvent( QEvent * ) override;
     void reloadContent( const QSize &sz ) override;
 private Q_SLOTS:
