@@ -67,7 +67,7 @@ private:
 
     Collections::SqlCollection *m_collection;
     QSharedPointer<MySqlEmbeddedStorage> m_storage;
-    QTemporaryDir *m_tmpDir;
+    static QTemporaryDir *s_tmpDir;
 };
 
 #endif // TESTSQLTRACK_H
