@@ -21,8 +21,6 @@
 #include "SafeFileSaver.h"
 
 //Taglib
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
 #include <apetag.h>
 #include <fileref.h>
 #include <flacfile.h>
@@ -37,11 +35,9 @@
 #include <uniquefileidentifierframe.h>
 #include <vorbisfile.h>
 #include <xiphcomment.h>
-#pragma GCC diagnostic pop
 
 #include <QtDebug>
 #include <QCryptographicHash>
-#include <QDateTime>
 #include <QDir>
 #include <QFileInfo>
 #include <QRandomGenerator>
@@ -104,7 +100,7 @@ AFTTagger::AFTTagger( int &argc, char **argv )
 
     m_time.start();
 
-    foreach( const QString &path, m_fileFolderList )
+    for( const auto &path : m_fileFolderList )
         processPath( path );
 
     m_textStream << tr( "INFO: All done, exiting..." ) << Qt::endl;
@@ -133,7 +129,7 @@ AFTTagger::processPath( const QString &path )
         {
             if( m_verbose )
                 m_textStream << tr( "INFO: Processing directory %1" ).arg( path ) << Qt::endl;
-            foreach( const QString &pathEntry, QDir( path ).entryList() )
+            for( const QString &pathEntry : QDir( path ).entryList() )
             {
                 if( pathEntry != QLatin1String(".") && pathEntry != QLatin1String("..") )
                     processPath( QDir( path ).canonicalPath() + QLatin1Char('/') +  pathEntry );
@@ -320,7 +316,7 @@ AFTTagger::handleMPEG( TagLib::MPEG::File *file )
         }
         if( newUid || ( nothingfound && !m_delete ) )
         {
-            QString ourId = QString( "Amarok 2 AFTv" + QString::number( s_currentVersion ) + " - amarok.kde.org" );
+            QString ourId = QStringLiteral( "Amarok 2 AFTv" ) + QString::number( s_currentVersion ) + QStringLiteral( " - amarok.kde.org" );
             if( uid.isEmpty() )
                 uid = createCurrentUID( file );
             if( m_verbose )
@@ -471,7 +467,7 @@ AFTTagger::handleXiphComment( TagLib::Ogg::XiphComment *comment, TagLib::File *f
     }
     if( newUid || ( nothingfound && !m_delete ) )
     {
-        QString ourId = QString( "Amarok 2 AFTv" + QString::number( s_currentVersion ) + " - amarok.kde.org" );
+        QString ourId = QStringLiteral( "Amarok 2 AFTv" ) + QString::number( s_currentVersion ) + QStringLiteral( " - amarok.kde.org" );
         if( uid.isEmpty() )
             uid = createCurrentUID( file );
         if( m_verbose )
@@ -577,7 +573,7 @@ AFTTagger::handleMPC( TagLib::MPC::File *file )
 
     if( newUid || ( nothingfound && !m_delete ) )
     {
-        QString ourId = QString( "Amarok 2 AFTv" + QString::number( s_currentVersion ) + " - amarok.kde.org" );
+        QString ourId = QStringLiteral( "Amarok 2 AFTv" ) + QString::number( s_currentVersion ) + QStringLiteral( " - amarok.kde.org" );
         if( uid.isEmpty() )
             uid = createCurrentUID( file );
         if( m_verbose )
@@ -623,7 +619,7 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
                 nothingfound = false;
 
                 if( m_verbose )
-                    m_textStream << tr( "INFO: Removing old-style ATF identifier %1" ).arg( key.toCString() ) << Qt::endl;
+                    m_textStream << tr( "INFO: Removing old-style ATF identifier %1" ).arg( QLatin1String( key.toCString() ) ) << Qt::endl;
 
                 toRemove.append( key );
                 if( !m_delete )
@@ -634,7 +630,7 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
                 nothingfound = false;
 
                 if( m_verbose )
-                    m_textStream << tr( "INFO: Found an existing AFT identifier: %1" ).arg( key.toCString() ) << Qt::endl;
+                    m_textStream << tr( "INFO: Found an existing AFT identifier: %1" ).arg( QLatin1String( key.toCString() ) ) << Qt::endl;
 
                 if( m_delete )
                 {
@@ -681,12 +677,12 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
 
     if( newUid || ( nothingfound && !m_delete ) )
     {
-        QString ourId = QString( "Amarok 2 AFTv" + QString::number( s_currentVersion ) + " - amarok.kde.org" );
+        QString ourId = QStringLiteral( "Amarok 2 AFTv" ) + QString::number( s_currentVersion ) + QStringLiteral( " - amarok.kde.org" );
         if( uid.isEmpty() )
             uid = createCurrentUID( file );
         if( m_verbose )
             m_textStream << tr( "INFO: Adding new field and saving file with UID: %1" ).arg( uid ) << Qt::endl;
-        itemsMap.insert( Qt5QStringToTString( QString( "----:com.apple.iTunes:" + ourId ) ),
+        itemsMap.insert( Qt5QStringToTString( QString( QStringLiteral( "----:com.apple.iTunes:" ) + ourId ) ),
                          TagLib::StringList( Qt5QStringToTString( uid ) ) );
         file->save();
         return true;
@@ -721,14 +717,14 @@ AFTTagger::createV1UID( TagLib::File *file )
     md5.addData( QString::number( QRandomGenerator::global()->generate() ).toUtf8() );
     md5.addData( QString::number( QRandomGenerator::global()->generate() ).toUtf8() );
     md5.addData( QString::number( m_time.elapsed() ).toUtf8() );
-    return QString( md5.result().toHex() );
+    return QLatin1String( md5.result().toHex() );
 }
 
 QString
 AFTTagger::upgradeUID( int version, const QString &currValue )
 {
     Q_UNUSED(version)
-    return currValue + "abcd";
+    return currValue + QStringLiteral( "abcd" );
 }
 
 void
@@ -739,7 +735,7 @@ AFTTagger::readArgs()
         displayHelp();
     bool nomore = false;
     int argnum = 0;
-    foreach( const QString &arg, argslist )
+    for( const auto &arg : argslist )
     {
         ++argnum;
         if( arg.isEmpty() || argnum == 1 )
@@ -764,21 +760,21 @@ AFTTagger::readArgs()
             else
                 displayHelp();
         }
-        else if( arg.startsWith( '-' ) )
+        else if( arg.startsWith( QLatin1Char( '-' ) ) )
         {
             QString myarg = QString( arg ).remove( 0, 1 );
             int pos = 0;
             while( pos < myarg.length() )
             {
-                if( myarg[pos] == 'd' )
+                if( myarg[pos] == QLatin1Char( 'd' ) )
                     m_delete = true;
-                else if( myarg[pos] == 'n' )
+                else if( myarg[pos] == QLatin1Char( 'n' ) )
                     m_newid = true;
-                else if( myarg[pos] == 'q' )
+                else if( myarg[pos] == QLatin1Char( 'q' ) )
                     m_quiet = true;
-                else if( myarg[pos] == 'r' )
+                else if( myarg[pos] == QLatin1Char( 'r' ) )
                     m_recurse = true;
-                else if( myarg[pos] == 'v' )
+                else if( myarg[pos] == QLatin1Char( 'v' ) )
                     m_verbose = true;
                 else
                     displayHelp();
@@ -798,7 +794,7 @@ void
 AFTTagger::displayHelp()
 {
     m_textStream << tr( "Amarok AFT Tagger" ) << Qt::endl << Qt::endl;
-    m_textStream << tr( "IRC:\nserver: irc.libera.chat / channels: #amarok, #amarok-de, #amarok-es, #amarok-fr\n\nFeedback:\namarok@kde.org" ) << Qt::endl << Qt::endl;
+    m_textStream << tr( "IRC:\nserver: irc.libera.chat / channel: #amarok\n\nFeedback:\namarok@kde.org" ) << Qt::endl << Qt::endl;
     m_textStream << tr( "Usage: amarok_afttagger [options] +File/Folder(s)" ) << Qt::endl << Qt::endl;
     m_textStream << tr( "User-modifiable Options:" ) << Qt::endl;
     m_textStream << tr( "+File/Folder(s)       : Files or folders to tag" ) << Qt::endl;
